package com.xxh.cloud.metadata.framework.modules.base.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.redis.RedisUtils;
import com.xxh.cloud.framework.common.tree.TreeUtils;
import com.xxh.cloud.framework.common.user.AuthContextUtils;
import com.xxh.cloud.framework.common.user.LoginUser;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.bean.dto.OpLogGenDTO;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.MetadataCategoryInfo;
import com.xxh.cloud.metadata.framework.modules.base.service.MetadataCategoryInfoService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategorySaveDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategoryTreeDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategoryUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.helper.MetadataCategoryHelper;
import com.xxh.cloud.metadata.framework.modules.base.biz.MetadataCategoryInfoBizService;
import com.xxh.cloud.metadata.framework.modules.cache.helper.MetaDataCacheKeysHelper;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class MetadataCategoryInfoBizServiceImpl implements MetadataCategoryInfoBizService {



    @Autowired
    private MetadataCategoryInfoService metadataCategoryInfoService;
    @Autowired
    private RedisUtils redisUtils;
    @Autowired
    private AdminUserClientService adminUserClientService;

    @Override
    public List<MetadataCategoryVO> tree(MetadataCategoryTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<MetadataCategoryInfo> list= metadataCategoryInfoService.list(
                new QueryWrapper<MetadataCategoryInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .orderByDesc("orders")
        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        Set<String> userIds=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
        });

        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
        List<MetadataCategoryVO> dataList=new ArrayList<>();
        list.forEach(item->{
            dataList.add(MetadataCategoryHelper.getMetadataStandardCategoryVO(item,userMap));
        });
        List<MetadataCategoryVO> data= TreeUtils.build(dataList);
        return data;
    }

    @Override
    public MetadataCategoryVO save(MetadataCategorySaveDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataCategoryInfo entity=new MetadataCategoryInfo();
        entity.setProjectCode(params.getProjectCode());
        if(StrUtil.isEmpty(params.getId())){
            entity.setId(MetadataCategoryHelper.getMetadataStandardCategoryId());
        }else {
            entity.setId(params.getId());
        }
        entity.setName(params.getName());
        entity.setPid(params.getPid());
        entity.setOrders(params.getOrders());
        entity.setRemark(params.getRemark());
        entity.setRowsStatus(YN.YES.getCode());
        metadataCategoryInfoService.save(entity);

        OpLogGenDTO opLogDTO= OperationLogUtils.getOpLogGenDTO(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_MetadataCategory,entity.getId(),null);
        opLogDTO.addExtend("名称",entity.getName());
        OperationLogUtils.addOpLogGen(opLogDTO);

        return MetadataCategoryHelper.getMetadataStandardCategoryVO(entity);
    }

    @Override
    public MetadataCategoryVO update(MetadataCategoryUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataCategoryInfo entity=metadataCategoryInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        Map<String, Object> logContent=new HashMap<>();
        logContent.put("原名称",entity.getName());

        entity.setName(params.getName());
        entity.setOrders(params.getOrders());
        entity.setRemark(params.getRemark());
        metadataCategoryInfoService.updateById(entity);
        redisUtils.delete(MetaDataCacheKeysHelper.getMetadataCategoryKey(entity.getId()));

        logContent.put("新名称",entity.getName());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_MetadataCategory,entity.getId(),logContent);
        return MetadataCategoryHelper.getMetadataStandardCategoryVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        MetadataCategoryInfo entity=metadataCategoryInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        long num= metadataCategoryInfoService.count(new QueryWrapper<MetadataCategoryInfo>()
                .eq("rows_status", YN.YES.getCode())
                .eq("pid",entity.getId()));

        if(num>0){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        metadataCategoryInfoService.updateById(entity);
        redisUtils.delete(MetaDataCacheKeysHelper.getMetadataCategoryKey(entity.getId()));
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_MetadataCategory,entity.getId(),null);

    }

    @Override
    public MetadataCategoryVO infoById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        MetadataCategoryInfo entity=metadataCategoryInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return MetadataCategoryHelper.getMetadataStandardCategoryVO(entity);
    }






}
