package com.xxh.cloud.metadata.framework.modules.base.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.basic.client.api.ParamsClientService;
import com.xxh.cloud.basic.client.api.bean.bos.ParamsBO;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.param.constant.ParamValTypeEnum;
import com.xxh.cloud.framework.common.redis.RedisUtils;
import com.xxh.cloud.framework.common.utils.XXEnumUtil;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.MetadataStandardBizTypeEnum;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.MetadataStandardTypeEnum;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.MetadataInfo;
import com.xxh.cloud.metadata.framework.modules.base.service.MetadataInfoService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoQueryDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoSaveDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataInfoVO;
import com.xxh.cloud.metadata.framework.modules.base.helper.MetadataInfoHelper;
import com.xxh.cloud.metadata.framework.modules.base.biz.MetadataInfoBizService;
import com.xxh.cloud.metadata.framework.modules.cache.helper.MetaDataCacheKeysHelper;
import com.xxh.cloud.metadata.framework.modules.cache.service.MetadataCategoryCacheService;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class MetadataInfoBizServiceImpl implements MetadataInfoBizService {



    @Autowired
    private RedisUtils redisUtils;
    @Autowired
    private AdminUserClientService adminUserClientService;
    @Autowired
    private MetadataCategoryCacheService metadataCategoryCacheService;

    @Autowired
    private MetadataInfoService metadataInfoService;

    @Autowired
    private ParamsClientService paramsClientService;


    private Map<String, ParamsBO> getParamsMap(){
        List<String> ids=new ArrayList<>();
        Map<String,MetadataStandardTypeEnum> map= XXEnumUtil.getEnumMap(MetadataStandardTypeEnum.class);
        map.forEach((k,v)->{
            ids.add(StrUtil.format(ParamValTypeEnum.MetadataValue_Config.getCode(),k));
        });
        Map<String, ParamsBO> paramsMap= paramsClientService.getParamsMapByIds(ids);
        return paramsMap;
    }

    @Override
    public IPage<MetadataInfo> queryMetadataInfo(MetadataInfoQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<MetadataInfo> page = metadataInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<MetadataInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getBizType()),"biz_type",params.getBizType())
                        .eq(StrUtil.isNotEmpty(params.getDataType()),"data_type",params.getDataType())
                        .eq(StrUtil.isNotEmpty(params.getUnit()),"unit",params.getUnit())
                        .eq(StrUtil.isNotEmpty(params.getCategoryId()),"category_id",params.getCategoryId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
        );

        return page;
    }

    @Override
    public PageData<MetadataInfoVO> query(MetadataInfoQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<MetadataInfo> page = metadataInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<MetadataInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getBizType()),"biz_type",params.getBizType())
                        .eq(StrUtil.isNotEmpty(params.getDataType()),"data_type",params.getDataType())
                        .eq(StrUtil.isNotEmpty(params.getUnit()),"unit",params.getUnit())
                        .eq(StrUtil.isNotEmpty(params.getCategoryId()),"category_id",params.getCategoryId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        Set<String> userIds=new HashSet<>();
        Set<String> categoryIds=new HashSet<>();
        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getCategoryId())){
                categoryIds.add(item.getCategoryId());
            }
        });

        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
        Map<String, MetadataCategoryVO> metadataCategoryMap= metadataCategoryCacheService.getMapByIds(categoryIds);

        PageData<MetadataInfoVO> data= new PageConverter<MetadataInfo, MetadataInfoVO>() {
            @Override
            public MetadataInfoVO converter(MetadataInfo entity) {
                return MetadataInfoHelper.getMetadataInfoVO(entity,metadataCategoryMap,userMap);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public MetadataInfoVO save(MetadataInfoSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataInfo entity=new MetadataInfo();
        entity.setProjectCode(params.getProjectCode());
        entity.setId(params.getId());
        entity.setCategoryId(params.getCategoryId());
        entity.setName(params.getName());
        if(StrUtil.isEmpty(params.getBizType())){
            entity.setBizType(MetadataStandardBizTypeEnum.Msbt_Standard.getCode());
        }else {
            entity.setBizType(params.getBizType());
        }

        entity.setDataType(params.getDataType());
//        entity.setDataContentType(params.getDataContentType());
        if(MapUtil.isNotEmpty(params.getValConfig())){
            entity.setValConfig(JSON.toJSONString(params.getValConfig()));
        }
        entity.setUnit(params.getUnit());



        if(MapUtil.isNotEmpty(params.getResultType())){
            entity.setResultType(JSON.toJSONString(params.getResultType()));
        }
        entity.setReferenceContent(params.getReferenceContent());
        entity.setRemark(params.getRemark());
        entity.setOrders(params.getOrders());
        entity.setRowsStatus(YN.YES.getCode());
        metadataInfoService.save(entity);

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("名称",entity.getName());
        logContent.put("业务类型",entity.getBizType());
        logContent.put("数据类型",entity.getDataType());
        logContent.put("单位",entity.getUnit());
//        logContent.put("数据内容分类",entity.getDataContentType());
        logContent.put("结果类型",entity.getResultType());

        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_Metadata,entity.getId(),logContent);

        return MetadataInfoHelper.getMetadataInfoVO(entity);
    }

    @Override
    public MetadataInfoVO update(MetadataInfoUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataInfo entity=metadataInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        Map<String, Object> logContent=new HashMap<>();
        logContent.put("原名称",entity.getName());
        logContent.put("原业务类型",entity.getBizType());
        logContent.put("原数据类型",entity.getDataType());
        logContent.put("原单位",entity.getUnit());
//        logContent.put("数据内容分类",entity.getDataContentType());

        entity.setName(params.getName());
        entity.setDataType(params.getDataType());
        if(MapUtil.isNotEmpty(params.getValConfig())){
            entity.setValConfig(JSON.toJSONString(params.getValConfig()));
        }
        entity.setUnit(params.getUnit());
//        entity.setDataContentType(params.getDataContentType());

        if(MapUtil.isNotEmpty(params.getResultType())){
            entity.setResultType(JSON.toJSONString(params.getResultType()));
        }
        entity.setReferenceContent(params.getReferenceContent());
        entity.setRemark(params.getRemark());
        entity.setOrders(params.getOrders());
        metadataInfoService.updateById(entity);
        redisUtils.delete(MetaDataCacheKeysHelper.getMetadataInfoKey(entity.getId()));

        logContent.put("新名称",entity.getName());
        logContent.put("新业务类型",entity.getBizType());
        logContent.put("新数据类型",entity.getDataType());
        logContent.put("新单位",entity.getUnit());
//        logContent.put("数据内容分类",entity.getDataContentType());

        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_Metadata,entity.getId(),logContent);

        return MetadataInfoHelper.getMetadataInfoVO(entity);
    }


    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        MetadataInfo entity=metadataInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        metadataInfoService.updateById(entity);
        redisUtils.delete(MetaDataCacheKeysHelper.getMetadataInfoKey(entity.getId()));
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_Metadata,entity.getId(),null);
    }

    @Override
    public MetadataInfoVO infoById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        MetadataInfo entity=metadataInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return this.getMetadataInfoVO(entity);
    }


    private MetadataInfoVO getMetadataInfoVO(MetadataInfo entity){
        Set<String> userIds=new HashSet<>();
        Set<String> categoryIds=new HashSet<>();
        if(StrUtil.isNotEmpty(entity.getCreator())){
            userIds.add(entity.getCreator());
        }
        if(StrUtil.isNotEmpty(entity.getUpdater())){
            userIds.add(entity.getUpdater());
        }
        if(StrUtil.isNotEmpty(entity.getCategoryId())){
            categoryIds.add(entity.getCategoryId());
        }
        Map<String, ParamsBO>  paramsMap= this.getParamsMap();
        Map<String, MetadataCategoryVO> metadataCategoryMap= metadataCategoryCacheService.getMapByIds(categoryIds);
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
        return  MetadataInfoHelper.getMetadataInfoVO(entity,metadataCategoryMap,userMap,paramsMap);
    }





}
