package com.xxh.cloud.metadata.framework.modules.base.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.redis.RedisUtils;
import com.xxh.cloud.framework.common.tree.TreeUtils;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableCategoryInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategoryTreeDTO;
import com.xxh.cloud.metadata.framework.modules.base.service.TableCategoryInfoService;
import com.xxh.cloud.metadata.framework.modules.base.service.TableInfoService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategorySaveDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategoryUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.helper.TableCategoryHelper;
import com.xxh.cloud.metadata.framework.modules.base.biz.TableCategoryInfoBizService;
import com.xxh.cloud.metadata.framework.modules.cache.helper.MetaDataCacheKeysHelper;
import com.xxh.cloud.metadata.framework.modules.cache.service.TableCategoryCacheService;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class TableCategoryInfoBizServiceImpl implements TableCategoryInfoBizService {



    @Autowired
    private TableCategoryInfoService tableCategoryInfoService;
    @Autowired
    private TableInfoService tableInfoService;
    @Autowired
    private TableCategoryCacheService tableCategoryCacheService;
    @Autowired
    private AdminUserClientService adminUserClientService;



    @Override
    public List<TableCategoryVO> tree(TableCategoryTreeDTO params) {
        List<TableCategoryInfo> list= tableCategoryInfoService.list(
                new QueryWrapper<TableCategoryInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code", params.getProjectCode())
        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        Set<String> userIds=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
        });

        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        List<TableCategoryVO> dataList=new ArrayList<>();
        list.forEach(item->{
            dataList.add(TableCategoryHelper.getTableCategoryVO(item,userMap));
        });

        List<TableCategoryVO> data= TreeUtils.build(dataList);
        return data;
    }

    @Override
    public TableCategoryVO save(TableCategorySaveDTO params) {
        ValidatorUtils.validateEntity(params);
        TableCategoryInfo entity=new TableCategoryInfo();
        if(StrUtil.isEmpty(params.getId())){
            entity.setId(TableCategoryHelper.getTableCategoryId());
        }else {
            entity.setId(params.getId());
        }
        entity.setProjectCode(params.getProjectCode());
        entity.setName(params.getName());
        entity.setPid(params.getPid());
        entity.setOrders(params.getOrders());
        entity.setRemark(params.getRemark());
        entity.setRowsStatus(YN.YES.getCode());
        tableCategoryInfoService.save(entity);

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("名称",entity.getName());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_TableCategory,entity.getId(),logContent);

        return TableCategoryHelper.getTableCategoryVO(entity);
    }

    @Override
    public TableCategoryVO update(TableCategoryUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        TableCategoryInfo entity=tableCategoryInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        Map<String, Object> logContent=new HashMap<>();
        logContent.put("原名称",entity.getName());
        entity.setName(params.getName());
        entity.setOrders(params.getOrders());
        entity.setRemark(params.getRemark());
        tableCategoryInfoService.updateById(entity);
        tableCategoryCacheService.removeById(entity.getId());

        logContent.put("新名称",entity.getName());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_TableCategory,entity.getId(),logContent);

        return TableCategoryHelper.getTableCategoryVO(entity);
    }

    @Override
    public TableCategoryVO infoById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        TableCategoryInfo entity=tableCategoryInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return this.info(entity);
    }



    private TableCategoryVO info(TableCategoryInfo entity){
        Set<String> userIds=new HashSet<>();
        if(StrUtil.isNotEmpty(entity.getCreator())){
            userIds.add(entity.getCreator());
        }
        if(StrUtil.isNotEmpty(entity.getUpdater())){
            userIds.add(entity.getUpdater());
        }
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
        return TableCategoryHelper.getTableCategoryVO(entity,userMap);
    }

//    @Override
//    public List<TableCategoryVO> getListByIds(Collection<String> ids) {
//        if(CollUtil.isEmpty(ids)){
//            return null;
//        }
//        List<TableCategoryInfo> list= tableCategoryInfoService.list(
//                new QueryWrapper<TableCategoryInfo>()
//                        .eq("rows_status", YN.YES.getCode())
//                        .in("id",ids)
//        );
//        if(CollUtil.isEmpty(list)){
//            return null;
//        }
//
//        Set<String> userIds=new HashSet<>();
//        list.forEach(item->{
//            if(StrUtil.isNotEmpty(item.getCreator())){
//                userIds.add(item.getCreator());
//            }
//            if(StrUtil.isNotEmpty(item.getUpdater())){
//                userIds.add(item.getUpdater());
//            }
//        });
//
//        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
//        List<TableCategoryVO> data=new ArrayList<>();
//        list.forEach(item->{
//            data.add(TableCategoryHelper.getTableCategoryVO(item,userMap));
//        });
//        return data;
//    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        TableCategoryInfo entity=tableCategoryInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        long num= tableInfoService.count(
                new QueryWrapper<TableInfo>()
                        .eq("category_id",entity.getId())
                        .eq("rows_status", YN.YES.getCode())
        );
        if(num>0){
            throw new BusinessException(BusinessBaseErrorEnum.Illegal_Operation_ERROR,"有关联数据,无法操作");
        }
        entity.setRowsStatus(YN.NO.getCode());
        tableCategoryInfoService.updateById(entity);
        tableCategoryCacheService.removeById(entity.getId());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_TableCategory,entity.getId(),null);

    }


}
