package com.xxh.cloud.metadata.framework.modules.base.helper;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.xxh.cloud.basic.client.api.bean.bos.ParamsBO;
import com.xxh.cloud.framework.common.param.bos.MetadataValueConfigBO;
import com.xxh.cloud.framework.common.param.constant.ParamValTypeEnum;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.MetadataStandardTypeEnum;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.MetadataInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataInfoVO;
import com.xxh.cloud.metadata.client.api.bean.bos.metadata.MetadataStandardValueDicModel;
import com.xxh.cloud.metadata.client.api.bean.bos.metadata.MetadataStandardValueNumModel;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;

import java.util.HashMap;
import java.util.Map;

public class MetadataInfoHelper {


    public static MetadataInfoVO getMetadataInfoVO(MetadataInfo entity) {
        MetadataInfoVO data = new MetadataInfoVO();
        BeanUtil.copyProperties(entity, data, "valConfig", "resultType");

        if (StrUtil.isNotEmpty(entity.getValConfig())) {
            data.setValConfig(JSON.parseObject(entity.getValConfig(), Map.class));
        } else {
            data.setValConfig(new HashMap<>());
        }

        if (StrUtil.isNotEmpty(entity.getResultType())) {
            data.setResultType(JSON.parseObject(entity.getResultType(), Map.class));
        }
        if(MetadataStandardTypeEnum.MT_Dict.getCode().equals(data.getDataType())){
            data.setDataContentType(Convert.toStr(data.getValConfig().get("dictType")));
        }
        return data;
    }


    public static MetadataInfoVO getMetadataInfoVO(MetadataInfo entity,
                                                   Map<String, MetadataCategoryVO> metadataCategoryMap,
                                                   Map<String, AdminUserBO> userMap,
                                                   Map<String, ParamsBO> paramsMap) {
        MetadataInfoVO data = getMetadataInfoVO(entity, metadataCategoryMap, userMap);

        if (MapUtil.isNotEmpty(paramsMap)) {
            String paramKey = StrUtil.format(ParamValTypeEnum.MetadataValue_Config.getCode(), entity.getDataType());
            ParamsBO paramsBO = paramsMap.get(paramKey);
            if (paramsBO != null && CollUtil.isNotEmpty(paramsBO.getParamValueList())) {
                paramsBO.getParamValueList().forEach(item -> {
                    MetadataValueConfigBO mvcBO = BeanUtil.fillBeanWithMap(item, new MetadataValueConfigBO(), false);
                    mvcBO.setVal(data.getValConfig().get(mvcBO.getKey()));
                    data.addMetadataValueConfig(mvcBO);
                });
            }
        }
        return data;
    }


    public static MetadataInfoVO getMetadataInfoVO(MetadataInfo entity, Map<String, MetadataCategoryVO> metadataCategoryMap, Map<String, AdminUserBO> userMap) {
        MetadataInfoVO data = getMetadataInfoVO(entity);
        if (data == null) {
            return null;
        }

        if (MapUtil.isNotEmpty(metadataCategoryMap) && StrUtil.isNotEmpty(data.getCategoryId())) {
            MetadataCategoryVO category = metadataCategoryMap.get(data.getCategoryId());
            if (category != null) {
                data.setCategoryName(category.getName());
            }
        }

        if (MapUtil.isNotEmpty(userMap)) {
            if (StrUtil.isNotEmpty(data.getCreator())) {
                AdminUserBO user = userMap.get(data.getCreator());
                if (user != null) {
                    data.setCreatorUserName(user.getUserName());
                    data.setCreatorRealName(user.getRealName());
                }
            }
            if (StrUtil.isNotEmpty(data.getUpdater())) {
                AdminUserBO user = userMap.get(data.getUpdater());
                if (user != null) {
                    data.setUpdaterUserName(user.getUserName());
                    data.setUpdaterRealName(user.getRealName());
                }
            }
        }

        return data;
    }


}
