package com.xxh.cloud.metadata.framework.modules.base.helper;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.xxh.cloud.metadata.client.api.bean.bos.meta.MetadataBO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableColumnInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableColumnVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;

import java.util.List;
import java.util.Map;

public class TableInfoHelper {


    public static String getTableConfigId(){
        return StrUtil.format("TD_{}", IdUtil.getSnowflake(6,3).nextIdStr());
    }

    public static String getTableColumnId(){
        return StrUtil.format("TC{}", IdUtil.getSnowflake(6,4).nextIdStr());
    }

    public static TableInfoVO getTableInfoVO(TableInfo entity){
        TableInfoVO data=new TableInfoVO();
        BeanUtil.copyProperties(entity,data);
        return data;
    }

    public static TableInfoVO getTableInfoVO(TableInfo entity,
                                             Map<String, AdminUserBO> userMap,
                                             Map<String, TableCategoryVO> categoryMap){
        TableInfoVO data=getTableInfoVO(entity);
        if(data==null){
            return null;
        }

        if(MapUtil.isNotEmpty(userMap)){
            if(StrUtil.isNotEmpty(data.getCreator())){
                AdminUserBO user= userMap.get(data.getCreator());
                if(user!=null){
                    data.setCreatorUserName(user.getUserName());
                    data.setCreatorRealName(user.getRealName());
                }
            }
            if(StrUtil.isNotEmpty(data.getUpdater())){
                AdminUserBO user= userMap.get(data.getUpdater());
                if(user!=null){
                    data.setUpdaterUserName(user.getUserName());
                    data.setUpdaterRealName(user.getRealName());
                }
            }
        }

        if(MapUtil.isNotEmpty(categoryMap) && StrUtil.isNotEmpty(data.getCategoryId())){
            TableCategoryVO category=categoryMap.get(data.getCategoryId());
            if(category!=null){
                data.setCategoryName(category.getName());
            }
        }
        return data;
    }

    public static TableInfoVO getTableInfoVO(TableInfo entity,
                                             Map<String, AdminUserBO> userMap,
                                             Map<String, TableCategoryVO> categoryMap,
                                             List<TableColumnInfo> columnList,
                                             Map<String, MetadataBO> metadataMap){
        TableInfoVO data=getTableInfoVO(entity,userMap,categoryMap);
        if(data==null){
            return null;
        }
        if(CollUtil.isEmpty(columnList)){
            return data;
        }

        columnList.forEach(item->{
            if(data.getId().equals(item.getTableId())){
                data.addCol(getTableColumnVO(item,metadataMap));
            }
        });

        return data;
    }


    public static TableColumnVO getTableColumnVO(TableColumnInfo entity,Map<String, MetadataBO> metadataMap){
        TableColumnVO data=new TableColumnVO();
        BeanUtil.copyProperties(entity,data,"metadata","config");
        if(StrUtil.isNotEmpty(entity.getConfig())){
            data.setConfig(JSON.parseObject(entity.getConfig(),Map.class));
        }
        if(MapUtil.isNotEmpty(metadataMap) && StrUtil.isNotEmpty(data.getMetadataId())){
            data.setMetadata(metadataMap.get(data.getMetadataId()));
        }
        return data;
    }




}
