package com.xxh.cloud.metadata.framework.modules.cache.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.redis.BasicCacheServiceImpl;
import com.xxh.cloud.metadata.client.api.bean.bos.meta.MetadataBO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableColumnInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableInfoListDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.metadata.framework.modules.base.biz.TableInfoBizService;
import com.xxh.cloud.metadata.framework.modules.base.helper.TableInfoHelper;
import com.xxh.cloud.metadata.framework.modules.base.service.TableColumnInfoService;
import com.xxh.cloud.metadata.framework.modules.base.service.TableInfoService;
import com.xxh.cloud.metadata.framework.modules.cache.helper.MetaDataCacheKeysHelper;
import com.xxh.cloud.metadata.framework.modules.cache.service.TableInfoCacheService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class TableInfoCacheServiceImpl  extends BasicCacheServiceImpl<TableInfoVO>  implements TableInfoCacheService {

    @Autowired
    private TableInfoService tableInfoService;
    @Autowired
    private TableColumnInfoService tableColumnInfoService;

    @Override
    public String getCacheKey(String id) {
        return MetaDataCacheKeysHelper.getTableKey(id);
    }

    @Override
    public String getCacheKeyPattern() {
        return MetaDataCacheKeysHelper.getTableMainKey();
    }

    @Override
    public Class<TableInfoVO> getJsonClazz() {
        return TableInfoVO.class;
    }

    @Override
    public String getId(TableInfoVO entity) {
        return entity.getId();
    }

    @Override
    public TableInfoVO getById2DB(String id) {
        if(StrUtil.isEmpty(id)){
            return null;
        }
        TableInfo entity=tableInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            return null;
        }


        List<TableColumnInfo> list= tableColumnInfoService.list(
                new QueryWrapper<TableColumnInfo>()
                        .eq("table_id",entity.getId())
        );

        Set<String> categoryIds=new HashSet<>();
        Set<String> userIds=new HashSet<>();
        if(StrUtil.isNotEmpty(entity.getCategoryId())){
            categoryIds.add(entity.getCategoryId());
        }
        if(StrUtil.isNotEmpty(entity.getCreator())){
            userIds.add(entity.getCreator());
        }
        if(StrUtil.isNotEmpty(entity.getUpdater())){
            userIds.add(entity.getUpdater());
        }

        Set<String> metadataIds=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getMetadataId())){
                metadataIds.add(item.getMetadataId());
            }
        });
        return TableInfoHelper.getTableInfoVO(entity,null,null,list,null);



    }

    @Override
    public List<TableInfoVO> getListByIds2DB(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return null;
        }
        List<TableInfo> list= tableInfoService.list(
                new QueryWrapper<TableInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .in("id",ids)
        );
        if(CollUtil.isEmpty(list)){
            return null;
        }

        Set<String> tableIds=new HashSet<>();
        list.forEach(item->{
            tableIds.add(item.getId());
        });


        List<TableColumnInfo> columnList= tableColumnInfoService.list(
                new QueryWrapper<TableColumnInfo>()
                        .in("table_id",tableIds)
        );

        List<TableInfoVO> data=new ArrayList<>();
        list.forEach(item->{
            data.add(TableInfoHelper.getTableInfoVO(item,null,null,columnList,null));
        });
        return data;
    }


}
