package com.xxh.cloud.metadata.framework.modules.client.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.tree.TreeListUtils;
import com.xxh.cloud.metadata.client.api.MetadataClientService;
import com.xxh.cloud.metadata.client.api.bean.bos.meta.MetadataBO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.MetadataCategoryInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.MetadataInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataInfoVO;
import com.xxh.cloud.metadata.framework.modules.base.service.MetadataCategoryInfoService;
import com.xxh.cloud.metadata.framework.modules.base.service.MetadataInfoService;
import com.xxh.cloud.metadata.framework.modules.cache.service.MetadataInfoCacheService;
import com.xxh.cloud.metadata.framework.modules.client.helper.MetadataClientConvert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
public class MetadataClientServiceImpl implements MetadataClientService {

    @Autowired
    private MetadataInfoCacheService metadataInfoCacheService;

    @Autowired
    private MetadataInfoService metadataInfoService;

    @Autowired
    private MetadataCategoryInfoService metadataCategoryInfoService;

    @Override
    public MetadataBO getMetadata(String id) {
        if(StrUtil.isEmpty(id)){
            return null;
        }
        MetadataInfoVO entity= metadataInfoCacheService.getById(id);
        return MetadataClientConvert.getMetadataBO(entity);
    }

    @Override
    public List<MetadataBO> getMetadataList(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>();
        }
        List<MetadataInfoVO> list = metadataInfoCacheService.getListByIds(ids);
        if (CollUtil.isEmpty(list)) {
            return new ArrayList<>();
        }
        return list.stream().map(MetadataClientConvert::getMetadataBO).collect(Collectors.toList());
    }

    @Override
    public Map<String, MetadataBO> getMetadataMap(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>();
        }
        List<MetadataInfoVO> list = metadataInfoCacheService.getListByIds(ids);
        if (CollUtil.isEmpty(list)) {
            return new HashMap<>();
        }
        return new HashMap<>(list.stream().collect(Collectors.toMap(MetadataInfoVO::getId, MetadataClientConvert::getMetadataBO)));
    }


    @Override
    public List<MetadataBO> getMetadataListByCategory(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new ArrayList<>();
        }
        List<String> ids= this.getMetadataIdsByCategory(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>();
        }
        return this.getMetadataList(ids);
    }




    @Override
    public Map<String, MetadataBO> getMetadataMapByCategory(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new HashMap<>();
        }
        List<String> ids= this.getMetadataIdsByCategory(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>();
        }
        return this.getMetadataMap(ids);
    }

    @Override
    public List<MetadataBO> getMetadataListByCategory2Child(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new ArrayList<>();
        }
        List<String> ids= this.getMetadataIdsByCategoryChild(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>();
        }
        return this.getMetadataList(ids);
    }

    @Override
    public Map<String, MetadataBO> getMetadataMapByCategory2Child(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new HashMap<>();
        }
        List<String> ids= this.getMetadataIdsByCategoryChild(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>();
        }
        return this.getMetadataMap(ids);
    }

    private List<String> getMetadataIdsByCategory(String categoryId) {
        List<String> categoryIds=new ArrayList<>();
        categoryIds.add(categoryId);
        return this.getMetadataIdsByCategory(categoryIds);
    }

    private List<String> getMetadataIdsByCategory(List<String> categoryIds) {
        List<String> ids=new ArrayList<>();
        if(CollUtil.isEmpty(categoryIds)){
            return ids;
        }
        List<MetadataInfo> list = metadataInfoService.list(
                new QueryWrapper<MetadataInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in("category_id",categoryIds)
        );
        if(CollUtil.isEmpty(list)){
            return  ids;
        }

        list.forEach(item->{
            ids.add(item.getId());
        });
        return ids;
    }

    private List<String> getMetadataIdsByCategoryChild(String categoryId) {
        List<String> categoryIds=new ArrayList<>();

        List<MetadataCategoryInfo> list= metadataCategoryInfoService.list(
                new QueryWrapper<MetadataCategoryInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .orderByDesc("orders")
        );

        if(CollUtil.isEmpty(list)){
            return  new ArrayList<>();
        }

        TreeListUtils<MetadataCategoryInfo> treeListUtils=new TreeListUtils<MetadataCategoryInfo>() {
            @Override
            public String getId(MetadataCategoryInfo metadataCategoryInfo) {
                return metadataCategoryInfo.getId();
            }

            @Override
            public String getPid(MetadataCategoryInfo metadataCategoryInfo) {
                return metadataCategoryInfo.getPid();
            }
        };

        categoryIds = treeListUtils.getTreeListIds(list,categoryId,true);

        return this.getMetadataIdsByCategory(categoryIds);
    }

}
