package com.xxh.cloud.metadata.framework.modules.client.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.xxh.cloud.metadata.client.api.StandardMedicantDrugRelClientService;
import com.xxh.cloud.metadata.client.api.bean.bos.standard.StandardMedicantDrugRelBO;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardMedicantCacheService;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardMedicantDrugRelCacheService;
import com.xxh.cloud.metadata.framework.modules.client.helper.StandardClientConvert;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantDrugRelVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantVO;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
public class StandardMedicantDrugRelClientServiceImpl implements StandardMedicantDrugRelClientService {

    @Autowired
    private StandardMedicantDrugRelCacheService standardMedicantDrugRelCacheService;
    @Autowired
    private StandardMedicantCacheService standardMedicantCacheService;


    @Override
    public StandardMedicantDrugRelBO getById(String id) {
        if(StrUtil.isEmpty(id)){
            return null;
        }
        StandardMedicantDrugRelVO entity = standardMedicantDrugRelCacheService.getById(id);

        StandardMedicantDrugRelBO bo = StandardClientConvert.getStandardMedicantDrugRelBO(entity);

        if (null != bo) {
            StandardMedicantVO medicant = standardMedicantCacheService.getById(entity.getMedicantId());
            if (null != medicant) {
                bo.setStandardMedicantInfo(StandardClientConvert.getStandardMedicantBO(medicant));
            }
        }

        return bo;
    }

    @Override
    public List<StandardMedicantDrugRelBO> getList(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>(0);
        }
        List<StandardMedicantDrugRelVO> list = standardMedicantDrugRelCacheService.getListByIds(ids);
        if (CollUtil.isEmpty(list)) {
            return new ArrayList<>(0);
        }

        List<String> medicantIds = new ArrayList<>();
        list.forEach(i -> medicantIds.add(i.getMedicantId()));
        Map<String, StandardMedicantVO> medicantMap = standardMedicantCacheService.getMapByIds(medicantIds);

        return list.stream().map(i -> {
            StandardMedicantDrugRelBO bo = StandardClientConvert.getStandardMedicantDrugRelBO(i);
            if (null != bo) {
                StandardMedicantVO medicant = medicantMap.get(i.getMedicantId());
                if (null != medicant) {
                    bo.setStandardMedicantInfo(StandardClientConvert.getStandardMedicantBO(medicant));
                }
            }
            return bo;
        }).collect(Collectors.toList());
    }

    @Override
    public Map<String, StandardMedicantDrugRelBO> getMap(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>(0);
        }
        List<StandardMedicantDrugRelVO> list = standardMedicantDrugRelCacheService.getListByIds(ids);
        if (CollUtil.isEmpty(list)) {
            return new HashMap<>(0);
        }
        
        List<String> medicantIds = new ArrayList<>();
        list.forEach(i -> medicantIds.add(i.getMedicantId()));
        Map<String, StandardMedicantVO> medicantMap = standardMedicantCacheService.getMapByIds(medicantIds);

        Map<String, StandardMedicantDrugRelBO> map = new HashMap<>();
        list.forEach(i -> {
            StandardMedicantDrugRelBO bo = StandardClientConvert.getStandardMedicantDrugRelBO(i);
            if (null != bo) {
                StandardMedicantVO medicant = medicantMap.get(i.getMedicantId());
                if (null != medicant) {
                    bo.setStandardMedicantInfo(StandardClientConvert.getStandardMedicantBO(medicant));
                }
            }
            map.put(bo.getId(), bo);
        });

        return map;
    }
}
