package com.xxh.cloud.metadata.framework.modules.client.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.tree.TreeListUtils;
import com.xxh.cloud.metadata.client.api.TableClientService;
import com.xxh.cloud.metadata.client.api.bean.bos.table.TableBO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableCategoryInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.dos.TableInfo;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.metadata.framework.modules.base.service.TableCategoryInfoService;
import com.xxh.cloud.metadata.framework.modules.base.service.TableInfoService;
import com.xxh.cloud.metadata.framework.modules.cache.service.TableInfoCacheService;
import com.xxh.cloud.metadata.framework.modules.client.helper.TableClientConvert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

@Service
public class TableClientServiceImpl implements TableClientService {



    @Autowired
    private TableInfoCacheService tableInfoCacheService;
    @Autowired
    private TableInfoService tableInfoService;
    @Autowired
    private TableCategoryInfoService tableCategoryInfoService;




    @Override
    public TableBO getTable(String id) {
        if(StrUtil.isEmpty(id)){
            return null;
        }
        TableInfoVO entity= tableInfoCacheService.getById(id);
        return TableClientConvert.getTableBO(entity);
    }

    @Override
    public List<TableBO> getTableList(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>();
        }
        List<TableInfoVO> list= tableInfoCacheService.getListByIds(ids);
        if (CollUtil.isEmpty(list)) {
            return new ArrayList<>();
        }
        return list.stream().map(TableClientConvert::getTableBO).collect(Collectors.toList());
    }

    @Override
    public Map<String, TableBO> getTableMap(Collection<String> ids) {
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>();
        }
        List<TableInfoVO> list= tableInfoCacheService.getListByIds(ids);
        if (CollUtil.isEmpty(list)) {
            return new HashMap<>();
        }
        return new HashMap<>(list.stream().collect(Collectors.toMap(TableInfoVO::getId, TableClientConvert::getTableBO)));
    }


    @Override
    public List<TableBO> getTableListByCategory(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new ArrayList<>();
        }

        List<String> ids= this.getTableIdsByCategory(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>();
        }
        return this.getTableList(ids);
    }

    @Override
    public Map<String, TableBO> getTableMapByCategory(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new HashMap<>();
        }
        List<String> ids= this.getTableIdsByCategory(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>();
        }
        return this.getTableMap(ids);
    }

    @Override
    public List<TableBO> getTableListByCategory2Child(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new ArrayList<>();
        }
        List<String> ids= this.getTableIdsByCategoryChild(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new ArrayList<>();
        }
        return this.getTableList(ids);
    }

    @Override
    public Map<String, TableBO> getTableMapByCategory2Child(String categoryId) {
        if(StrUtil.isEmpty(categoryId)){
            return new HashMap<>();
        }
        List<String> ids= this.getTableIdsByCategoryChild(categoryId);
        if(CollUtil.isEmpty(ids)){
            return new HashMap<>();
        }
        return this.getTableMap(ids);
    }

    private List<String> getTableIdsByCategory(String categoryId){
        List<String> categoryIds=new ArrayList<>();
        categoryIds.add(categoryId);
        return this.getTableIdsByCategory(categoryIds);
    }

    private List<String> getTableIdsByCategory(List<String> categoryIds){
        List<String> ids=new ArrayList<>();
        if(CollUtil.isEmpty(categoryIds)){
            return ids;
        }
        List<TableInfo> list = tableInfoService.list(
                new QueryWrapper<TableInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in("category_id",categoryIds)
        );
        if(CollUtil.isEmpty(list)){
            return  ids;
        }
        list.forEach(item->{
            ids.add(item.getId());
        });
        return ids;
    }

    private List<String> getTableIdsByCategoryChild(String categoryId) {
        List<String> categoryIds=new ArrayList<>();
        List<TableCategoryInfo> list= tableCategoryInfoService.list(
                new QueryWrapper<TableCategoryInfo>()
                        .eq("rows_status", YN.YES.getCode())
        );
        if(CollUtil.isEmpty(list)){
            return  new ArrayList<>();
        }
        TreeListUtils<TableCategoryInfo> treeListUtils=new TreeListUtils<TableCategoryInfo>() {
            @Override
            public String getId(TableCategoryInfo entity) {
                return entity.getId();
            }
            @Override
            public String getPid(TableCategoryInfo entity) {
                return entity.getPid();
            }
        };
        categoryIds = treeListUtils.getTreeListIds(list,categoryId,true);
        return this.getTableIdsByCategory(categoryIds);
    }


}
