package com.xxh.cloud.metadata.framework.modules.script.sql.ddl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.xxh.cloud.framework.common.constant.DataSourceTypeEnum;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.utils.StrSqlUtils;
import com.xxh.cloud.metadata.framework.modules.script.sql.ddl.convert.DataTypeConvertFactory;
import com.xxh.cloud.metadata.framework.modules.script.sql.ddl.convert.ITypeConvert;
import com.xxh.cloud.metadata.framework.modules.script.bean.dto.EntityDDLCreatePropertyDTO;
import com.xxh.cloud.metadata.framework.modules.script.bean.vos.TableEntityPropertyVO;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class SqlDDLUtils {


    //======================================表

    /**获取库的表列表*/
    public static String getTabel2DBSQL(DataSourceTypeEnum dataSourceType, String dbName){
        return SqlDDLUtils.getTabel2DBSQL(dataSourceType.getCode(),dbName);
    }

    /**获取库的表列表*/
    public static String getTabel2DBSQL(String dataSourceType, String dbName){
        if(DataSourceTypeEnum.MySQL.getCode().equals(dataSourceType)){
            return StrUtil.format("SELECT TABLE_NAME as code ,TABLE_COMMENT as name " +
                    "FROM information_schema.tables where TABLE_SCHEMA ='{}'",dbName);
        }
        throw new BusinessException(BusinessBaseErrorEnum.DataSource_Config_ERROR);
    }



    /**
     * 表列表
     * */
    public static String getTabel2DBLikeSQL(DataSourceTypeEnum dataSourceType, String dbName,String tableName){
        return SqlDDLUtils.getTabel2DBLikeSQL(dataSourceType.getCode(),dbName,tableName);
    }

    /**
     * 表列表
     * */
    public static String getTabel2DBLikeSQL(String dataSourceType, String dbName,String tableName){
        if(DataSourceTypeEnum.MySQL.getCode().equals(dataSourceType)){
            if(StrUtil.isEmpty(tableName)){
                return StrUtil.format("SELECT TABLE_NAME as code " +
                        " ,TABLE_COMMENT as name FROM information_schema.tables " +
                        "where TABLE_SCHEMA ='{}'",dbName);
            }else {
                return StrUtil.format("SELECT TABLE_NAME as code " +
                        " ,TABLE_COMMENT as name FROM information_schema.tables " +
                        "where TABLE_SCHEMA ='{}' and  TABLE_NAME like '%{}%' ",dbName,tableName);
            }
        }
        throw new BusinessException(BusinessBaseErrorEnum.DataSource_Config_ERROR);
    }




    /**获取库的表列表*/
    public static String getTabel2DBSQL(DataSourceTypeEnum dataSourceType, String dbName,String tableName){
        return SqlDDLUtils.getTabel2DBSQL(dataSourceType.getCode(),dbName,tableName);
    }

    /**获取库的表列表*/
    public static String getTabel2DBSQL(String dataSourceType, String dbName,String tableName){
        if(DataSourceTypeEnum.MySQL.getCode().equals(dataSourceType)){
            return StrUtil.format("SELECT TABLE_NAME as code " +
                    " ,TABLE_COMMENT as name FROM information_schema.tables " +
                    "where TABLE_SCHEMA ='{}' and  TABLE_NAME='{}' ",dbName,tableName);
        }
        throw new BusinessException(BusinessBaseErrorEnum.DataSource_Config_ERROR);
    }


    //======================================表字段

    /**获取表的列列表*/
    public static String getColumn2TableSQL(DataSourceTypeEnum typeEnum, String dbName,String tableName){
        return SqlDDLUtils.getColumn2TableSQL(typeEnum.getCode(),dbName,tableName);
    }

    /**获取表的列列表*/
    public static String getColumn2TableSQL(String dataSourceType, String dbName,String tableName){
        if(DataSourceTypeEnum.MySQL.getCode().equals(dataSourceType)){
//            return StrUtil.format("select column_name as code, " +
//                    "column_comment as name,column_type as typeFull," +
//                    "data_type as type,character_maximum_length as typeSize, " +
//                    "is_nullable as isNull ,column_key as isPri,table_name as tableName  " +
//                    "from information_schema.columns " +
//                    "where table_schema ='{}' and table_name = '{}'",dbName,tableName);

            return StrUtil.format("select COLUMN_NAME  as code,  COLUMN_COMMENT   as name,COLUMN_TYPE  as typeFull," +
                    " DATA_TYPE as type,   CHARACTER_MAXIMUM_LENGTH  as typeSize, IS_NULLABLE  as isNull , " +
                    " COLUMN_KEY  as isPri,TABLE_NAME  as tableName from information_schema.columns" +
                    " where TABLE_SCHEMA ='{}' and TABLE_NAME = '{}'",dbName,tableName);

        }
        throw new BusinessException(BusinessBaseErrorEnum.DataSource_Config_ERROR);
    }


    /**获取表的列列表*/
    public static String getColumn2TableSQL(DataSourceTypeEnum dataSourceType, String dbName, Set<String> tableNames){
        return  SqlDDLUtils.getColumn2TableSQL(dataSourceType.getCode(),dbName,tableNames);
    }

    /**获取表的列列表*/
    public static String getColumn2TableSQL(String dataSourceType, String dbName, Set<String> tableNames){
        if(DataSourceTypeEnum.MySQL.getCode().equals(dataSourceType)){
            return StrUtil.format("select column_name as code, " +
                    "column_comment as name,column_type as typeFull," +
                    "data_type as type,character_maximum_length as typeSize, " +
                    "is_nullable as isNull ,column_key as isPri,table_name as tableName " +
                    "from information_schema.columns " +
                    "where table_schema ='{}' and table_name in {}",dbName, StrSqlUtils.in(tableNames));

        }
        throw new BusinessException(BusinessBaseErrorEnum.DataSource_Config_ERROR);
    }


    //======================================create table

    /**生成建表语句*/
    public static String createTableSQL(DataSourceTypeEnum dataSourceType,
                                        String tableCode,
                                        String tableName,
                                        List<EntityDDLCreatePropertyDTO> props){
        ITypeConvert dbTypeConvert= DataTypeConvertFactory.getConvertTypeFactory(dataSourceType);

        Set<String> priKeys=new HashSet<>();
        StringBuilder sqlBody=new StringBuilder();
        for(EntityDDLCreatePropertyDTO prop:props){
            sqlBody.append(SqlDDLUtils.getColumnSQL(dbTypeConvert,prop,priKeys));
        }

        sqlBody.append(SqlDDLUtils.getCommonColumnSQL(dbTypeConvert,priKeys));


        String _sqlBody;
        if(sqlBody.toString().trim().endsWith(",")){
            int endIdx= sqlBody.toString().lastIndexOf(",");
            _sqlBody=sqlBody.toString().substring(0,endIdx);
        }else{
            _sqlBody=sqlBody.toString();
        }

        return StrUtil.format("CREATE TABLE {} ( {} ) COMMENT = '{}';",tableCode,_sqlBody,tableName);
    }

    private static String getColumnSQL(ITypeConvert typeConvert, EntityDDLCreatePropertyDTO prop, Set<String> priKeys){
        String dbType= typeConvert.getDataType(prop.getDataType(),prop.getDataTypeSize());
        String name;
        if(StrUtil.isNotEmpty(prop.getName())){
            name=prop.getName();
        }else{
            name=prop.getCode();
        }
        if(StrUtil.isNotEmpty(prop.getPriKey()) && YN.YES.getCode().equals(prop.getPriKey())){
            priKeys.add(prop.getCode());
            return StrUtil.format(" {} {} NOT NULL   COMMENT '{}' , ",prop.getCode(),dbType,name);
        }else {
            return StrUtil.format(" {} {}  COMMENT '{}' , ",prop.getCode(),dbType,name);
        }
    }

    private static String getCommonColumnSQL(ITypeConvert typeConvert,Set<String> priKeys){
        StringBuilder sql=new StringBuilder();
        if(priKeys.size()>0){
            if(StrUtil.isNotEmpty(sql.toString())){
                sql.append(" , ");
            }
            sql.append(StrUtil.format("  PRIMARY KEY ({})", CollUtil.join(priKeys,",")));
        }

        return sql.toString();
    }


    //======================================alter table

    public static String alterTableSQL(DataSourceTypeEnum dataSourceType,
                                       String tableName,
                                       EntityDDLCreatePropertyDTO modelProp,
                                       TableEntityPropertyVO tableProp){

        ITypeConvert typeConvert=DataTypeConvertFactory.getConvertTypeFactory(dataSourceType);

        if(tableProp==null){
            return StrUtil.format("ALTER TABLE {} ADD COLUMN {} {}  COMMENT '{}';",
                    tableName,
                    modelProp.getCode(),
                    typeConvert.getDataType(modelProp.getDataType(),modelProp.getDataTypeSize()),
                    modelProp.getName()
            );
        }else{
            return StrUtil.format("ALTER TABLE {} CHANGE {}  {} {}  COMMENT '{}';",
                    tableName,
                    tableProp.getCode(),
                    modelProp.getCode(),
                    typeConvert.getDataType(modelProp.getDataType(),modelProp.getDataTypeSize()),
                    modelProp.getName()

            );
        }
    }

    //======================================drop table

    public static String dropTableSQL(String tableCode){
        return StrUtil.format("drop table if exists {};",tableCode);
    }


    public static String truncateTableDataSQL(String tableCode){
        return StrUtil.format("truncate table {};",tableCode);
    }


}
