package com.xxh.cloud.metadata.framework.modules.script.sql.operate;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.InsertColumnBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.script.SqlConvertByType;

import java.util.List;
import java.util.Map;

public class InsertBatchSqlWrapper implements ISqlWrapper{

    private List<InsertColumnBean> insertCol;

    private String tableName;

    private List<Map<String,String>> insertVal;

    public InsertBatchSqlWrapper tableName(String tableName){
        this.tableName=tableName;
        return this;
    }

    public InsertBatchSqlWrapper insertCol(List<InsertColumnBean> insertCol){
        this.insertCol=insertCol;
        return this;
    }

    public InsertBatchSqlWrapper insertVal(List<Map<String,String>> insertVal){
        this.insertVal=insertVal;
        return this;
    }



    private void check() throws BusinessException {
        if(StrUtil.isEmpty(this.tableName)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"SQL错误:表名不能为空");
        }
        if(CollUtil.isEmpty(this.insertCol)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"SQL错误:insert字段不能为空");
        }
        if(CollUtil.isEmpty(this.insertVal)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"SQL错误:insert值不能为空");
        }
        if(this.insertVal.size()>1000){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"SQL错误:批量新增数据最大1000条");
        }
    }


    @Override
    public String getSqlSegment() {
        this.check();
        boolean isOne=true;
        StringBuilder cols=new StringBuilder();
        for(InsertColumnBean entity:this.insertCol){
            if(isOne){
                isOne=false;
            }else {
                cols.append(" , ");
            }
            cols.append(entity.getP());
        }

        StringBuilder sql=new StringBuilder();
        sql.append("INSERT INTO ").append(this.tableName);
        sql.append(" ( ").append(cols.toString()).append(" ) ");
        sql.append(" VALUES ");

        boolean isValOne=true;
        for(Map<String,String> val:this.insertVal){
            String _val=this.getSqlOneVal(val);
            if(StrUtil.isNotEmpty(_val)){
                if(isValOne){
                    isValOne=false;
                }else {
                    sql.append(" , ");
                }
                sql.append(_val);
            }
        }
        return  sql.toString();
    }


    private String getSqlOneVal(Map<String,String> val){
        boolean isValAllNull=false;
        boolean isOne=true;
        StringBuilder vals=new StringBuilder();
        vals.append("(");
        for(InsertColumnBean entity:this.insertCol){
            if(isOne){
                isOne=false;
            }else {
                vals.append(" , ");
            }

            String v=val.get(entity.getP());
            if(StrUtil.isNotEmpty(v)){
                isValAllNull=true;
                vals.append(SqlConvertByType.convert(entity.getT(),v));
            }else {
                vals.append("null");
            }

        }
        vals.append(")");

        return isValAllNull?vals.toString():null;
    }

}
