package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptBizRelQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptBizRelSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptBizRelUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDeptBizRelVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDeptBizRelBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDeptBizRel;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardDeptConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDeptBizRelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardDeptBizRelBizServiceImpl implements StandardDeptBizRelBizService {

    @Autowired
    private StandardDeptBizRelService standardDeptBizRelService;

    @Override
    public List<StandardDeptBizRelVO> list(StandardDeptBizRelQueryDTO params) {
        ValidatorUtils.validateEntity(params);

        List<StandardDeptBizRel> list = standardDeptBizRelService.list(new QueryWrapper<StandardDeptBizRel>()
                .eq("rows_status",YN.YES.getCode())
                .eq(StrUtil.isNotBlank(params.getProjectCode()), "project_code", params.getProjectCode())
                .eq(StrUtil.isNotBlank(params.getDeptId()),"dept_id",params.getDeptId())
                .in(CollUtil.isNotEmpty(params.getDeptIds()),"dept_id",params.getDeptIds())
        );

        List<StandardDeptBizRelVO> data = new ArrayList<>();

        if(CollUtil.isNotEmpty(list)){
            list.forEach(item -> data.add(StandardDeptConvert.getStandardDeptBizRelVO(item)));
        }

        return data;
    }

    @Override
    public void save(StandardDeptBizRelSaveDTO params) {
        ValidatorUtils.validateEntity(params);

        // 清除部门关系
        standardDeptBizRelService.remove(new QueryWrapper<StandardDeptBizRel>()
            .eq("dept_id", params.getDeptId())
            .eq(StrUtil.isNotBlank(params.getProjectCode()), "project_code", params.getProjectCode())
        );

        if (CollUtil.isEmpty(params.getBizDeptIds())) {
            return;
        }

        // 添加部门关系
        List<StandardDeptBizRel> list = new ArrayList<>();
        params.getBizDeptIds().forEach(i -> {
            StandardDeptBizRel entity = new StandardDeptBizRel();
            entity.setId(IdUtil.getSnowflake(1,14).nextIdStr());
            entity.setDeptId(params.getDeptId());
            entity.setBizDeptId(i);
            entity.setProjectCode(params.getProjectCode());
            entity.setRowsStatus(YN.YES.getCode());
            list.add(entity);
        });

        standardDeptBizRelService.saveBatch(list);
    }

    @Override
    public void update(StandardDeptBizRelUpdateDTO params) {
        ValidatorUtils.validateEntity(params);

        // 清除部门关系
        StandardDeptBizRel exist = standardDeptBizRelService.getById(params.getId());
        if (null == exist || !YN.YES.getCode().equals(exist.getRowsStatus())) {
            return;
        }

        exist.setProjectCode(StrUtil.isNotBlank(params.getProjectCode()) ? params.getProjectCode() : null);
        exist.setDeptId(StrUtil.isNotBlank(params.getDeptId()) ? params.getDeptId() : null);
        exist.setBizDeptId(StrUtil.isNotBlank(params.getBizDeptId()) ? params.getBizDeptId() : null);

        standardDeptBizRelService.updateById(exist);
    }

}
