package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.tree.TreeUtils;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptBizRelQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptBizRelSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptGetDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardDeptUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.ro.StandardSysDeptRO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDeptBizRelVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDeptVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDeptBizRelBizService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDeptBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDeptInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardDeptConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDeptInfoService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.mapper.StandardSysDeptQueryMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
public class StandardDeptBizServiceImpl implements StandardDeptBizService {

    @Autowired
    private StandardDeptInfoService standardDeptInfoService;

    @Autowired
    private StandardSysDeptQueryMapper standardSysDeptQueryMapper;

    @Autowired
    private StandardDeptBizRelBizService standardDeptBizRelBizService;

    @Override
    public IPage<StandardDeptInfo> queryStandardDept(StandardDeptQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardDeptInfo> page = standardDeptInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDeptInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .orderByDesc("pid","id")
        );
        return page;
    }

    @Override
    public PageData<StandardDeptVO> query(StandardDeptQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardDeptInfo> page = standardDeptInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDeptInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .orderByDesc("pid","id")
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardDeptVO> data= new PageConverter<StandardDeptInfo, StandardDeptVO>() {
            @Override
            public StandardDeptVO converter(StandardDeptInfo entity) {
                return StandardDeptConvert.getStandardDeptVO(entity);
            }
        }.getPageData(page);

        return data;

    }

    @Override
    public List<StandardDeptVO> list(StandardDeptListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDeptInfo> list = standardDeptInfoService.list(new QueryWrapper<StandardDeptInfo>()
                .eq("rows_status",YN.YES.getCode())
                .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                .orderByDesc("pid","id")
        );

        List<StandardDeptVO> data=new ArrayList<>();

        if(CollUtil.isEmpty(list)){
            return data;
        }

        list.forEach(item->{
            data.add(StandardDeptConvert.getStandardDeptVO(item));
        });

        return data;
    }

    @Override
    public List<StandardDeptVO> tree(StandardDeptListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDeptInfo> list = standardDeptInfoService.list(new QueryWrapper<StandardDeptInfo>()
                .eq("rows_status",YN.YES.getCode())
                .orderByDesc("pid","id")
        );

        List<StandardDeptVO> dataList=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return dataList;
        }
        
        List<String> deptIds = new ArrayList<>();
        list.forEach(item->{
            deptIds.add(item.getId());
            dataList.add(StandardDeptConvert.getStandardDeptVO(item));
        });

        
        // 查询科室关联信息
        StandardDeptBizRelQueryDTO deptBizRelQuery = new StandardDeptBizRelQueryDTO();
        deptBizRelQuery.setDeptIds(deptIds);
        deptBizRelQuery.setProjectCode(params.getProjectCode());
        List<StandardDeptBizRelVO> deptList = standardDeptBizRelBizService.list(deptBizRelQuery);
        if (CollUtil.isNotEmpty(deptList)) {
            List<StandardSysDeptRO> relDeptList = standardSysDeptQueryMapper.sysDetpList(new QueryWrapper<StandardSysDeptRO>()
                .in("id", deptList.stream().map(StandardDeptBizRelVO::getBizDeptId).collect(Collectors.toSet()))
            );
            if (CollUtil.isNotEmpty(relDeptList)) {
                Map<String, StandardSysDeptRO> standardMap = new HashMap<>();
                relDeptList.forEach(i -> standardMap.put(i.getId(), i));

                Map<String, List<StandardSysDeptRO>> m = new HashMap<>();
                deptList.forEach(i -> {
                    StandardSysDeptRO d = standardMap.get(i.getBizDeptId());
                    if (null != d) {
                        List<StandardSysDeptRO> l = m.get(i.getDeptId());
                        if (null == l) {
                            l = new ArrayList<>();
                            m.put(i.getDeptId(), l);
                        }
                        l.add(d);
                    }
                });

                dataList.forEach(i -> i.setRelDeptList(m.get(i.getId())));
            }
        }
        
        List<StandardDeptVO> data= TreeUtils.build(dataList);
        return data;
    }




    @Override
    public List<StandardDeptVO> tree2SysDept(StandardDeptListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSysDeptRO> list= standardSysDeptQueryMapper.sysDetpList(new QueryWrapper<StandardSysDeptRO>());
        List<StandardDeptVO> dataList=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return dataList;
        }
        list.forEach(item->{
            StandardDeptVO dataItem=new StandardDeptVO();
            BeanUtil.copyProperties(item,dataItem);
            dataList.add(dataItem);
        });
        List<StandardDeptVO> data= TreeUtils.build(dataList);
        return data;
    }

    @Override
    public StandardDeptVO save(StandardDeptSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDeptInfo entity = new StandardDeptInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(1,14).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setPid(params.getPid());
        entity.setRemark(params.getRemark());
        entity.setRowsStatus(YN.YES.getCode());
        standardDeptInfoService.save(entity);
        
        // 保存科室关联信息
        if (CollUtil.isNotEmpty(params.getBizDeptIds())) {
            StandardDeptBizRelSaveDTO deptBizRelSave = new StandardDeptBizRelSaveDTO();
            deptBizRelSave.setDeptId(entity.getId());
            deptBizRelSave.setBizDeptIds(params.getBizDeptIds());
            deptBizRelSave.setProjectCode(params.getProjectCode());
            standardDeptBizRelBizService.save(deptBizRelSave);
        }
        
        return StandardDeptConvert.getStandardDeptVO(entity);
    }

    @Override
    public StandardDeptVO update(StandardDeptUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDeptInfo entity=standardDeptInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setRemark(params.getRemark());
        standardDeptInfoService.updateById(entity);
        
        // 保存科室关联信息
        if (CollUtil.isNotEmpty(params.getBizDeptIds())) {
            StandardDeptBizRelSaveDTO deptBizRelSave = new StandardDeptBizRelSaveDTO();
            deptBizRelSave.setDeptId(entity.getId());
            deptBizRelSave.setBizDeptIds(params.getBizDeptIds());
            deptBizRelSave.setProjectCode(params.getProjectCode());
            standardDeptBizRelBizService.save(deptBizRelSave);
        }
        
        return StandardDeptConvert.getStandardDeptVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDeptInfo entity=standardDeptInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardDeptInfoService.updateById(entity);
    }

    @Override
    public StandardDeptVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDeptInfo entity=standardDeptInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardDeptConvert.getStandardDeptVO(entity);
    }

    @Override
    public StandardDeptVO detail(StandardDeptGetDTO params) {
        if(StrUtil.isEmpty(params.getId())){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDeptInfo entity=standardDeptInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        StandardDeptVO vo = StandardDeptConvert.getStandardDeptVO(entity);
        
        // 查询科室关联信息
        StandardDeptBizRelQueryDTO deptBizRelQuery = new StandardDeptBizRelQueryDTO();
        deptBizRelQuery.setDeptId(params.getId());
        deptBizRelQuery.setProjectCode(params.getProjectCode());
        List<StandardDeptBizRelVO> deptList = standardDeptBizRelBizService.list(deptBizRelQuery);
        if (CollUtil.isNotEmpty(deptList)) {
            List<StandardSysDeptRO> relDeptList = standardSysDeptQueryMapper.sysDetpList(new QueryWrapper<StandardSysDeptRO>()
                .in("id", deptList.stream().map(StandardDeptBizRelVO::getBizDeptId).collect(Collectors.toSet()))
            );

            vo.setRelDeptList(relDeptList);
        }
        
        return vo;
    }






}
