package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.tree.TreeUtils;
import com.xxh.cloud.framework.common.utils.StrJoinSplitUtils;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardDiseaseCacheService;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDiseaseDiagnosisRelService;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDiseaseIcdRelService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseDiagnosisVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseFullVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseIcdVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseBizService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseRelationBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDiseaseInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardDiseaseConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDiseaseInfoService;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

@Service
public class StandardDiseaseBizServiceImpl implements StandardDiseaseBizService {


    @Autowired
    private StandardDiseaseCacheService standardDiseaseCacheService;
    @Autowired
    private StandardDiseaseInfoService standardDiseaseInfoService;

    @Autowired
    private StandardDiseaseIcdRelService standardDiseaseIcdRelService;
    @Autowired
    private StandardDiseaseDiagnosisRelService standardDiseaseDiagnosisRelService;

    @Autowired
    private StandardDiseaseRelationBizService standardDiseaseRelationBizService;


    @Autowired
    private AdminUserClientService adminUserClientService;


    @Override
    public PageData<StandardDiseaseVO> query(StandardDiseaseQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardDiseaseInfo> page = standardDiseaseInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDiseaseInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getSystemId()),"system_id",params.getSystemId())
                        .eq(StrUtil.isNotEmpty(params.getIcd10Code()),"icd10_code",params.getIcd10Code())
                        .eq(StrUtil.isNotEmpty(params.getPid()),"pid",params.getPid())
                        .eq(StrUtil.isNotEmpty(params.getShowStatus()),"show_status",params.getShowStatus())
                        .eq(StrUtil.isNotEmpty(params.getOneStatus()),"one_status",params.getOneStatus())
                        .eq(StrUtil.isNotEmpty(params.getTwoStatus()),"two_status",params.getTwoStatus())

                        .eq(StrUtil.isNotEmpty(params.getDiseaseType()),"disease_type",params.getDiseaseType())
                        .eq(StrUtil.isNotEmpty(params.getOperationYn()),"operation_yn",params.getOperationYn())
                        .eq(StrUtil.isNotEmpty(params.getInHospitalYn()),"in_hospital_yn",params.getInHospitalYn())
                        .eq(StrUtil.isNotEmpty(params.getFollowUpYn()),"follow_up_yn",params.getFollowUpYn())

                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                    i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                                        .or().like("en_name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                        )

        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        Set<String> userIds=new HashSet<>();
        Set<String> systemIds=new HashSet<>();
        Set<String> typeIds=new HashSet<>();
        Set<String> ids=new HashSet<>();

        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getSystemId())){
                systemIds.add(item.getSystemId());
            }
            if(StrUtil.isNotEmpty(item.getType())){
                List<String> _ids=StrJoinSplitUtils.split2List(item.getType());
                typeIds.addAll(_ids);
            }
            ids.add(item.getId());
        });


        Map<String,Integer> childIdNumMap=new HashMap<>();

        if(StrUtil.isNotEmpty(params.getIsShowChildFlag()) && YN.YES.getCode().equals(params.getIsShowChildFlag())){
            List<Map<String, Object>> mapList= standardDiseaseInfoService.listMaps(
                    new QueryWrapper<StandardDiseaseInfo>()
                            .select("pid ","count(1) as num")
                            .eq("rows_status",YN.YES.getCode())
                            .in("pid",ids)
                            .groupBy("pid")
            );
            if(CollUtil.isNotEmpty(mapList)){
                mapList.forEach(item->{
                    String id = Convert.toStr(item.get("pid"));
                    Integer num= Convert.toInt(item.get("num"));
                    childIdNumMap.put(id,num);
                });
            }
        }

        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardDiseaseVO> data= new PageConverter<StandardDiseaseInfo, StandardDiseaseVO>() {
            @Override
            public StandardDiseaseVO converter(StandardDiseaseInfo entity) {
                return StandardDiseaseConvert.getStandardDiseaseVO(entity,childIdNumMap, userMap);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public IPage<StandardDiseaseInfo> queryStandardDisease(StandardDiseaseQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardDiseaseInfo> page = standardDiseaseInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDiseaseInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getSystemId()),"system_id",params.getSystemId())
                        .eq(StrUtil.isNotEmpty(params.getIcd10Code()),"icd10_code",params.getIcd10Code())
                        .eq(StrUtil.isNotEmpty(params.getPid()),"pid",params.getPid())

                        .eq(StrUtil.isNotEmpty(params.getShowStatus()),"show_status",params.getShowStatus())
                        .eq(StrUtil.isNotEmpty(params.getOneStatus()),"one_status",params.getOneStatus())
                        .eq(StrUtil.isNotEmpty(params.getTwoStatus()),"two_status",params.getTwoStatus())

                        .eq(StrUtil.isNotEmpty(params.getDiseaseType()),"disease_type",params.getDiseaseType())
                        .eq(StrUtil.isNotEmpty(params.getOperationYn()),"operation_yn",params.getOperationYn())
                        .eq(StrUtil.isNotEmpty(params.getInHospitalYn()),"in_hospital_yn",params.getInHospitalYn())
                        .eq(StrUtil.isNotEmpty(params.getFollowUpYn()),"follow_up_yn",params.getFollowUpYn())

                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                                        .or().like("en_name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                        )

        );






        return page;
    }

    @Override
    public List<StandardDiseaseVO> list(StandardDiseaseListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseInfo> list = standardDiseaseInfoService.list(new QueryWrapper<StandardDiseaseInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getSystemId()),"system_id",params.getSystemId())
                        .eq(StrUtil.isNotEmpty(params.getIcd10Code()),"icd10_code",params.getIcd10Code())
                        .eq(StrUtil.isNotEmpty(params.getPid()),"pid",params.getPid())

                        .eq(StrUtil.isNotEmpty(params.getShowStatus()),"show_status",params.getShowStatus())
                        .eq(StrUtil.isNotEmpty(params.getOneStatus()),"one_status",params.getOneStatus())
                        .eq(StrUtil.isNotEmpty(params.getTwoStatus()),"two_status",params.getTwoStatus())

                        .eq(StrUtil.isNotEmpty(params.getDiseaseType()),"disease_type",params.getDiseaseType())
                        .eq(StrUtil.isNotEmpty(params.getOperationYn()),"operation_yn",params.getOperationYn())
                        .eq(StrUtil.isNotEmpty(params.getInHospitalYn()),"in_hospital_yn",params.getInHospitalYn())
                        .eq(StrUtil.isNotEmpty(params.getFollowUpYn()),"follow_up_yn",params.getFollowUpYn())

                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                                        .or().like("en_name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                        )

        );
        List<StandardDiseaseVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }

        Set<String> userIds=new HashSet<>();
        Set<String> systemIds=new HashSet<>();
        Set<String> typeIds=new HashSet<>();
        Set<String> ids=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getSystemId())){
                systemIds.add(item.getSystemId());
            }
            if(StrUtil.isNotEmpty(item.getType())){
                List<String> _ids=StrJoinSplitUtils.split2List(item.getType());
                typeIds.addAll(_ids);
            }
            ids.add(item.getId());
        });


        Map<String,Integer> childIdNumMap=new HashMap<>();
        if(StrUtil.isNotEmpty(params.getIsShowChildFlag()) && YN.YES.getCode().equals(params.getIsShowChildFlag())){
            List<Map<String, Object>> mapList= standardDiseaseInfoService.listMaps(
                    new QueryWrapper<StandardDiseaseInfo>()
                            .select("pid ","count(1) as num")
                            .eq("rows_status",YN.YES.getCode())
                            .in("pid",ids)
                            .groupBy("pid")
            );
            if(CollUtil.isNotEmpty(mapList)){
                mapList.forEach(item->{
                    String id = Convert.toStr(item.get("pid"));
                    Integer num= Convert.toInt(item.get("num"));
                    childIdNumMap.put(id,num);
                });
            }
        }

        System.out.println("==================");
        list.forEach(item->{
            data.add(StandardDiseaseConvert.getStandardDiseaseVO(item,childIdNumMap, null));
        });
        return data;
    }

    @Override
    public List<StandardDiseaseVO> tree(StandardDiseaseTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseInfo> list = standardDiseaseInfoService.list(new QueryWrapper<StandardDiseaseInfo>()
                .eq("rows_status",YN.YES.getCode())
                .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())

        );
        List<StandardDiseaseVO> dataList=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return dataList;
        }

        //
        Set<String> userIds=new HashSet<>();
        Set<String> systemIds=new HashSet<>();
        Set<String> typeIds=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getSystemId())){
                systemIds.add(item.getSystemId());
            }
            if(StrUtil.isNotEmpty(item.getType())){
                List<String> _ids=StrJoinSplitUtils.split2List(item.getType());
                typeIds.addAll(_ids);
            }
        });



        list.forEach(item->{
            dataList.add(StandardDiseaseConvert.getStandardDiseaseVO(item));
        });
        List<StandardDiseaseVO> data= TreeUtils.build(dataList);
        return data;
    }

    @Override
    public StandardDiseaseVO save(StandardDiseaseSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseInfo entity=new StandardDiseaseInfo();

        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            if(StrUtil.isNotEmpty(params.getIcd10Code())){
                entity.setId(params.getIcd10Code());
            }else {
                entity.setId(IdUtil.getSnowflake(2,1).nextIdStr());
            }
        }
        entity.setType(StrJoinSplitUtils.join(params.getType()));
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setIcd10Code(params.getIcd10Code());
        entity.setEnName(params.getEnName());
        entity.setAbbrName(params.getAbbrName());
        entity.setPid(params.getPid());
        entity.setSystemId(params.getSystemId());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        entity.setShowStatus(params.getShowStatus());
        entity.setOneStatus(params.getOneStatus());
        entity.setTwoStatus(params.getTwoStatus());

        entity.setDiseaseType(params.getDiseaseType());
        entity.setInHospitalYn(params.getInHospitalYn());
        entity.setFollowUpYn(params.getFollowUpYn());
        entity.setOperationYn(params.getOperationYn());

        standardDiseaseInfoService.save(entity);

        Map<String, Object> logContent= BeanUtil.beanToMap(entity);
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata,
                ObjectTypeEnum.OT_Disease,entity.getId(), logContent);

        return StandardDiseaseConvert.getStandardDiseaseVO(entity);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public StandardDiseaseVO saveFull(StandardDiseaseSaveFullDTO params) {
        ValidatorUtils.validateEntity(params);

        // disease
        StandardDiseaseVO vo = this.save(params.getDiseaseInfo());

        if (null != vo) {
            // diagnosis关联明细
            if (CollUtil.isNotEmpty(params.getDiagnosisAddList())) {
                params.getDiagnosisAddList().forEach(i -> {
                    i.setDiseaseId(vo.getId());
                    i.setProjectCode(vo.getProjectCode());
                });
                StandardDiseaseDiagnosisAddBatchDTO standardDiseaseDiagnosisAddBatchDTO = new StandardDiseaseDiagnosisAddBatchDTO();
                standardDiseaseDiagnosisAddBatchDTO.setItems(params.getDiagnosisAddList());
                standardDiseaseRelationBizService.addBatchRelDiagnosis(standardDiseaseDiagnosisAddBatchDTO);
            }

            // icd关联明细
            if (CollUtil.isNotEmpty(params.getIcdAddList())) {
                params.getIcdAddList().forEach(i -> {
                    i.setDiseaseId(vo.getId());
                    i.setProjectCode(vo.getProjectCode());
                });
                StandardDiseaseIcdAddBatchDTO standardDiseaseIcdAddBatchDTO = new StandardDiseaseIcdAddBatchDTO();
                standardDiseaseIcdAddBatchDTO.setItems(params.getIcdAddList());
                standardDiseaseRelationBizService.addBatchRelIdc(standardDiseaseIcdAddBatchDTO);
            }
        }

        return vo;
    }

    @Override
    public StandardDiseaseVO update(StandardDiseaseUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseInfo entity=standardDiseaseInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        entity.setType(StrJoinSplitUtils.join(params.getType()));
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setIcd10Code(params.getIcd10Code());
        entity.setEnName(params.getEnName());
        entity.setAbbrName(params.getAbbrName());
        entity.setSystemId(params.getSystemId());
        entity.setRemark(params.getRemark());
        entity.setShowStatus(params.getShowStatus());
        entity.setOneStatus(params.getOneStatus());
        entity.setTwoStatus(params.getTwoStatus());

        entity.setDiseaseType(params.getDiseaseType());
        entity.setInHospitalYn(params.getInHospitalYn());
        entity.setFollowUpYn(params.getFollowUpYn());
        entity.setOperationYn(params.getOperationYn());


        standardDiseaseInfoService.updateById(entity);

        standardDiseaseCacheService.removeById(entity.getId());

        Map<String, Object> logContent= BeanUtil.beanToMap(entity);
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata,
                ObjectTypeEnum.OT_Disease,entity.getId(), logContent);

        return StandardDiseaseConvert.getStandardDiseaseVO(entity);
    }

    @Override
    public StandardDiseaseVO updateFull(StandardDiseaseUpdateFullDTO params) {
        ValidatorUtils.validateEntity(params);

        StandardDiseaseVO vo = this.update(params.getDiseaseInfo());
        if (null != vo) {
            // diagnosis关联明细
            if (CollUtil.isNotEmpty(params.getDiagnosisUpdateList())) {
                params.getDiagnosisUpdateList().forEach(i -> {
                    i.setDiseaseId(vo.getId());
                    i.setProjectCode(vo.getProjectCode());
                });
                standardDiseaseRelationBizService.updateBatchRelDiagnosisByDisease(params.getDiagnosisUpdateList());
            }

            // icd关联明细
            if (CollUtil.isNotEmpty(params.getIcdUpdateList())) {
                params.getIcdUpdateList().forEach(i -> {
                    i.setDiseaseId(vo.getId());
                    i.setProjectCode(vo.getProjectCode());
                });
                standardDiseaseRelationBizService.updateBatchRelIdcByDisease(params.getIcdUpdateList());
            }
        }

        return vo;
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseInfo entity=standardDiseaseInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        long num= standardDiseaseInfoService.count(new QueryWrapper<StandardDiseaseInfo>()
                .eq("pid",entity.getId()));
        if(num>0){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardDiseaseInfoService.updateById(entity);

        standardDiseaseCacheService.removeById(id);

        //todo:删除关联

        Map<String, Object> logContent= BeanUtil.beanToMap(entity);
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata,
                ObjectTypeEnum.OT_Disease,entity.getId(), logContent);

    }

    @Override
    public StandardDiseaseVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseInfo entity=standardDiseaseInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        //todo:
        Set<String> userIds=new HashSet<>();
        Set<String> systemIds=new HashSet<>();
        Set<String> typeIds=new HashSet<>();
        if(StrUtil.isNotEmpty(entity.getCreator())){
            userIds.add(entity.getCreator());
        }
        if(StrUtil.isNotEmpty(entity.getUpdater())){
            userIds.add(entity.getUpdater());
        }
        if(StrUtil.isNotEmpty(entity.getSystemId())){
            systemIds.add(entity.getSystemId());
        }
        if(StrUtil.isNotEmpty(entity.getType())){
            typeIds.addAll(StrJoinSplitUtils.split2Set(entity.getType()));
        }

        return StandardDiseaseConvert.getStandardDiseaseVO(entity);
    }

    @Override
    public StandardDiseaseFullVO getFullById(String id) {
        StandardDiseaseVO vo = this.getById(id);
        if (null == vo) {
            return null;
        }
        
        StandardDiseaseIcdListDTO standardDiseaseIcdListDTO = new StandardDiseaseIcdListDTO();
        standardDiseaseIcdListDTO.setDiseaseId(vo.getId());
        standardDiseaseIcdListDTO.setProjectCode(vo.getProjectCode());
        List<StandardDiseaseIcdVO> standardDiseaseIcdList = standardDiseaseRelationBizService.listRelIdc(standardDiseaseIcdListDTO);

        StandardDiseaseDiagnosisListDTO standardDiseaseDiagnosisListDTO = new StandardDiseaseDiagnosisListDTO();
        standardDiseaseDiagnosisListDTO.setDiseaseId(vo.getId());
        standardDiseaseDiagnosisListDTO.setProjectCode(vo.getProjectCode());
        List<StandardDiseaseDiagnosisVO> standardDiseaseDiagnosisList = standardDiseaseRelationBizService.listRelDiagnosis(standardDiseaseDiagnosisListDTO);

        return StandardDiseaseConvert.getStandardDiseaseFullVO(vo, standardDiseaseIcdList, standardDiseaseDiagnosisList);
    }
}
