package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.utils.StrJoinSplitUtils;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardDiseaseCacheService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDiseaseDiagnosisRel;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDiseaseIcdRel;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDiseaseInfo;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDiseaseDiagnosisRelService;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDiseaseIcdRelService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseDiagnosisVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseIcdVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseRelationBizService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardDiseaseConvert;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardDiseaseDiagnosisConvert;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardDiseaseRelationBizServiceImpl implements StandardDiseaseRelationBizService {

    @Autowired
    private StandardDiseaseDiagnosisRelService standardDiseaseDiagnosisRelService;

    @Autowired
    private StandardDiseaseIcdRelService standardDiseaseIcdRelService;

    @Autowired
    private StandardDiseaseCacheService standardDiseaseCacheService;

    @Autowired
    private AdminUserClientService adminUserClientService;



    @Override
    public PageData<StandardDiseaseDiagnosisVO> queryRelDiagnosis(StandardDiseaseDiagnosisPageDTO params) {
        ValidatorUtils.validateEntity(params);

        IPage<StandardDiseaseDiagnosisRel> page = standardDiseaseDiagnosisRelService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDiseaseDiagnosisRel>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getDiseaseId()),"disease_id",params.getDiseaseId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getObjType()),"obj_type",params.getObjType())
                        .like(StrUtil.isNotEmpty(params.getObjName()),"obj_name",params.getObjName())
                        .eq(StrUtil.isNotEmpty(params.getObjId()),"obj_id",params.getObjId())
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return new PageData<>(null, 0);
        }


        Set<String> userIds=new HashSet<>();
        Set<String> diseaseIds =new HashSet<>();

        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getDiseaseId())){
                diseaseIds.add(item.getDiseaseId());
            }
        });


        Map<String,StandardDiseaseVO> diseaseMap= standardDiseaseCacheService.getMapByIds(diseaseIds);
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardDiseaseDiagnosisVO> data= new PageConverter<StandardDiseaseDiagnosisRel, StandardDiseaseDiagnosisVO>() {
            @Override
            public StandardDiseaseDiagnosisVO converter(StandardDiseaseDiagnosisRel entity) {
                return  StandardDiseaseDiagnosisConvert.getStandardDiseaseDiagnosisVO(entity,diseaseMap,userMap);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardDiseaseDiagnosisVO> listRelDiagnosis(StandardDiseaseDiagnosisListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseDiagnosisRel> list=standardDiseaseDiagnosisRelService.list(
                new QueryWrapper<StandardDiseaseDiagnosisRel>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getDiseaseId()),"disease_id",params.getDiseaseId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getObjType()),"obj_type",params.getObjType())
                        .like(StrUtil.isNotEmpty(params.getObjName()),"obj_name",params.getObjName())
                        .eq(StrUtil.isNotEmpty(params.getObjId()),"obj_id",params.getObjId())

        );

        List<StandardDiseaseDiagnosisVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }

        Set<String> userIds=new HashSet<>();
        Set<String> diseaseIds =new HashSet<>();

        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getDiseaseId())){
                diseaseIds.add(item.getDiseaseId());
            }
        });

        Map<String,StandardDiseaseVO> diseaseMap= standardDiseaseCacheService.getMapByIds(diseaseIds);
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        list.forEach(item->{
            data.add(StandardDiseaseDiagnosisConvert.getStandardDiseaseDiagnosisVO(item,diseaseMap,userMap));
        });
        return data;
    }

    @Override
    public void addRelDiagnosis(StandardDiseaseDiagnosisAddDTO params) {
        ValidatorUtils.validateEntity(params);

        long num = standardDiseaseDiagnosisRelService.count(new QueryWrapper<StandardDiseaseDiagnosisRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq("disease_id",params.getDiseaseId())
                        .eq("obj_type",params.getObjType())
                        .eq("obj_id",params.getObjId())
                        .eq("project_code", params.getProjectCode())
        );

        if(num > 0){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_EXISTS,"关联已存在");
        }

        StandardDiseaseDiagnosisRel entity=new StandardDiseaseDiagnosisRel();
        entity.setId(IdUtil.getSnowflake(5,1).nextIdStr());
        entity.setDiseaseId(params.getDiseaseId());
        entity.setObjType(params.getObjType());
        entity.setObjName(params.getObjName());
        entity.setObjId(params.getObjId());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardDiseaseDiagnosisRelService.save(entity);
    }

    @Override
    public void addBatchRelDiagnosis(StandardDiseaseDiagnosisAddBatchDTO params) {
        ValidatorUtils.validateEntity(params);

        List<StandardDiseaseDiagnosisRel> entityList=new ArrayList<>();

        for(StandardDiseaseDiagnosisAddBatchItem item : params.getItems()) {
            long num = standardDiseaseDiagnosisRelService.count(new QueryWrapper<StandardDiseaseDiagnosisRel>()
                    .eq("rows_status",YN.YES.getCode())
                    .eq("disease_id",item.getDiseaseId())
                    .eq("obj_type",item.getObjType())
                    .eq("obj_id",item.getObjId())
                    .eq("project_code", item.getProjectCode())
            );                          
            if(num > 0){
                continue;
            }

            StandardDiseaseDiagnosisRel entity=new StandardDiseaseDiagnosisRel();
            entity.setId(IdUtil.getSnowflake(5,1).nextIdStr());
            entity.setDiseaseId(item.getDiseaseId());
            entity.setObjType(item.getObjType());
            entity.setObjName(item.getObjName());
            entity.setObjId(item.getObjId());
            entity.setRemark(item.getRemark());
            entity.setProjectCode(item.getProjectCode());
            entity.setRowsStatus(YN.YES.getCode());
            entityList.add(entity);
        }

        if (CollUtil.isNotEmpty(entityList)) {
            standardDiseaseDiagnosisRelService.saveBatch(entityList);
        }
    }

    @Override
    public void delRelDiagnosisById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseDiagnosisRel entity = standardDiseaseDiagnosisRelService.getOne(new QueryWrapper<StandardDiseaseDiagnosisRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq("id",id)
        );
        if (null == entity) {
            return;
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardDiseaseDiagnosisRelService.updateById(entity);
    }

    @Override
    public void delRelDiagnosisByIds(List<String> ids) {
        if(CollUtil.isEmpty(ids)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        List<StandardDiseaseDiagnosisRel> list = standardDiseaseDiagnosisRelService.list(new QueryWrapper<StandardDiseaseDiagnosisRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .in("id",ids)
        );
        if(CollUtil.isEmpty(list)){
            return;
        }
        list.forEach(item-> item.setRowsStatus(YN.NO.getCode()));
        standardDiseaseDiagnosisRelService.updateBatchById(list);
    }

    @Override
    public StandardDiseaseDiagnosisVO getRelDiagnosisById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseDiagnosisRel entity = standardDiseaseDiagnosisRelService.getOne(new QueryWrapper<StandardDiseaseDiagnosisRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq("id",id)
        );
        if (null == entity) {
            return null;
        }

        StandardDiseaseDiagnosisVO vo = StandardDiseaseDiagnosisConvert.getStandardDiseaseDiagnosisVO(entity);
        
        Set<String> userIds = new HashSet<>();
        if (StrUtil.isNotEmpty(vo.getCreator())){
            userIds.add(vo.getCreator());
        }
        if (StrUtil.isNotEmpty(vo.getUpdater())){
            userIds.add(vo.getUpdater());
        }
        if (CollUtil.isNotEmpty(userIds)) {
            Map<String, AdminUserBO> userMap = adminUserClientService.getUserMapByIds(userIds);
            if (CollUtil.isNotEmpty(userMap)) {
                AdminUserBO creatorName = userMap.get(vo.getCreator());
                AdminUserBO updaterName = userMap.get(vo.getUpdater());

                if (null != creatorName) {
                    vo.setCreatorName(creatorName.getRealName());
                }
                if (null != updaterName) {
                    vo.setUpdaterName(updaterName.getRealName());
                }
            }
        }
        if (StrUtil.isNotBlank(vo.getDiseaseId())) {
            StandardDiseaseVO disease = standardDiseaseCacheService.getById(vo.getDiseaseId());
            vo.setStandardDiseaseInfo(disease);
        }

        return vo;
    }

    @Override
    public void updateBatchRelDiagnosisByDisease(List<StandardDiseaseDiagnosisUpdateDTO> params) {
        if (CollUtil.isEmpty(params)) {
            return;
        }
        params.forEach(i -> {
            ValidatorUtils.validateEntity(i);
        });

        List<StandardDiseaseDiagnosisRel> entityList = new ArrayList<>();
        params.forEach(i -> {
            StandardDiseaseDiagnosisRel entity = standardDiseaseDiagnosisRelService.getOne(new QueryWrapper<StandardDiseaseDiagnosisRel>()
                    .eq("rows_status",YN.YES.getCode())
                    .eq("project_code", i.getProjectCode())
                    .eq("disease_id",i.getDiseaseId())
                    .eq("obj_type",i.getObjType())
                    .eq("obj_id",i.getObjId())
            );
            if(null == entity){
                return;
            }
            entity.setObjName(i.getObjName());
            entity.setRemark(i.getRemark());

            entityList.add(entity);
        });

        if (CollUtil.isNotEmpty(entityList)) {
            standardDiseaseDiagnosisRelService.updateBatchById(entityList);
        }
    }


    //=========================================================================================


    @Override
    public PageData<StandardDiseaseIcdVO> queryRelIdc(StandardDiseaseIcdPageDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardDiseaseIcdRel> page = standardDiseaseIcdRelService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDiseaseIcdRel>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getDiseaseId()),"disease_id",params.getDiseaseId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getIcd10Code()),"icd10_code",params.getIcd10Code())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .like(StrUtil.isNotEmpty(params.getEnName()),"en_name",params.getEnName())
                        .like(StrUtil.isNotEmpty(params.getAbbrName()),"abbr_name",params.getAbbrName())
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return new PageData<>(null, 0);
        }


        Set<String> userIds=new HashSet<>();
        Set<String> diseaseIds =new HashSet<>();

        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getDiseaseId())){
                diseaseIds.add(item.getDiseaseId());
            }
        });


        Map<String,StandardDiseaseVO> diseaseMap= standardDiseaseCacheService.getMapByIds(diseaseIds);
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardDiseaseIcdVO> data= new PageConverter<StandardDiseaseIcdRel, StandardDiseaseIcdVO>() {
            @Override
            public StandardDiseaseIcdVO converter(StandardDiseaseIcdRel entity) {
                return  StandardDiseaseDiagnosisConvert.getStandardDiseaseIcdVO(entity,diseaseMap,userMap);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardDiseaseIcdVO> listRelIdc(StandardDiseaseIcdListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseIcdRel> list=standardDiseaseIcdRelService.list(new QueryWrapper<StandardDiseaseIcdRel>()
                    .eq("rows_status", YN.YES.getCode())
                    .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                    .eq(StrUtil.isNotEmpty(params.getDiseaseId()),"disease_id",params.getDiseaseId())
                    .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                    .eq(StrUtil.isNotEmpty(params.getIcd10Code()),"icd10_code",params.getIcd10Code())
                    .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                    .like(StrUtil.isNotEmpty(params.getEnName()),"en_name",params.getEnName())
                    .like(StrUtil.isNotEmpty(params.getAbbrName()),"abbr_name",params.getAbbrName())

        );

        List<StandardDiseaseIcdVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }

        Set<String> userIds=new HashSet<>();
        Set<String> diseaseIds =new HashSet<>();

        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getDiseaseId())){
                diseaseIds.add(item.getDiseaseId());
            }
        });

        Map<String,StandardDiseaseVO> diseaseMap= standardDiseaseCacheService.getMapByIds(diseaseIds);
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        list.forEach(item->{
            data.add(StandardDiseaseDiagnosisConvert.getStandardDiseaseIcdVO(item,diseaseMap,userMap));
        });
        return data;
    }

    @Override
    public void addRelIdc(StandardDiseaseIcdAddDTO params) {
        ValidatorUtils.validateEntity(params);
        long num = standardDiseaseIcdRelService.count(new QueryWrapper<StandardDiseaseIcdRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq("disease_id",params.getDiseaseId())
                        .eq("project_code",params.getProjectCode())
                        .eq("icd10_code",params.getIcd10Code())
        );
        if(num>0){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_EXISTS,"关联已存在");
        }

        StandardDiseaseIcdRel entity=new StandardDiseaseIcdRel();
        entity.setId(IdUtil.getSnowflake(5,1).nextIdStr());
        entity.setDiseaseId(params.getDiseaseId());
        entity.setIcd10Code(params.getIcd10Code());
        entity.setName(params.getName());
        entity.setEnName(params.getEnName());
        entity.setAbbrName(params.getAbbrName());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardDiseaseIcdRelService.save(entity);
    }

    @Override
    public void addBatchRelIdc(StandardDiseaseIcdAddBatchDTO params) {
        ValidatorUtils.validateEntity(params);

        List<StandardDiseaseIcdRel> entityList=new ArrayList<>();

        for(StandardDiseaseIcdAddDTO item:params.getItems()){
            long num = standardDiseaseIcdRelService.count(new QueryWrapper<StandardDiseaseIcdRel>()
                            .eq("rows_status",YN.YES.getCode())
                            .eq("disease_id",item.getDiseaseId())
                            .eq("project_code",item.getProjectCode())
                            .eq("icd10_code",item.getIcd10Code())
            );
            if(num > 0){
                continue;
            }
            StandardDiseaseIcdRel entity=new StandardDiseaseIcdRel();
            entity.setId(IdUtil.getSnowflake(5,1).nextIdStr());
            entity.setDiseaseId(item.getDiseaseId());
            entity.setIcd10Code(item.getIcd10Code());
            entity.setName(item.getName());
            entity.setEnName(item.getEnName());
            entity.setAbbrName(item.getAbbrName());
            entity.setRemark(item.getRemark());
            entity.setProjectCode(item.getProjectCode());
            entity.setRowsStatus(YN.YES.getCode());
            entityList.add(entity);
        }

        if (CollUtil.isNotEmpty(entityList)) {
            standardDiseaseIcdRelService.saveBatch(entityList);
        }
    }

    @Override
    public void delRelIdcById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseIcdRel entity = standardDiseaseIcdRelService.getOne(new QueryWrapper<StandardDiseaseIcdRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq("id",id)
        );
        if (null == entity) {
            return;
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardDiseaseIcdRelService.updateById(entity);
    }

    @Override
    public void delRelIdcByIds(List<String> ids) {
        if(CollUtil.isEmpty(ids)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        List<StandardDiseaseIcdRel> list = standardDiseaseIcdRelService.list(new QueryWrapper<StandardDiseaseIcdRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .in("id",ids)
        );
        if(CollUtil.isEmpty(list)){
            return;
        }
        list.forEach(item-> item.setRowsStatus(YN.NO.getCode()));
        standardDiseaseIcdRelService.updateBatchById(list);
    }

    @Override
    public StandardDiseaseIcdVO getRelIdcById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseIcdRel entity = standardDiseaseIcdRelService.getOne(new QueryWrapper<StandardDiseaseIcdRel>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq("id",id)
        );
        if (null == entity) {
            return null;
        }

        StandardDiseaseIcdVO vo = StandardDiseaseDiagnosisConvert.getStandardDiseaseIcdVO(entity);
        
        Set<String> userIds = new HashSet<>();
        if (StrUtil.isNotEmpty(vo.getCreator())){
            userIds.add(vo.getCreator());
        }
        if (StrUtil.isNotEmpty(vo.getUpdater())){
            userIds.add(vo.getUpdater());
        }
        if (CollUtil.isNotEmpty(userIds)) {
            Map<String, AdminUserBO> userMap = adminUserClientService.getUserMapByIds(userIds);
            if (CollUtil.isNotEmpty(userMap)) {
                AdminUserBO creatorName = userMap.get(vo.getCreator());
                AdminUserBO updaterName = userMap.get(vo.getUpdater());

                if (null != creatorName) {
                    vo.setCreatorName(creatorName.getRealName());
                }
                if (null != updaterName) {
                    vo.setUpdaterName(updaterName.getRealName());
                }
            }
        }
        if (StrUtil.isNotBlank(vo.getDiseaseId())) {
            StandardDiseaseVO disease = standardDiseaseCacheService.getById(vo.getDiseaseId());
            vo.setStandardDiseaseInfo(disease);
        }

        return vo;
    }

    @Override
    public void updateBatchRelIdcByDisease(List<StandardDiseaseIcdUpdateDTO> params) {
        if (CollUtil.isEmpty(params)) {
            return;
        }
        params.forEach(i -> {
            ValidatorUtils.validateEntity(i);
        });

        List<StandardDiseaseIcdRel> entityList = new ArrayList<>();
        params.forEach(i -> {
            StandardDiseaseIcdRel entity = standardDiseaseIcdRelService.getOne(new QueryWrapper<StandardDiseaseIcdRel>()
                    .eq("rows_status",YN.YES.getCode())
                    .eq("project_code", i.getProjectCode())
                    .eq("disease_id",i.getDiseaseId())
                    .eq("icd10_code",i.getIcd10Code())
            );
            if(null == entity){
                return;
            }
            entity.setName(i.getName());
            entity.setAbbrName(i.getAbbrName());
            entity.setEnName(i.getEnName());
            entity.setRemark(i.getRemark());

            entityList.add(entity);
        });

        if (CollUtil.isNotEmpty(entityList)) {
            standardDiseaseIcdRelService.updateBatchById(entityList);
        }
    }














}
