package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardDiseaseSystemCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSystemDiseaseListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSystemDiseaseQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSystemDiseaseSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSystemDiseaseUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseSystemVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseSystemBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardDiseaseSystemInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardDiseaseSystemConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardDiseaseSystemInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardDiseaseSystemBizServiceImpl implements StandardDiseaseSystemBizService {

    @Autowired
    private StandardDiseaseSystemInfoService standardDiseaseSystemInfoService;
    @Autowired
    private StandardDiseaseSystemCacheService standardDiseaseSystemCacheService;



    @Override
    public PageData<StandardDiseaseSystemVO> query(StandardSystemDiseaseQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardDiseaseSystemInfo> page = standardDiseaseSystemInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardDiseaseSystemInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                                        .or().like("en_name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                        )

        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }
        PageData<StandardDiseaseSystemVO> data= new PageConverter<StandardDiseaseSystemInfo, StandardDiseaseSystemVO>() {
            @Override
            public StandardDiseaseSystemVO converter(StandardDiseaseSystemInfo entity) {
                return StandardDiseaseSystemConvert.getStandardDiseaseSystemVO(entity);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public List<StandardDiseaseSystemVO> list(StandardSystemDiseaseListDTO params) {
        ValidatorUtils.validateEntity(params);

        List<StandardDiseaseSystemInfo> list = standardDiseaseSystemInfoService.list(new QueryWrapper<StandardDiseaseSystemInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                                        .or().like("en_name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                        )

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        List<StandardDiseaseSystemVO> data=new ArrayList<>();
        list.forEach(item->{
            data.add(StandardDiseaseSystemConvert.getStandardDiseaseSystemVO(item));
        });
        return data;
    }

    @Override
    public StandardDiseaseSystemVO save(StandardSystemDiseaseSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseSystemInfo entity=new StandardDiseaseSystemInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,2).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setEnName(params.getEnName());
        entity.setAbbrName(params.getAbbrName());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardDiseaseSystemInfoService.save(entity);

        Map<String, Object> logContent= BeanUtil.beanToMap(entity);
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata,
                ObjectTypeEnum.OT_DiseaseSystem,entity.getId(), logContent);

        return StandardDiseaseSystemConvert.getStandardDiseaseSystemVO(entity);
    }

    @Override
    public StandardDiseaseSystemVO update(StandardSystemDiseaseUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseSystemInfo entity=standardDiseaseSystemInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setEnName(params.getEnName());
        entity.setAbbrName(params.getAbbrName());
        entity.setRemark(params.getRemark());
        standardDiseaseSystemInfoService.updateById(entity);
        standardDiseaseSystemCacheService.removeById(entity.getId());

        Map<String, Object> logContent= BeanUtil.beanToMap(entity);
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata,
                ObjectTypeEnum.OT_DiseaseSystem,entity.getId(), logContent);

        return StandardDiseaseSystemConvert.getStandardDiseaseSystemVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseSystemInfo entity=standardDiseaseSystemInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardDiseaseSystemInfoService.updateById(entity);
        standardDiseaseSystemCacheService.removeById(id);

        Map<String, Object> logContent= BeanUtil.beanToMap(entity);
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata,
                ObjectTypeEnum.OT_DiseaseSystem,entity.getId(), logContent);

    }

    @Override
    public StandardDiseaseSystemVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardDiseaseSystemInfo entity=standardDiseaseSystemInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardDiseaseSystemConvert.getStandardDiseaseSystemVO(entity);
    }
}
