package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardEventCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardEventListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardEventQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardEventSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardEventUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardEventVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardEventBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardEventInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardEventConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardEventInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardEventBizServiceImpl implements StandardEventBizService {


    @Autowired
    private StandardEventInfoService standardEventInfoService;
    @Autowired
    private StandardEventCacheService standardEventCacheService;


    @Override
    public IPage<StandardEventInfo> queryStandardEvent(StandardEventQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardEventInfo> page = standardEventInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardEventInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getGrade()),"grade",params.getGrade())
        );
        return page;
    }

    @Override
    public PageData<StandardEventVO> query(StandardEventQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardEventInfo> page = standardEventInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardEventInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getGrade()),"grade",params.getGrade())
        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }
        PageData<StandardEventVO> data= new PageConverter<StandardEventInfo, StandardEventVO>() {
            @Override
            public StandardEventVO converter(StandardEventInfo entity) {
                return StandardEventConvert.getStandardEventVO(entity);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public List<StandardEventVO> list(StandardEventListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardEventInfo> list = standardEventInfoService.list(new QueryWrapper<StandardEventInfo>()
                .eq("rows_status",YN.YES.getCode())
                .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                .eq(StrUtil.isNotEmpty(params.getGrade()),"grade",params.getGrade())
        );
        List<StandardEventVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }
        list.forEach(item->{
            data.add(StandardEventConvert.getStandardEventVO(item));
        });
        return data;
    }

    @Override
    public StandardEventVO save(StandardEventSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardEventInfo entity=new StandardEventInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,12).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setGrade(params.getGrade());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardEventInfoService.save(entity);

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("所属项目:",entity.getProjectCode());
        logContent.put("编号",entity.getId());
        logContent.put("名称",entity.getName());
        logContent.put("等级",entity.getGrade());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_StandardEvent,entity.getId(),logContent);

        return StandardEventConvert.getStandardEventVO(entity);
    }

    @Override
    public StandardEventVO update(StandardEventUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardEventInfo entity=standardEventInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("所属项目:",entity.getProjectCode());
        logContent.put("编号",entity.getId());
        logContent.put("原名称",entity.getName());
        logContent.put("原等级",entity.getGrade());

        entity.setName(params.getName());
        entity.setGrade(params.getGrade());
        entity.setRemark(params.getRemark());

        standardEventInfoService.updateById(entity);
        standardEventCacheService.removeById(entity.getId());


        logContent.put("新名称",entity.getName());
        logContent.put("新等级",entity.getGrade());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_StandardEvent,entity.getId(),logContent);

        return StandardEventConvert.getStandardEventVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardEventInfo entity=standardEventInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        entity.setRowsStatus(YN.NO.getCode());
        standardEventCacheService.removeById(entity.getId());
        standardEventInfoService.updateById(entity);

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("所属项目:",entity.getProjectCode());
        logContent.put("编号",entity.getId());
        logContent.put("名称",entity.getName());
        logContent.put("等级",entity.getGrade());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_StandardEvent,entity.getId(),logContent);

    }

    @Override
    public StandardEventVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardEventInfo entity= standardEventInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardEventConvert.getStandardEventVO(entity);
    }
}
