package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardExamineProjectInfo;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardExamineProjectNameInfo;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardExamineProjectNameInfoService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineNameListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineNameQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineNameSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineNameUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardExamineNameVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardExamineProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardExamineNameBizService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardExamineProjectConvert;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Log4j2
@Service
public class StandardExamineNameBizServiceImpl implements StandardExamineNameBizService {

    @Autowired
    private StandardExamineProjectNameInfoService standardExamineProjectNameInfoService;

    @Override
    public PageData<StandardExamineNameVO> query(StandardExamineNameQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardExamineProjectNameInfo> page = standardExamineProjectNameInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardExamineProjectNameInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())
                        .orderByDesc("create_date")
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardExamineNameVO> data=new PageConverter<StandardExamineProjectNameInfo, StandardExamineNameVO>() {
            @Override
            public StandardExamineNameVO converter(StandardExamineProjectNameInfo entity) {
                return StandardExamineProjectConvert.getStandardExamineNameVO(entity);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public IPage<StandardExamineProjectNameInfo> queryStandardExamineName(StandardExamineNameQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardExamineProjectNameInfo> page = standardExamineProjectNameInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardExamineProjectNameInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())
                        .orderByDesc("create_date")
        );
        return page;
    }

    @Override
    public List<StandardExamineNameVO> list(StandardExamineNameListDTO params) {
        ValidatorUtils.validateEntity(params);

        List<StandardExamineProjectNameInfo> list = standardExamineProjectNameInfoService.list(new QueryWrapper<StandardExamineProjectNameInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())
                        .orderByDesc("create_date")
        );

        if(CollUtil.isEmpty(list)){
            return null;
        }

        List<StandardExamineNameVO> data=new ArrayList<>();
        list.forEach(item->{
            data.add(StandardExamineProjectConvert.getStandardExamineNameVO(item));
        });

        return data;
    }

    @Override
    public StandardExamineNameVO save(StandardExamineNameSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectNameInfo entity=new StandardExamineProjectNameInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,4).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardExamineProjectNameInfoService.save(entity);
        //todo:log
        return StandardExamineProjectConvert.getStandardExamineNameVO(entity);
    }

    @Override
    public StandardExamineNameVO update(StandardExamineNameUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectNameInfo entity=standardExamineProjectNameInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setRemark(params.getRemark());
        standardExamineProjectNameInfoService.updateById(entity);
        //standardExamineProjectCacheService.removeById(entity.getId());
        //todo: , log
        return StandardExamineProjectConvert.getStandardExamineNameVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardExamineProjectNameInfo entity=standardExamineProjectNameInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardExamineProjectNameInfoService.updateById(entity);
        //todo: ,log,delete
        //standardExamineProjectCacheService.removeById(id);
    }

    @Override
    public StandardExamineNameVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardExamineProjectNameInfo entity=standardExamineProjectNameInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardExamineProjectConvert.getStandardExamineNameVO(entity);
    }


}
