package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardExamineProjectCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineProjectListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineProjectQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineProjectSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardExamineProjectUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardExamineProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardExamineProjectBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardExamineProjectInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardExamineProjectConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardExamineProjectInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardExamineProjectBizServiceImpl implements StandardExamineProjectBizService {


    @Autowired
    private StandardExamineProjectInfoService standardExamineProjectInfoService;
    @Autowired
    private StandardExamineProjectCacheService standardExamineProjectCacheService;


    @Override
    public PageData<StandardExamineProjectVO> query(StandardExamineProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardExamineProjectInfo> page = standardExamineProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardExamineProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardExamineProjectVO> data=new PageConverter<StandardExamineProjectInfo, StandardExamineProjectVO>() {
            @Override
            public StandardExamineProjectVO converter(StandardExamineProjectInfo entity) {
                return StandardExamineProjectConvert.getStandardExamineProjectVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public IPage<StandardExamineProjectInfo> queryStandardExamineProject(StandardExamineProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardExamineProjectInfo> page = standardExamineProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardExamineProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );
        return page;
    }

    @Override
    public List<StandardExamineProjectVO> list(StandardExamineProjectListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardExamineProjectInfo> list = standardExamineProjectInfoService.list(new QueryWrapper<StandardExamineProjectInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())

                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                    .or().like("alias_name",params.getKeywords())
                        )

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        List<StandardExamineProjectVO> data=new ArrayList<>();
        list.forEach(item->{
            data.add(StandardExamineProjectConvert.getStandardExamineProjectVO(item));
        });
        return data;
    }

    @Override
    public StandardExamineProjectVO save(StandardExamineProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectInfo entity=new StandardExamineProjectInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,3).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setType(params.getType());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardExamineProjectInfoService.save(entity);
        //todo:log
        return StandardExamineProjectConvert.getStandardExamineProjectVO(entity);
    }

    @Override
    public StandardExamineProjectVO update(StandardExamineProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectInfo entity=standardExamineProjectInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setType(params.getType());
        entity.setRemark(params.getRemark());
        standardExamineProjectInfoService.updateById(entity);
        standardExamineProjectCacheService.removeById(entity.getId());
        //todo: , log
        return StandardExamineProjectConvert.getStandardExamineProjectVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardExamineProjectInfo entity=standardExamineProjectInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardExamineProjectInfoService.updateById(entity);
        //todo: ,log,delete
        standardExamineProjectCacheService.removeById(id);
    }

    @Override
    public StandardExamineProjectVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardExamineProjectInfo entity=standardExamineProjectInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardExamineProjectConvert.getStandardExamineProjectVO(entity);
    }
}
