package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeGroupListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeGroupQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeGroupSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeGroupUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardFeeGroupVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardFeeGroupBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardFeeGroupInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardFeeConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardFeeGroupInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardFeeGroupBizServiceImpl implements StandardFeeGroupBizService {

    @Autowired
    private StandardFeeGroupInfoService standardFeeGroupInfoService;

    @Override
    public PageData<StandardFeeGroupVO> query(StandardFeeGroupQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardFeeGroupInfo> page = standardFeeGroupInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardFeeGroupInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }
        PageData<StandardFeeGroupVO> data= new PageConverter<StandardFeeGroupInfo, StandardFeeGroupVO>() {
            @Override
            public StandardFeeGroupVO converter(StandardFeeGroupInfo entity) {
                return StandardFeeConvert.getStandardFeeGroupVO(entity);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public List<StandardFeeGroupVO> list(StandardFeeGroupListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardFeeGroupInfo> list = standardFeeGroupInfoService.list(new QueryWrapper<StandardFeeGroupInfo>()
                .eq("rows_status", YN.YES.getCode())
                .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
        );
        List<StandardFeeGroupVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }
        list.forEach(item->{
            data.add(StandardFeeConvert.getStandardFeeGroupVO(item));
        });
        return data;
    }

    @Override
    public StandardFeeGroupVO save(StandardFeeGroupSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        //todo:



        return null;
    }

    @Override
    public StandardFeeGroupVO update(StandardFeeGroupUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeGroupInfo entity=standardFeeGroupInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        //todo:
        return null;
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardFeeGroupInfo entity=standardFeeGroupInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardFeeGroupInfoService.updateById(entity);

    }

    @Override
    public StandardFeeGroupVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardFeeGroupInfo entity=standardFeeGroupInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardFeeConvert.getStandardFeeGroupVO(entity);
    }
}
