package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeProjectListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeProjectQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeProjectSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardFeeProjectUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardFeeProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardFeeProjectBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardFeeProjectInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardFeeConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardFeeProjectInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardFeeProjectBizServiceImpl implements StandardFeeProjectBizService {

    @Autowired
    private StandardFeeProjectInfoService standardFeeProjectInfoService;


    @Override
    public PageData<StandardFeeProjectVO> query(StandardFeeProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);

        IPage<StandardFeeProjectInfo> page = standardFeeProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardFeeProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .eq(StrUtil.isNotEmpty(params.getGroupId()),"group_id",params.getGroupId())
        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardFeeProjectVO> data= new PageConverter<StandardFeeProjectInfo, StandardFeeProjectVO>() {
            @Override
            public StandardFeeProjectVO converter(StandardFeeProjectInfo entity) {
                return StandardFeeConvert.getStandardFeeProjectVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardFeeProjectVO> list(StandardFeeProjectListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardFeeProjectInfo> list = standardFeeProjectInfoService.list(new QueryWrapper<StandardFeeProjectInfo>()
                .eq("rows_status", YN.YES.getCode())
                .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                .eq(StrUtil.isNotEmpty(params.getGroupId()),"group_id",params.getGroupId())
        );
        List<StandardFeeProjectVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }
        list.forEach(item->{
            data.add(StandardFeeConvert.getStandardFeeProjectVO(item));
        });
        return data;
    }

    @Override
    public StandardFeeProjectVO save(StandardFeeProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        //todo:
        return null;
    }

    @Override
    public StandardFeeProjectVO update(StandardFeeProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeProjectInfo entity=standardFeeProjectInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        //todo:

        return null;
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardFeeProjectInfo entity=standardFeeProjectInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardFeeProjectInfoService.updateById(entity);
    }

    @Override
    public StandardFeeProjectVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardFeeProjectInfo entity=standardFeeProjectInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardFeeConvert.getStandardFeeProjectVO(entity);
    }
}
