package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.log.bean.constant.ModuleTypeEnum;
import com.xxh.cloud.log.bean.constant.ObjectTypeEnum;
import com.xxh.cloud.log.bean.constant.OperationTypeEnum;
import com.xxh.cloud.log.utils.OperationLogUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardKeywordsCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardKeywordsListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardKeywordsQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardKeywordsSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardKeywordsUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardKeywordsVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardKeywordsBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardKeywordsInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardKeywordsConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardKeywordsInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class StandardKeywordsBizServiceImpl implements StandardKeywordsBizService {

    @Autowired
    private StandardKeywordsCacheService standardKeywordsCacheService;
    @Autowired
    private StandardKeywordsInfoService standardKeywordsInfoService;


    @Override
    public PageData<StandardKeywordsVO> query(StandardKeywordsQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardKeywordsInfo> page = standardKeywordsInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardKeywordsInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getRelOneType()),"rel_one_type",params.getRelOneType())
                        .eq(StrUtil.isNotEmpty(params.getRelTwoType()),"rel_two_type",params.getRelTwoType())
                        .eq(StrUtil.isNotEmpty(params.getRelThreeType()),"rel_three_type",params.getRelThreeType())
                        .eq(StrUtil.isNotEmpty(params.getRelVal()),"rel_val",params.getRelVal())
        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }
        PageData<StandardKeywordsVO> data= new PageConverter<StandardKeywordsInfo, StandardKeywordsVO>() {
            @Override
            public StandardKeywordsVO converter(StandardKeywordsInfo entity) {
                return StandardKeywordsConvert.getStandardKeywordsVO(entity);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public IPage<StandardKeywordsInfo> queryStandardKeywords(StandardKeywordsQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardKeywordsInfo> page = standardKeywordsInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardKeywordsInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getRelOneType()),"rel_one_type",params.getRelOneType())
                        .eq(StrUtil.isNotEmpty(params.getRelTwoType()),"rel_two_type",params.getRelTwoType())
                        .eq(StrUtil.isNotEmpty(params.getRelThreeType()),"rel_three_type",params.getRelThreeType())
                        .eq(StrUtil.isNotEmpty(params.getRelVal()),"rel_val",params.getRelVal())
        );
        return page;
    }

    @Override
    public List<StandardKeywordsVO> list(StandardKeywordsListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardKeywordsInfo> list = standardKeywordsInfoService.list(new QueryWrapper<StandardKeywordsInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())
                        .eq(StrUtil.isNotEmpty(params.getRelOneType()),"rel_one_type",params.getRelOneType())
                        .eq(StrUtil.isNotEmpty(params.getRelTwoType()),"rel_two_type",params.getRelTwoType())
                        .eq(StrUtil.isNotEmpty(params.getRelThreeType()),"rel_three_type",params.getRelThreeType())
                        .eq(StrUtil.isNotEmpty(params.getRelVal()),"rel_val",params.getRelVal())
        );

        List<StandardKeywordsVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }
        list.forEach(item->{
            data.add(StandardKeywordsConvert.getStandardKeywordsVO(item));
        });
        return data;
    }

    @Override
    public StandardKeywordsVO save(StandardKeywordsSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardKeywordsInfo entity=new StandardKeywordsInfo();
        entity.setId(IdUtil.getSnowflake(2,13).nextIdStr());
        entity.setName(params.getName());
        entity.setRegExp(params.getRegExp());
        entity.setRemark(params.getRemark());
        entity.setRelOneType(params.getRelOneType());
        entity.setRelTwoType(params.getRelTwoType());
        entity.setRelThreeType(params.getRelThreeType());
        entity.setRelVal(params.getRelVal());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardKeywordsInfoService.save(entity);

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("所属项目:",params.getProjectCode());
        logContent.put("编号",entity.getId());
        logContent.put("名称",entity.getName());
        logContent.put("规则",entity.getRegExp());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Add, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_StandardKeywords,entity.getId(),logContent);

        return StandardKeywordsConvert.getStandardKeywordsVO(entity);
    }

    @Override
    public StandardKeywordsVO update(StandardKeywordsUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardKeywordsInfo entity=standardKeywordsInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        Map<String, Object> logContent=new HashMap<>();
        logContent.put("编号",entity.getId());
        logContent.put("原名称",entity.getName());
        logContent.put("原规则",entity.getRegExp());

        entity.setName(params.getName());
        entity.setRegExp(params.getRegExp());
        entity.setRemark(params.getRemark());
        entity.setRelOneType(params.getRelOneType());
        entity.setRelTwoType(params.getRelTwoType());
        entity.setRelThreeType(params.getRelThreeType());
        entity.setRelVal(params.getRelVal());
        standardKeywordsInfoService.updateById(entity);
        standardKeywordsCacheService.removeById(entity.getId());

        logContent.put("新名称",entity.getName());
        logContent.put("新规则",entity.getRegExp());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Edit, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_StandardKeywords,entity.getId(),logContent);
        return StandardKeywordsConvert.getStandardKeywordsVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }

        StandardKeywordsInfo entity=standardKeywordsInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardKeywordsInfoService.updateById(entity);
        standardKeywordsCacheService.removeById(entity.getId());

        Map<String, Object> logContent=new HashMap<>();
        logContent.put("所属项目:",entity.getProjectCode());
        logContent.put("编号",entity.getId());
        logContent.put("名称",entity.getName());
        logContent.put("规则",entity.getRegExp());
        OperationLogUtils.addOpLogGen(OperationTypeEnum.OP_Del, ModuleTypeEnum.MT_Metadata, ObjectTypeEnum.OT_StandardKeywords,entity.getId(),logContent);
    }

    @Override
    public StandardKeywordsVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardKeywordsInfo entity= standardKeywordsInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardKeywordsConvert.getStandardKeywordsVO(entity);
    }
}
