package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardLaboratoryGroupCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryGroupListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryGroupQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryGroupSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryGroupUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardLaboratoryGroupVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardLaboratoryGroupBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardLaboratoryGroupInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardLaboratoryConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardLaboratoryGroupInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardLaboratoryGroupBizServiceImpl implements StandardLaboratoryGroupBizService {

    @Autowired
    private StandardLaboratoryGroupInfoService standardLaboratoryGroupInfoService;
    @Autowired
    private StandardLaboratoryGroupCacheService standardLaboratoryGroupCacheService;



    @Override
    public PageData<StandardLaboratoryGroupVO> query(StandardLaboratoryGroupQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardLaboratoryGroupInfo> page = standardLaboratoryGroupInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardLaboratoryGroupInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardLaboratoryGroupVO> data=new PageConverter<StandardLaboratoryGroupInfo, StandardLaboratoryGroupVO>() {
            @Override
            public StandardLaboratoryGroupVO converter(StandardLaboratoryGroupInfo entity) {
                return StandardLaboratoryConvert.getStandardLaboratoryGroupVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public IPage<StandardLaboratoryGroupInfo> queryStandardLaboratoryGroup(StandardLaboratoryGroupQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardLaboratoryGroupInfo> page = standardLaboratoryGroupInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardLaboratoryGroupInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );
        return page;
    }

    @Override
    public List<StandardLaboratoryGroupVO> list(StandardLaboratoryGroupListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardLaboratoryGroupInfo> list = standardLaboratoryGroupInfoService.list(new QueryWrapper<StandardLaboratoryGroupInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        List<StandardLaboratoryGroupVO> data=new ArrayList<>();
        list.forEach(item->{
            data.add(StandardLaboratoryConvert.getStandardLaboratoryGroupVO(item));
        });
        return data;
    }

    @Override
    public StandardLaboratoryGroupVO save(StandardLaboratoryGroupSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryGroupInfo entity=new StandardLaboratoryGroupInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,4).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setType(params.getType());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardLaboratoryGroupInfoService.save(entity);
        return StandardLaboratoryConvert.getStandardLaboratoryGroupVO(entity);
    }

    @Override
    public StandardLaboratoryGroupVO update(StandardLaboratoryGroupUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryGroupInfo entity=standardLaboratoryGroupInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setType(params.getType());
        entity.setRemark(params.getRemark());
        standardLaboratoryGroupInfoService.updateById(entity);
        standardLaboratoryGroupCacheService.removeById(entity.getId());
        //todo: cache, log
        return StandardLaboratoryConvert.getStandardLaboratoryGroupVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardLaboratoryGroupInfo entity=standardLaboratoryGroupInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        //REL
        //todo: cache,log,delete
        entity.setRowsStatus(YN.NO.getCode());
        standardLaboratoryGroupInfoService.updateById(entity);

        standardLaboratoryGroupCacheService.removeById(id);
    }

    @Override
    public StandardLaboratoryGroupVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardLaboratoryGroupInfo entity=standardLaboratoryGroupInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardLaboratoryConvert.getStandardLaboratoryGroupVO(entity);
    }
}
