package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.utils.StrJoinSplitUtils;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.client.api.StandardLaboratoryTypeClientService;
import com.xxh.cloud.metadata.client.api.StandardSampleClientService;
import com.xxh.cloud.metadata.client.api.StandardUnitClientService;
import com.xxh.cloud.metadata.client.api.bean.bos.standard.StandardLaboratoryTypeBO;
import com.xxh.cloud.metadata.client.api.bean.bos.standard.StandardSampleBO;
import com.xxh.cloud.metadata.client.api.bean.bos.standard.StandardUnitBO;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardLaboratoryProjectCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryProjectListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryProjectQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryProjectSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryProjectUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardLaboratoryProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardLaboratoryProjectBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardLaboratoryProjectInfo;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardLaboratoryRelationInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardLaboratoryConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardLaboratoryProjectInfoService;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardLaboratoryRelationInfoService;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardLaboratoryProjectBizServiceImpl implements StandardLaboratoryProjectBizService {

    @Autowired
    private StandardLaboratoryProjectInfoService standardLaboratoryProjectInfoService;
    @Autowired
    private StandardLaboratoryRelationInfoService standardLaboratoryRelationInfoService;

    @Autowired
    private StandardLaboratoryProjectCacheService standardLaboratoryProjectCacheService;

    @Autowired
    private AdminUserClientService adminUserClientService;
    @Autowired
    private StandardUnitClientService standardUnitClientService;
    @Autowired
    private StandardSampleClientService standardSampleClientService;
    @Autowired
    private StandardLaboratoryTypeClientService standardLaboratoryTypeClientService;


    @Override
    public PageData<StandardLaboratoryProjectVO> query(StandardLaboratoryProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardLaboratoryProjectInfo> page = standardLaboratoryProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardLaboratoryProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                     .or().like("abbr_name",params.getKeywords())
                                     .or().like("alias_name",params.getKeywords())
                        )
        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }
        //
        Set<String> userIds=new HashSet<>();
        Set<String> sampleIds=new HashSet<>();
        Set<String> typeIds=new HashSet<>();
        Set<String> unitIds=new HashSet<>();

        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getSampleId())){
                sampleIds.add(item.getSampleId());
            }
            if(StrUtil.isNotEmpty(item.getTypeIds())){
                List<String> _ids= StrJoinSplitUtils.split2List(item.getTypeIds());
                typeIds.addAll(_ids);
            }
            if(StrUtil.isNotEmpty(item.getUnitIds())){
                List<String> _ids= StrJoinSplitUtils.split2List(item.getUnitIds());
                unitIds.addAll(_ids);
            }
        });

        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
        Map<String, StandardLaboratoryTypeBO> laboratoryTypeMap= standardLaboratoryTypeClientService.getMap(typeIds);
        Map<String, StandardUnitBO> unitMap= standardUnitClientService.getMap(unitIds);
        Map<String, StandardSampleBO> sampleMap= standardSampleClientService.getMap(sampleIds);


        PageData<StandardLaboratoryProjectVO> data=new PageConverter<StandardLaboratoryProjectInfo, StandardLaboratoryProjectVO>() {
            @Override
            public StandardLaboratoryProjectVO converter(StandardLaboratoryProjectInfo entity) {
                return StandardLaboratoryConvert.getStandardLaboratoryProjectVO(entity,laboratoryTypeMap,unitMap,sampleMap,userMap);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public IPage<StandardLaboratoryProjectInfo> queryStandardLaboratoryProject(StandardLaboratoryProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardLaboratoryProjectInfo> page = standardLaboratoryProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardLaboratoryProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )
        );
        return page;
    }

    @Override
    public List<StandardLaboratoryProjectVO> list(StandardLaboratoryProjectListDTO params) {
        ValidatorUtils.validateEntity(params);

        List<StandardLaboratoryProjectInfo> list = standardLaboratoryProjectInfoService.list(new QueryWrapper<StandardLaboratoryProjectInfo>()
                        .eq("rows_status",YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("abbr_name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )
        );

        if(CollUtil.isEmpty(list)){
            return null;
        }

        Set<String> userIds=new HashSet<>();
        Set<String> sampleIds=new HashSet<>();
        Set<String> typeIds=new HashSet<>();
        Set<String> unitIds=new HashSet<>();

        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            if(StrUtil.isNotEmpty(item.getSampleId())){
                sampleIds.add(item.getSampleId());
            }
            if(StrUtil.isNotEmpty(item.getTypeIds())){
                List<String> _ids= StrJoinSplitUtils.split2List(item.getTypeIds());
                typeIds.addAll(_ids);
            }
            if(StrUtil.isNotEmpty(item.getUnitIds())){
                List<String> _ids= StrJoinSplitUtils.split2List(item.getUnitIds());
                unitIds.addAll(_ids);
            }
        });

        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);
        Map<String, StandardLaboratoryTypeBO> laboratoryTypeMap= standardLaboratoryTypeClientService.getMap(typeIds);
        Map<String, StandardUnitBO> unitMap= standardUnitClientService.getMap(unitIds);
        Map<String, StandardSampleBO> sampleMap= standardSampleClientService.getMap(sampleIds);



        List<StandardLaboratoryProjectVO> data=new ArrayList<>();
        list.forEach(item->{
            data.add( StandardLaboratoryConvert.getStandardLaboratoryProjectVO(item,laboratoryTypeMap,unitMap,sampleMap,userMap));
        });
        return data;
    }

    @Override
    public StandardLaboratoryProjectVO save(StandardLaboratoryProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryProjectInfo entity=new StandardLaboratoryProjectInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,5).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setAbbrName(params.getAbbrName());
        entity.setAliasName(params.getAliasName());
        entity.setTypeIds(StrJoinSplitUtils.join(params.getTypeIds()));
        entity.setSampleId(params.getSampleId());
        entity.setUnitIds(StrJoinSplitUtils.join(params.getUnitIds()));
        entity.setResultType(params.getResultType());
        entity.setResultDataType(params.getResultDataType());
        if(CollUtil.isNotEmpty(params.getReferenceRangeJson())){
            entity.setReferenceRangeJson(JSON.toJSONString(params.getReferenceRangeJson()));
        }
        if(CollUtil.isNotEmpty(params.getCriticalValueJson())){
            entity.setCriticalValueJson(JSON.toJSONString(params.getCriticalValueJson()));
        }
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardLaboratoryProjectInfoService.save(entity);

        List<StandardLaboratoryRelationInfo> slrList=new ArrayList<>();
        if(CollUtil.isNotEmpty(params.getGroupIds())){
            params.getGroupIds().forEach(gid->{
                slrList.add(StandardLaboratoryConvert.getStandardLaboratoryRelation_Add(gid,entity.getId()));
            });
        }
        if(slrList.size()>0){
            standardLaboratoryRelationInfoService.saveBatch(slrList);
        }

        return StandardLaboratoryConvert.getStandardLaboratoryProjectVO(entity);
    }

    @Override
    public StandardLaboratoryProjectVO update(StandardLaboratoryProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryProjectInfo entity=standardLaboratoryProjectInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setAbbrName(params.getAbbrName());
        entity.setAliasName(params.getAliasName());
        entity.setTypeIds(StrJoinSplitUtils.join(params.getTypeIds()));
        entity.setSampleId(params.getSampleId());
        entity.setUnitIds(StrJoinSplitUtils.join(params.getUnitIds()));
        entity.setResultType(params.getResultType());
        entity.setResultDataType(params.getResultDataType());
        if(CollUtil.isNotEmpty(params.getReferenceRangeJson())){
            entity.setReferenceRangeJson(JSON.toJSONString(params.getReferenceRangeJson()));
        }
        if(CollUtil.isNotEmpty(params.getCriticalValueJson())){
            entity.setCriticalValueJson(JSON.toJSONString(params.getCriticalValueJson()));
        }
        entity.setRemark(params.getRemark());
        standardLaboratoryProjectInfoService.updateById(entity);


        List<StandardLaboratoryRelationInfo> slrList=new ArrayList<>();
        if(CollUtil.isNotEmpty(params.getGroupIds())){
            params.getGroupIds().forEach(gid->{
                slrList.add(StandardLaboratoryConvert.getStandardLaboratoryRelation_Add(gid,entity.getId()));
            });
        }

        if(slrList.size()>0){
            standardLaboratoryRelationInfoService.remove(
                    new QueryWrapper<StandardLaboratoryRelationInfo>()
                            .eq("project_id",entity.getId())
            );
            standardLaboratoryRelationInfoService.saveBatch(slrList);
        }

        standardLaboratoryProjectCacheService.removeById(entity.getId());

        return StandardLaboratoryConvert.getStandardLaboratoryProjectVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardLaboratoryProjectInfo entity=standardLaboratoryProjectInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        //todo:
        standardLaboratoryRelationInfoService.remove(
                new QueryWrapper<StandardLaboratoryRelationInfo>()
                        .eq("project_id",entity.getId())
        );

        entity.setRowsStatus(YN.NO.getCode());
        standardLaboratoryProjectInfoService.updateById(entity);

        standardLaboratoryProjectCacheService.removeById(id);
    }

    @Override
    public StandardLaboratoryProjectVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardLaboratoryProjectInfo entity=standardLaboratoryProjectInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardLaboratoryConvert.getStandardLaboratoryProjectVO(entity);
    }
}
