package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardLaboratoryTypeCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryTypeListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryTypeQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryTypeSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardLaboratoryTypeUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardLaboratoryTypeVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardLaboratoryTypeBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardLaboratoryTypeInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardLaboratoryConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardLaboratoryTypeInfoService;
import com.xxh.cloud.user.client.api.AdminUserClientService;
import com.xxh.cloud.user.client.api.bean.bos.AdminUserBO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardLaboratoryTypeBizServiceImpl implements StandardLaboratoryTypeBizService {



    @Autowired
    private StandardLaboratoryTypeInfoService standardLaboratoryTypeInfoService;

    @Autowired
    private StandardLaboratoryTypeCacheService standardLaboratoryTypeCacheService;

    @Autowired
    private AdminUserClientService adminUserClientService;



    @Override
    public PageData<StandardLaboratoryTypeVO> query(StandardLaboratoryTypeQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardLaboratoryTypeInfo> page = standardLaboratoryTypeInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardLaboratoryTypeInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        Set<String> userIds=new HashSet<>();
        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
        });
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardLaboratoryTypeVO> data= new PageConverter<StandardLaboratoryTypeInfo, StandardLaboratoryTypeVO>() {
            @Override
            public StandardLaboratoryTypeVO converter(StandardLaboratoryTypeInfo entity) {
                return StandardLaboratoryConvert.getStandardLaboratoryTypeVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardLaboratoryTypeVO> list(StandardLaboratoryTypeListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardLaboratoryTypeInfo> list = standardLaboratoryTypeInfoService.list(
                new QueryWrapper<StandardLaboratoryTypeInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("alias_name",params.getKeywords())
                        )

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }

        Set<String> userIds=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
        });
        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        List<StandardLaboratoryTypeVO> data=new ArrayList<>();

        list.forEach(entity->{
            data.add(StandardLaboratoryConvert.getStandardLaboratoryTypeVO(entity));
        });
        return data;
    }

    @Override
    public StandardLaboratoryTypeVO save(StandardLaboratoryTypeSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryTypeInfo entity=new StandardLaboratoryTypeInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,6).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardLaboratoryTypeInfoService.save(entity);
        //todo: log
        return StandardLaboratoryConvert.getStandardLaboratoryTypeVO(entity);
    }

    @Override
    public StandardLaboratoryTypeVO update(StandardLaboratoryTypeUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryTypeInfo entity=standardLaboratoryTypeInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setAliasName(params.getAliasName());
        entity.setRemark(params.getRemark());
        standardLaboratoryTypeInfoService.updateById(entity);
        standardLaboratoryTypeCacheService.removeById(entity.getId());
        //todo: log
        return StandardLaboratoryConvert.getStandardLaboratoryTypeVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardLaboratoryTypeInfo entity=standardLaboratoryTypeInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardLaboratoryTypeInfoService.updateById(entity);

        standardLaboratoryTypeCacheService.removeById(entity.getId());
        //todo:log
    }

    @Override
    public StandardLaboratoryTypeVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardLaboratoryTypeInfo entity=standardLaboratoryTypeInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardLaboratoryConvert.getStandardLaboratoryTypeVO(entity);
    }
}
