package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardMedicantCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardMedicantBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardMedicantInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardMedicantConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardMedicantInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardMedicantBizServiceImpl implements StandardMedicantBizService {


    @Autowired
    private StandardMedicantInfoService standardMedicantInfoService;
    @Autowired
    private StandardMedicantCacheService standardMedicantCacheService;


    @Override
    public IPage<StandardMedicantInfo> queryStandardMedicant(StandardMedicantQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardMedicantInfo> page = standardMedicantInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardMedicantInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        // .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getMedicantCode()),"medicant_code",params.getMedicantCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("standard_name",params.getKeywords())
                                        .or().like("name",params.getKeywords())
                        )

        );
        return page;
    }


    @Override
    public PageData<StandardMedicantVO> query(StandardMedicantQueryDTO params) {
        ValidatorUtils.validateEntity(params);

        IPage<StandardMedicantInfo> page = standardMedicantInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardMedicantInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        // .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getMedicantCode()),"medicant_code",params.getMedicantCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("standard_name",params.getKeywords())
                                        .or().like("name",params.getKeywords())
                        )

        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return new PageData<>(null, 0);
        }

//        Set<String> userIds=new HashSet<>();
//        page.getRecords().forEach(item->{
//            if(StrUtil.isNotEmpty(item.getCreator())){
//                userIds.add(item.getCreator());
//            }
//            if(StrUtil.isNotEmpty(item.getUpdater())){
//                userIds.add(item.getUpdater());
//            }
//        });
//        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardMedicantVO> data= new PageConverter<StandardMedicantInfo, StandardMedicantVO>() {
            @Override
            public StandardMedicantVO converter(StandardMedicantInfo entity) {
                return StandardMedicantConvert.getStandardMedicantVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardMedicantVO> list(StandardMedicantListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardMedicantInfo> list = standardMedicantInfoService.list(
                new QueryWrapper<StandardMedicantInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        // .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getMedicantCode()),"medicant_code",params.getMedicantCode())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("standard_name",params.getKeywords())
                                        .or().like("name",params.getKeywords())
                        )

        );
        if(CollUtil.isEmpty(list)){
            return new ArrayList<>(0);
        }
        List<StandardMedicantVO> data=new ArrayList<>();
        list.forEach(entity->{
            data.add(StandardMedicantConvert.getStandardMedicantVO(entity));
        });
        return data;
    }

    @Override
    public StandardMedicantVO save(StandardMedicantSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantInfo entity=new StandardMedicantInfo();
        
        entity.setId(params.getMedicantCode());
        entity.setMedicantCode(params.getMedicantCode());
        entity.setStandardName(params.getStandardName());
        entity.setName(params.getName());
        entity.setCategory(params.getCategory());
        entity.setManufacturer(params.getManufacturer());
        entity.setNature(params.getNature());
        entity.setDiseaseRelation(params.getDiseaseRelation());
        entity.setShape(params.getShape());
        entity.setComposition(params.getComposition());
        entity.setIndication(params.getIndication());
        entity.setSpecification(params.getSpecification());
        entity.setAdverseReaction(params.getAdverseReaction());
        entity.setUsageuse(params.getUsageuse());
        entity.setContraindication(params.getContraindication());
        entity.setPrecautions(params.getPrecautions());
        entity.setUseChildren(params.getUseChildren());
        entity.setUsePregnant(params.getUsePregnant());
        entity.setUseOldPeople(params.getUseOldPeople());
        entity.setInteraction(params.getInteraction());
        entity.setPharmacology(params.getPharmacology());
        entity.setPharmacokinetics(params.getPharmacokinetics());
        entity.setStorage(params.getStorage());
        entity.setExpiryDate(params.getExpiryDate());
        entity.setOneUseNum(params.getOneUseNum());
        entity.setOneUseUnit(params.getOneUseUnit());
        entity.setOneDoseNum(params.getOneDoseNum());
        entity.setOneDoseUnit(params.getOneDoseUnit());
        entity.setUseFrequency(params.getUseFrequency());
        entity.setUseRemark(params.getUseRemark());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardMedicantInfoService.save(entity);

        return StandardMedicantConvert.getStandardMedicantVO(entity);
    }

    @Override
    public StandardMedicantVO update(StandardMedicantUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantInfo entity=standardMedicantInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        
        // entity.setMedicantCode(params.getMedicantCode());
        entity.setStandardName(params.getStandardName());
        entity.setName(params.getName());
        entity.setCategory(params.getCategory());
        entity.setManufacturer(params.getManufacturer());
        entity.setNature(params.getNature());
        entity.setDiseaseRelation(params.getDiseaseRelation());
        entity.setShape(params.getShape());
        entity.setComposition(params.getComposition());
        entity.setIndication(params.getIndication());
        entity.setSpecification(params.getSpecification());
        entity.setAdverseReaction(params.getAdverseReaction());
        entity.setUsageuse(params.getUsageuse());
        entity.setContraindication(params.getContraindication());
        entity.setPrecautions(params.getPrecautions());
        entity.setUseChildren(params.getUseChildren());
        entity.setUsePregnant(params.getUsePregnant());
        entity.setUseOldPeople(params.getUseOldPeople());
        entity.setInteraction(params.getInteraction());
        entity.setPharmacology(params.getPharmacology());
        entity.setPharmacokinetics(params.getPharmacokinetics());
        entity.setStorage(params.getStorage());
        entity.setExpiryDate(params.getExpiryDate());
        entity.setOneUseNum(params.getOneUseNum());
        entity.setOneUseUnit(params.getOneUseUnit());
        entity.setOneDoseNum(params.getOneDoseNum());
        entity.setOneDoseUnit(params.getOneDoseUnit());
        entity.setUseFrequency(params.getUseFrequency());
        entity.setUseRemark(params.getUseRemark());
        entity.setVersionCode(params.getVersionCode());

        standardMedicantInfoService.updateById(entity);

        standardMedicantCacheService.removeById(entity.getId());

        return StandardMedicantConvert.getStandardMedicantVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardMedicantInfo entity=standardMedicantInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardMedicantInfoService.updateById(entity);
        
        standardMedicantCacheService.removeById(entity.getId());
    }

    @Override
    public StandardMedicantVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardMedicantInfo entity=standardMedicantInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardMedicantConvert.getStandardMedicantVO(entity);
    }

}
