package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardMedicantCacheService;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardMedicantDrugRelCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantDrugRelListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantDrugRelQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantDrugRelSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardMedicantDrugRelUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantDrugRelVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardMedicantDrugRelBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardMedicantDrugRel;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardMedicantConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardMedicantDrugRelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardMedicantDrugRelBizServiceImpl implements StandardMedicantDrugRelBizService {

    @Autowired
    private StandardMedicantDrugRelService standardMedicantDrugRelService;
    @Autowired
    private StandardMedicantDrugRelCacheService standardMedicantDrugRelCacheService;
    @Autowired
    private StandardMedicantCacheService standardMedicantCacheService;

    @Override
    public IPage<StandardMedicantDrugRel> queryStandardMedicantDrugRel(StandardMedicantDrugRelQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardMedicantDrugRel> page = standardMedicantDrugRelService.page(
                new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardMedicantDrugRel>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()), "id", params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()), "id", params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()), "project_code", params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getMedicantId()), "medicant_id", params.getMedicantId())
                        .eq(StrUtil.isNotEmpty(params.getDrugId()), "drug_id", params.getDrugId()));
        return page;
    }

    @Override
    public PageData<StandardMedicantDrugRelVO> query(StandardMedicantDrugRelQueryDTO params) {
        ValidatorUtils.validateEntity(params);

        IPage<StandardMedicantDrugRel> page = standardMedicantDrugRelService.page(
                new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardMedicantDrugRel>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()), "id", params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()), "id", params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()), "project_code", params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getMedicantId()), "medicant_id", params.getMedicantId())
                        .eq(StrUtil.isNotEmpty(params.getDrugId()), "drug_id", params.getDrugId()));

        if (page == null || CollUtil.isEmpty(page.getRecords())) {
            return new PageData<>(null, 0);
        }

        List<String> medicantIds = new ArrayList<>();
        page.getRecords().forEach(item -> {
            medicantIds.add(item.getMedicantId());
        });

        Map<String, StandardMedicantVO> medicantMap = standardMedicantCacheService.getMapByIds(medicantIds);

        // Set<String> userIds=new HashSet<>();
        // page.getRecords().forEach(item->{
        // if(StrUtil.isNotEmpty(item.getCreator())){
        // userIds.add(item.getCreator());
        // }
        // if(StrUtil.isNotEmpty(item.getUpdater())){
        // userIds.add(item.getUpdater());
        // }
        // });
        // Map<String, AdminUserBO> userMap=
        // adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardMedicantDrugRelVO> data = new PageConverter<StandardMedicantDrugRel, StandardMedicantDrugRelVO>() {
            @Override
            public StandardMedicantDrugRelVO converter(StandardMedicantDrugRel entity) {
                StandardMedicantDrugRelVO vo = StandardMedicantConvert.getStandardMedicantDrugRelVO(entity);
                vo.setStandardMedicantInfo(medicantMap.get(vo.getMedicantId()));
                return vo;
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardMedicantDrugRelVO> list(StandardMedicantDrugRelListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardMedicantDrugRel> list = standardMedicantDrugRelService.list(
                new QueryWrapper<StandardMedicantDrugRel>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()), "id", params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()), "project_code", params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getMedicantId()), "medicant_id", params.getMedicantId())
                        .eq(StrUtil.isNotEmpty(params.getDrugId()), "drug_id", params.getDrugId()));
        if (CollUtil.isEmpty(list)) {
            return new ArrayList<>(0);
        }
        
        List<String> medicantIds = new ArrayList<>();
        list.forEach(item -> {
            medicantIds.add(item.getMedicantId());
        });

        Map<String, StandardMedicantVO> medicantMap = standardMedicantCacheService.getMapByIds(medicantIds);

        List<StandardMedicantDrugRelVO> data = new ArrayList<>();
        list.forEach(entity -> {
            StandardMedicantDrugRelVO vo = StandardMedicantConvert.getStandardMedicantDrugRelVO(entity);
            vo.setStandardMedicantInfo(medicantMap.get(vo.getMedicantId()));
            data.add(vo);
        });
        return data;
    }

    @Override
    public StandardMedicantDrugRelVO save(StandardMedicantDrugRelSaveDTO params) {
        ValidatorUtils.validateEntity(params);

        StandardMedicantDrugRel entity = new StandardMedicantDrugRel();
        entity.setId(IdUtil.getSnowflake(2, 7).nextIdStr());
        entity.setProjectCode(params.getProjectCode());
        entity.setMedicantId(params.getMedicantId());
        entity.setDrugId(params.getDrugId());
        entity.setRemark(params.getRemark());
        entity.setRowsStatus(YN.YES.getCode());

        standardMedicantDrugRelService.save(entity);

        return StandardMedicantConvert.getStandardMedicantDrugRelVO(entity);
    }

    @Override
    public StandardMedicantDrugRelVO update(StandardMedicantDrugRelUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantDrugRel entity = standardMedicantDrugRelService.getById(params.getId());
        if (entity == null || YN.NO.getCode().equals(entity.getRowsStatus())) {
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        entity.setProjectCode(params.getProjectCode());
        entity.setMedicantId(params.getMedicantId());
        entity.setDrugId(params.getDrugId());
        entity.setRemark(params.getRemark());

        standardMedicantDrugRelService.updateById(entity);

        standardMedicantDrugRelCacheService.removeById(entity.getId());

        return StandardMedicantConvert.getStandardMedicantDrugRelVO(entity);
    }

    @Override
    public void delById(String id) {
        if (StrUtil.isEmpty(id)) {
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR, "ID不能为空");
        }
        StandardMedicantDrugRel entity = standardMedicantDrugRelService.getById(id);
        if (entity == null || YN.NO.getCode().equals(entity.getRowsStatus())) {
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardMedicantDrugRelService.updateById(entity);

        standardMedicantDrugRelCacheService.removeById(entity.getId());
    }

    @Override
    public StandardMedicantDrugRelVO getById(String id) {
        if (StrUtil.isEmpty(id)) {
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR, "ID不能为空");
        }
        StandardMedicantDrugRel entity = standardMedicantDrugRelService.getById(id);
        if (entity == null || YN.NO.getCode().equals(entity.getRowsStatus())) {
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        StandardMedicantVO medicant = standardMedicantCacheService.getById(entity.getMedicantId());
        
        StandardMedicantDrugRelVO vo = StandardMedicantConvert.getStandardMedicantDrugRelVO(entity);
        vo.setStandardMedicantInfo(medicant);

        return vo;
    }

}
