package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardOperationCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardOperationListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardOperationQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardOperationSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardOperationUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardOperationVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardOperationBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardOperationInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardOperationConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardOperationInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardOperationBizServiceImpl implements StandardOperationBizService {

    @Autowired
    private StandardOperationInfoService standardOperationInfoService;
    @Autowired
    private StandardOperationCacheService standardOperationCacheService;


    @Override
    public PageData<StandardOperationVO> query(StandardOperationQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardOperationInfo> page = standardOperationInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardOperationInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getPart()),"part",params.getPart())
                        .eq(StrUtil.isNotEmpty(params.getMedicalInsurance()),"medical_insurance",params.getMedicalInsurance())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("sequela",params.getKeywords())
                        )
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardOperationVO> data= new PageConverter<StandardOperationInfo, StandardOperationVO>() {
            @Override
            public StandardOperationVO converter(StandardOperationInfo entity) {
                return StandardOperationConvert.getStandardOperationVO(entity);
            }
        }.getPageData(page);
        return data;
    }

    @Override
    public IPage<StandardOperationInfo> queryStandardOperation(StandardOperationQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardOperationInfo> page = standardOperationInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardOperationInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getPart()),"part",params.getPart())
                        .eq(StrUtil.isNotEmpty(params.getMedicalInsurance()),"medical_insurance",params.getMedicalInsurance())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("sequela",params.getKeywords())
                        )
        );
        return page;
    }

    @Override
    public List<StandardOperationVO> list(StandardOperationListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardOperationInfo> list = standardOperationInfoService.list(new QueryWrapper<StandardOperationInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getPart()),"part",params.getPart())
                        .eq(StrUtil.isNotEmpty(params.getMedicalInsurance()),"medical_insurance",params.getMedicalInsurance())
                        .and(StrUtil.isNotEmpty(params.getKeywords()),
                                i->i.or().like("name",params.getKeywords())
                                        .or().like("sequela",params.getKeywords())
                        )
        );

        if(CollUtil.isEmpty(list)){
            return null;
        }
        List<StandardOperationVO> data=new ArrayList<>();
        list.forEach(entity->{
            data.add(StandardOperationConvert.getStandardOperationVO(entity));
        });

        return data;
    }

    @Override
    public StandardOperationVO save(StandardOperationSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardOperationInfo entity=new StandardOperationInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,8).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setPart(params.getPart());
        entity.setMedicalInsurance(params.getMedicalInsurance());
        entity.setFee(params.getFee());
        entity.setDifficulty(params.getDifficulty());
        entity.setSequela(params.getSequela());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardOperationInfoService.save(entity);
        //todo:log
        return StandardOperationConvert.getStandardOperationVO(entity);
    }

    @Override
    public StandardOperationVO update(StandardOperationUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardOperationInfo entity=standardOperationInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setPart(params.getPart());
        entity.setMedicalInsurance(params.getMedicalInsurance());
        entity.setFee(params.getFee());
        entity.setDifficulty(params.getDifficulty());
        entity.setSequela(params.getSequela());
        entity.setRemark(params.getRemark());
        standardOperationInfoService.updateById(entity);
        standardOperationCacheService.removeById(entity.getId());
        //todo:log
        return StandardOperationConvert.getStandardOperationVO(entity);
    }

    @Override
    public StandardOperationVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardOperationInfo entity=standardOperationInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        return StandardOperationConvert.getStandardOperationVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardOperationInfo entity=standardOperationInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardOperationInfoService.updateById(entity);
        standardOperationCacheService.removeById(entity.getId());
        //todo:log
    }
}
