package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardPathologyProjectListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardPathologyProjectQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardPathologyProjectSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardPathologyProjectUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardPathologyProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardPathologyProjectBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardPathologyProjectInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardPathologyProjectConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardPathologyProjectInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class StandardPathologyProjectBizServiceImpl implements StandardPathologyProjectBizService {

    @Autowired
    private StandardPathologyProjectInfoService standardPathologyProjectInfoService;


    @Override
    public IPage<StandardPathologyProjectInfo> queryStandardPathologyProject(StandardPathologyProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardPathologyProjectInfo> page = standardPathologyProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardPathologyProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())
        );
        return page;
    }

    @Override
    public PageData<StandardPathologyProjectVO> query(StandardPathologyProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardPathologyProjectInfo> page = standardPathologyProjectInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardPathologyProjectInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())
        );

        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardPathologyProjectVO> data= new PageConverter<StandardPathologyProjectInfo, StandardPathologyProjectVO>() {
            @Override
            public StandardPathologyProjectVO converter(StandardPathologyProjectInfo entity) {
                return StandardPathologyProjectConvert.getStandardPathologyProjectVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardPathologyProjectVO> list(StandardPathologyProjectListDTO params) {
        ValidatorUtils.validateEntity(params);


        return null;
    }

    @Override
    public StandardPathologyProjectVO save(StandardPathologyProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardPathologyProjectInfo entity=new StandardPathologyProjectInfo();
        entity.setId(params.getId());
        entity.setName(params.getName());
        entity.setRowsStatus(YN.YES.getCode());
        standardPathologyProjectInfoService.save(entity);
        return StandardPathologyProjectConvert.getStandardPathologyProjectVO(entity);
    }

    @Override
    public StandardPathologyProjectVO update(StandardPathologyProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        return null;
    }

    @Override
    public StandardPathologyProjectVO getById(String id) {
        return null;
    }

    @Override
    public void delById(String id) {

    }
}
