package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardSampleCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSampleListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSampleQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSampleSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardSampleUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardSampleVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardSampleBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardSampleInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardSampleConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardSampleInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardSampleBizServiceImpl implements StandardSampleBizService {


    @Autowired
    private StandardSampleInfoService standardSampleInfoService;
    @Autowired
    private StandardSampleCacheService standardSampleCacheService;

    @Override
    public PageData<StandardSampleVO> query(StandardSampleQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardSampleInfo> page = standardSampleInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardSampleInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .like(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())

        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }
        Set<String> userIds=new HashSet<>();
        page.getRecords().forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
        });
//        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        PageData<StandardSampleVO> data= new PageConverter<StandardSampleInfo, StandardSampleVO>() {
            @Override
            public StandardSampleVO converter(StandardSampleInfo entity) {
                return StandardSampleConvert.getStandardSampleVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardSampleVO> list(StandardSampleListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSampleInfo> list = standardSampleInfoService.list(new QueryWrapper<StandardSampleInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getKeywords()),"name",params.getKeywords())

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        Set<String> userIds=new HashSet<>();
        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
        });

//        Map<String, AdminUserBO> userMap= adminUserClientService.getUserMapByIds(userIds);

        List<StandardSampleVO> data=new ArrayList<>();
        list.forEach(entity->{
            data.add(StandardSampleConvert.getStandardSampleVO(entity));
        });
        return data;
    }

    @Override
    public StandardSampleVO save(StandardSampleSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSampleInfo entity=new StandardSampleInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,9).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardSampleInfoService.save(entity);
        //todo:log
        return StandardSampleConvert.getStandardSampleVO(entity);
    }

    @Override
    public StandardSampleVO update(StandardSampleUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSampleInfo entity=standardSampleInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        standardSampleInfoService.updateById(entity);
        standardSampleCacheService.removeById(params.getId());
        //todo:log
        return StandardSampleConvert.getStandardSampleVO(entity);
    }

    @Override
    public StandardSampleVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardSampleInfo entity=standardSampleInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardSampleConvert.getStandardSampleVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardSampleInfo entity=standardSampleInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardSampleInfoService.updateById(entity);
        standardSampleCacheService.removeById(entity.getId());
        //todo:log

    }
}
