package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.tree.TreeUtils;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardSymptomCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardSymptomVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardSymptomBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardSymptomInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardSymptomConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardSymptomInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class StandardSymptomBizServiceImpl implements StandardSymptomBizService {

    @Autowired
    private StandardSymptomInfoService standardSymptomInfoService;
    @Autowired
    private StandardSymptomCacheService standardSymptomCacheService;


    @Override
    public IPage<StandardSymptomInfo> queryStandardSymptom(StandardSymptomQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardSymptomInfo> page = standardSymptomInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardSymptomInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .eq(StrUtil.isNotEmpty(params.getUrgent()),"urgent",params.getUrgent())
                        .like(StrUtil.isNotEmpty(params.getName()),"name",params.getName())

        );
        return page;
    }

    @Override
    public PageData<StandardSymptomVO> query(StandardSymptomQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardSymptomInfo> page = standardSymptomInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardSymptomInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .in(CollUtil.isNotEmpty(params.getIds()),"id",params.getIds())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .eq(StrUtil.isNotEmpty(params.getUrgent()),"urgent",params.getUrgent())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())

        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardSymptomVO> data= new PageConverter<StandardSymptomInfo, StandardSymptomVO>() {
            @Override
            public StandardSymptomVO converter(StandardSymptomInfo entity) {
                return StandardSymptomConvert.getStandardSymptomVO(entity);
            }
        }.getPageData(page);

        return data;
    }

    @Override
    public List<StandardSymptomVO> tree(StandardSymptomTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSymptomInfo> list = standardSymptomInfoService.list(new QueryWrapper<StandardSymptomInfo>()
                .eq("rows_status", YN.YES.getCode())
                .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
        );

        List<StandardSymptomVO> dataList=new ArrayList<>();
        list.forEach(item->{
            dataList.add(StandardSymptomConvert.getStandardSymptomVO(item));
        });
        List<StandardSymptomVO> data= TreeUtils.build(dataList);
        return data;
    }

    @Override
    public List<StandardSymptomVO> list(StandardSymptomListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSymptomInfo> list = standardSymptomInfoService.list(new QueryWrapper<StandardSymptomInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getType()),"type",params.getType())
                        .eq(StrUtil.isNotEmpty(params.getUrgent()),"urgent",params.getUrgent())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        Set<String> userIds=new HashSet<>();
        Set<String> ids=new HashSet<>();

        list.forEach(item->{
            if(StrUtil.isNotEmpty(item.getCreator())){
                userIds.add(item.getCreator());
            }
            if(StrUtil.isNotEmpty(item.getUpdater())){
                userIds.add(item.getUpdater());
            }
            ids.add(item.getId());
        });


        Map<String,Integer> childIdNumMap=new HashMap<>();
        if(StrUtil.isNotEmpty(params.getIsShowChildFlag()) && YN.YES.getCode().equals(params.getIsShowChildFlag())){
            List<Map<String, Object>> mapList= standardSymptomInfoService.listMaps(
                    new QueryWrapper<StandardSymptomInfo>()
                            .select("pid ","count(1) as num")
                            .eq("rows_status",YN.YES.getCode())
                            .in("pid",ids)
                            .groupBy("pid")
            );
            if(CollUtil.isNotEmpty(mapList)){
                mapList.forEach(item->{
                    String id = Convert.toStr(item.get("pid"));
                    Integer num= Convert.toInt(item.get("num"));
                    childIdNumMap.put(id,num);
                });
            }
        }



        List<StandardSymptomVO> data=new ArrayList<>();
        list.forEach(entity->{
            data.add(StandardSymptomConvert.getStandardSymptomVO(entity,childIdNumMap));
        });
        return data;
    }

    @Override
    public StandardSymptomVO save(StandardSymptomSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSymptomInfo entity=new StandardSymptomInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,10).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setType(params.getType());
        entity.setUrgent(params.getUrgent());
        entity.setPid(params.getPid());
        entity.setRemark(params.getRemark());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardSymptomInfoService.save(entity);
        //todo:
        return StandardSymptomConvert.getStandardSymptomVO(entity);
    }

    @Override
    public StandardSymptomVO update(StandardSymptomUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSymptomInfo entity=standardSymptomInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setType(params.getType());
        entity.setUrgent(params.getUrgent());
        entity.setPid(params.getPid());
        entity.setRemark(params.getRemark());
        standardSymptomInfoService.updateById(entity);
        standardSymptomCacheService.removeById(params.getId());
        //todo:log
        return StandardSymptomConvert.getStandardSymptomVO(entity);
    }

    @Override
    public StandardSymptomVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardSymptomInfo entity=standardSymptomInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardSymptomConvert.getStandardSymptomVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardSymptomInfo entity=standardSymptomInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        long num= standardSymptomInfoService.count(
                new QueryWrapper<StandardSymptomInfo>()
                .eq("pid",entity.getId())
        );
        if(num>0){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardSymptomInfoService.updateById(entity);

        standardSymptomCacheService.removeById(entity.getId());
        //todo:log

    }
}
