package com.xxh.cloud.metadata.framework.modules.standardBiz.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.cache.service.StandardUnitCacheService;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardUnitListDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardUnitQueryDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardUnitSaveDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.StandardUnitUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardUnitVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardUnitBizService;
import com.xxh.cloud.metadata.framework.modules.standard.entity.StandardUnitInfo;
import com.xxh.cloud.metadata.framework.modules.standardBiz.helper.StandardUnitConvert;
import com.xxh.cloud.metadata.framework.modules.standard.service.StandardUnitInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class StandardUnitBizServiceImpl implements StandardUnitBizService {

    @Autowired
    private StandardUnitInfoService standardUnitInfoService;
    @Autowired
    private StandardUnitCacheService standardUnitCacheService;


    @Override
    public PageData<StandardUnitVO> query(StandardUnitQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        IPage<StandardUnitInfo> page = standardUnitInfoService.page(new Page<>(params.getPage(), params.getRows()),
                new QueryWrapper<StandardUnitInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())

        );
        if(page==null || CollUtil.isEmpty(page.getRecords())){
            return null;
        }

        PageData<StandardUnitVO> data= new PageConverter<StandardUnitInfo, StandardUnitVO>() {
            @Override
            public StandardUnitVO converter(StandardUnitInfo entity) {
                return StandardUnitConvert.getStandardUnitVO(entity);
            }
        }.getPageData(page);


        return data;
    }

    @Override
    public List<StandardUnitVO> list(StandardUnitListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardUnitInfo> list = standardUnitInfoService.list(new QueryWrapper<StandardUnitInfo>()
                        .eq("rows_status", YN.YES.getCode())
                        .eq(StrUtil.isNotEmpty(params.getId()),"id",params.getId())
                        .eq(StrUtil.isNotEmpty(params.getProjectCode()),"project_code",params.getProjectCode())
                        .eq(StrUtil.isNotEmpty(params.getVersionCode()),"version_code",params.getVersionCode())
                        .eq(StrUtil.isNotEmpty(params.getName()),"name",params.getName())

        );
        if(CollUtil.isEmpty(list)){
            return null;
        }
        List<StandardUnitVO> data=new ArrayList<>();
        list.forEach(entity->{
            data.add(StandardUnitConvert.getStandardUnitVO(entity));
        });
        return data;
    }

    @Override
    public StandardUnitVO save(StandardUnitSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardUnitInfo entity=new StandardUnitInfo();
        if(StrUtil.isNotEmpty(params.getId())){
            entity.setId(params.getId());
        }else {
            entity.setId(IdUtil.getSnowflake(2,11).nextIdStr());
        }
        entity.setName(params.getName());
        entity.setRemark(params.getRemark());
        entity.setRuleConfig(params.getRuleConfig());
        entity.setProjectCode(params.getProjectCode());
        entity.setVersionCode(params.getVersionCode());
        entity.setRowsStatus(YN.YES.getCode());
        standardUnitInfoService.save(entity);
        //todo: log
        return StandardUnitConvert.getStandardUnitVO(entity);
    }

    @Override
    public StandardUnitVO update(StandardUnitUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardUnitInfo entity=standardUnitInfoService.getById(params.getId());
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setName(params.getName());
        entity.setRemark(params.getRemark());
        entity.setRuleConfig(params.getRuleConfig());
        standardUnitInfoService.updateById(entity);
        standardUnitCacheService.removeById(params.getId());
        //todo:log
        return StandardUnitConvert.getStandardUnitVO(entity);
    }

    @Override
    public void delById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardUnitInfo entity=standardUnitInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        entity.setRowsStatus(YN.NO.getCode());
        standardUnitInfoService.updateById(entity);

        standardUnitCacheService.removeById(entity.getId());
        //todo: log
    }

    @Override
    public StandardUnitVO getById(String id) {
        if(StrUtil.isEmpty(id)){
            throw new BusinessException(BusinessBaseErrorEnum.PARAMS_GET_ERROR,"ID不能为空");
        }
        StandardUnitInfo entity=standardUnitInfoService.getById(id);
        if(entity==null || YN.NO.getCode().equals(entity.getRowsStatus())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        return StandardUnitConvert.getStandardUnitVO(entity);
    }
}
