package com.xxh.cloud.metadata.framework.modules.tableData.biz.impl;

import cn.hutool.core.collection.CollUtil;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.utils.XXEnumUtil;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableColumnVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.metadata.framework.modules.cache.service.TableInfoCacheService;
import com.xxh.cloud.metadata.framework.modules.constant.TableBaseEnum;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardMedicantBizService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.Table2DataApiService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class Table2DataApiServiceImpl implements Table2DataApiService {

    @Autowired
    private TableInfoCacheService tableInfoCacheService;


    @Override
    public TableInfoVO getTableInfoVO(String tableId) {
        TableInfoVO tableInfo=  tableInfoCacheService.getById(tableId);
        if(tableInfo==null){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }
        if(CollUtil.isEmpty(tableInfo.getCols())){
            throw new BusinessException(BusinessBaseErrorEnum.DB_RECORD_NOT_EXISTS);
        }

        return tableInfo;
    }

    @Override
    public Map<String, TableColumnVO> getTableColumnList(TableInfoVO tableInfo, boolean isBase) {
        Map<String,TableColumnVO> data=new HashMap<>();
        tableInfo.getCols().forEach(item->{
            data.put(item.getCode(),item);
        });

        if(isBase){
            List<TableBaseEnum> tableBaseEnumList= XXEnumUtil.getEnumList(TableBaseEnum.class);
            tableBaseEnumList.forEach(item->{
                TableColumnVO tableColumnVO= new TableColumnVO();
                tableColumnVO.setCode(item.getCode());
                tableColumnVO.setName(item.getName());
                tableColumnVO.setType(item.getType().getCode());
                data.put(tableColumnVO.getCode(),tableColumnVO);
            });
        }
        return data;
    }

    @Override
    public Map<String, TableColumnVO> getTableColumnListByTableId(String tableId, boolean isBase) {
        TableInfoVO tableInfoVO=this.getTableInfoVO(tableId);
        return this.getTableColumnList(tableInfoVO,isBase);
    }


}
