package com.xxh.cloud.metadata.framework.modules.tableData.biz.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.xxh.cloud.framework.common.user.AuthContextUtils;
import com.xxh.cloud.framework.common.user.LoginUser;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableColumnVO;
import com.xxh.cloud.metadata.framework.modules.constant.TableBaseEnum;
import com.xxh.cloud.metadata.framework.modules.script.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.script.service.EntityOperateApiService;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.*;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.Table2DataApiService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataBizService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class TableDataBizServiceImpl implements TableDataBizService {

    @Autowired
    private EntityOperateApiService entityOperateApiService;
    @Autowired
    private Table2DataApiService table2DataApiService;



    @Override
    public void save(TableDataSaveDTO params) {
        ValidatorUtils.validateEntity(params);

        //todo:SQL注入校验

        Map<String,TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnListByTableId(params.getTableId(),false);

        EntityOperateSaveDTO saveDTO=new EntityOperateSaveDTO();
        saveDTO.setTableCode(params.getTableId());

        List<InsertBean> insert=new ArrayList<>();

        //id
        insert.add(new InsertBean(TableBaseEnum.ID.getCode(), TableBaseEnum.ID.getType().getCode(), IdUtil.getSnowflake(8,1).nextIdStr()));
        //p
        if(StrUtil.isNotEmpty(params.getProjectCode())){
            insert.add(new InsertBean(TableBaseEnum.ProjectCode.getCode(), TableBaseEnum.ProjectCode.getType().getCode(), params.getProjectCode()));
        }
        //v
        if(StrUtil.isNotEmpty(params.getVersionCode())){
            insert.add(new InsertBean(TableBaseEnum.VersionCode.getCode(), TableBaseEnum.VersionCode.getType().getCode(), params.getVersionCode()));
        }
        //otype
        if(StrUtil.isNotEmpty(params.getObjectType())){
            insert.add(new InsertBean(TableBaseEnum.ObjectType.getCode(), TableBaseEnum.ObjectType.getType().getCode(), params.getObjectType()));
        }
        //oid
        if(StrUtil.isNotEmpty(params.getObjectId())){
            insert.add(new InsertBean(TableBaseEnum.ObjectId.getCode(), TableBaseEnum.ObjectId.getType().getCode(), params.getObjectId()));
        }
        insert.add(new InsertBean(TableBaseEnum.CreateDate.getCode(), TableBaseEnum.CreateDate.getType().getCode(), DateUtil.now()));
        insert.add(new InsertBean(TableBaseEnum.UpdateDate.getCode(), TableBaseEnum.UpdateDate.getType().getCode(), DateUtil.now()));
        LoginUser loginUser= AuthContextUtils.getCurrentLoginUser();
        if(loginUser!=null){
            insert.add(new InsertBean(TableBaseEnum.Creator.getCode(), TableBaseEnum.Creator.getType().getCode(), loginUser.getId()));
            insert.add(new InsertBean(TableBaseEnum.Updater.getCode(), TableBaseEnum.Updater.getType().getCode(), loginUser.getId()));
        }

        params.getData().forEach((k,v)->{
            TableColumnVO tableColumn=tableColumnMap.get(k);
            if(tableColumn!=null){
                insert.add(new InsertBean(tableColumn.getCode(),tableColumn.getType(),v));
            }
        });
        saveDTO.setInsert(insert);
        entityOperateApiService.save(saveDTO);
    }

    @Override
    public void update(TableDataUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        Map<String,TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnListByTableId(params.getTableId(),false);

        EntityOperateUpdateByIdDTO updateByIdDTO=new EntityOperateUpdateByIdDTO();
        updateByIdDTO.setTableCode(params.getTableId());
        updateByIdDTO.setId(params.getId());

        List<UpdateBean> updates=new ArrayList<>();
        params.getData().forEach((k,v)->{
            if(StrUtil.isNotEmpty(k) && StrUtil.isNotEmpty(v)){
                TableColumnVO tableColumn=tableColumnMap.get(k);
                if(tableColumn!=null){
                    updates.add(new UpdateBean(tableColumn.getCode(),tableColumn.getType(),v));
                }
            }
        });
        updateByIdDTO.setUpdates(updates);

        entityOperateApiService.updateById(updateByIdDTO);
    }



    @Override
    public void delById(TableDataGetDTO params) {
        ValidatorUtils.validateEntity(params);
        EntityOperateDeleteByIdDTO deleteByIdDTO=new EntityOperateDeleteByIdDTO();
        deleteByIdDTO.setTableCode(params.getTableId());
        deleteByIdDTO.setId(params.getId());
        entityOperateApiService.deleteById(deleteByIdDTO);
    }




}
