package com.xxh.cloud.metadata.framework.modules.tableData.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableColumnVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.metadata.framework.modules.cache.service.TableInfoCacheService;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.ConditionOp;
import com.xxh.cloud.metadata.framework.modules.constant.TableBaseEnum;
import com.xxh.cloud.metadata.framework.modules.script.bean.dto.EntityOperateListDTO;
import com.xxh.cloud.metadata.framework.modules.script.service.EntityOperateApiService;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.OrderByBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.SelectBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.WhereAndOrBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.WhereItemBean;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.dto.TableDataListDTO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataList2TableVO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataVO;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.Table2DataApiService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataListService;
import com.xxh.cloud.metadata.framework.modules.tableData.helper.TableDataConvert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Service
public class TableDataListServiceImpl implements TableDataListService {

    @Autowired
    private EntityOperateApiService entityOperateApiService;
    @Autowired
    private Table2DataApiService table2DataApiService;


    @Override
    public List<TableDataVO> list(TableDataListDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO tableInfo= table2DataApiService.getTableInfoVO(params.getTableId());
        Map<String, TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnList(tableInfo,true);
        List<Map<String, Object>> list=this._list(params,tableColumnMap);

        List<TableDataVO> data=new ArrayList<>();
        if(CollUtil.isEmpty(list)){
            return data;
        }
        list.forEach(item->{
            data.add(TableDataConvert.getTableDataVO(item));
        });
        return data;
    }

    @Override
    public TableDataList2TableVO list2Table(TableDataListDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO tableInfo= table2DataApiService.getTableInfoVO(params.getTableId());
        Map<String, TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnList(tableInfo,true);
        List<Map<String, Object>> list=this._list(params,tableColumnMap);

        List<TableDataVO> data=new ArrayList<>();
        if(CollUtil.isNotEmpty(list)){
            list.forEach(item->{
                data.add(TableDataConvert.getTableDataVO(item));
            });
        }
        return TableDataConvert.getTableDataList2TableVO(tableInfo,data);
    }

    @Override
    public List<Map<String, Object>> listMap(TableDataListDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO tableInfo= table2DataApiService.getTableInfoVO(params.getTableId());
        Map<String, TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnList(tableInfo,true);
        return this._list(params,tableColumnMap);
    }


    private List<Map<String, Object>> _list(TableDataListDTO params,Map<String, TableColumnVO> tableColumnMap){

        EntityOperateListDTO listDTO=new EntityOperateListDTO();
        listDTO.setTableCode(params.getTableId());

        //select
        List<SelectBean> select=new ArrayList<>();
        tableColumnMap.forEach((key,item)->{
            select.add(new SelectBean(params.getTableId(),item.getCode(),item.getType()));
        });
        listDTO.setSelect(select);

        //where
        List<WhereAndOrBean> where=new ArrayList<>();
        if(CollUtil.isNotEmpty(params.getCondtions())){
            params.getCondtions().forEach(item->{
                TableColumnVO tableColumn= tableColumnMap.get(item.getPropCode());
                if(tableColumn!=null){
                    where.add(new WhereAndOrBean(new WhereItemBean(params.getTableId(),item.getPropCode(),tableColumn.getType(),
                            item.getOp(),item.getVal(),item.getVal2(),item.getVals())));
                }
            });
        }

        if(StrUtil.isNotEmpty(params.getObjectType())){
            where.add(new WhereAndOrBean(new WhereItemBean(params.getTableId(),
                    TableBaseEnum.ObjectType.getCode(),
                    TableBaseEnum.ObjectType.getType(),
                    ConditionOp.EQ,
                    params.getObjectType()
            )));
        }

        if(StrUtil.isNotEmpty(params.getObjectId())){
            where.add(new WhereAndOrBean(new WhereItemBean(params.getTableId(),
                    TableBaseEnum.ObjectId.getCode(),
                    TableBaseEnum.ObjectId.getType(),
                    ConditionOp.EQ,
                    params.getObjectId()
            )));
        }
        listDTO.setWhere(where);

        //order by
        List<OrderByBean> orderBy=new ArrayList<>();
        if(CollUtil.isNotEmpty(params.getOrderBys())){
            params.getOrderBys().forEach(item->{
                orderBy.add(new OrderByBean(params.getTableId(),item.getPropCode(),item.getOrderByType()));
            });
        }
        listDTO.setOrderBy(orderBy);



        List<Map<String,Object>> data= entityOperateApiService.list(listDTO);
        return data;
    }
}
