package com.xxh.cloud.metadata.framework.modules.tableData.biz.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.mybatisplus.page.PageConverter;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.utils.XXEnumUtil;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableColumnVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.metadata.framework.modules.cache.service.TableInfoCacheService;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.ConditionOp;
import com.xxh.cloud.metadata.framework.modules.constant.TableBaseEnum;
import com.xxh.cloud.metadata.framework.modules.script.bean.dto.EntityOperateQueryDTO;
import com.xxh.cloud.metadata.framework.modules.script.service.EntityOperateApiService;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.OrderByBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.SelectBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.WhereAndOrBean;
import com.xxh.cloud.metadata.framework.modules.script.sql.operate.bean.WhereItemBean;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.dto.TableDataQueryDTO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataPage2TableVO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataVO;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.Table2DataApiService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataQueryService;
import com.xxh.cloud.metadata.framework.modules.tableData.helper.TableDataConvert;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class TableDataQueryServiceImpl implements TableDataQueryService {



    @Autowired
    private EntityOperateApiService entityOperateApiService;
    @Autowired
    private Table2DataApiService table2DataApiService;


    @Override
    public PageData<TableDataVO> query(TableDataQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO tableInfo= table2DataApiService.getTableInfoVO(params.getTableId());
        Map<String, TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnList(tableInfo,true);
        IPage<Map<String, Object>> page= this._query(params,tableColumnMap);
        PageData<TableDataVO> data=new PageConverter<Map<String, Object>, TableDataVO>() {
            @Override
            public TableDataVO converter(Map<String, Object> entity) {
                return TableDataConvert.getTableDataVO(entity);
            }
        }.getPageData(page);
        return data;
    }


    @Override
    public TableDataPage2TableVO query2Table(TableDataQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO tableInfo=  table2DataApiService.getTableInfoVO(params.getTableId());
        Map<String, TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnList(tableInfo,true);
        IPage<Map<String, Object>> page= this._query(params,tableColumnMap);

        PageData<TableDataVO> data=new PageConverter<Map<String, Object>, TableDataVO>() {
            @Override
            public TableDataVO converter(Map<String, Object> entity) {
                return TableDataConvert.getTableDataVO(entity);
            }
        }.getPageData(page);
        return TableDataConvert.getTableDataPage2TableVO(tableInfo,data);
    }

    @Override
    public PageData<Map<String, Object>> queryMap(TableDataQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO tableInfo=  table2DataApiService.getTableInfoVO(params.getTableId());
        Map<String, TableColumnVO> tableColumnMap= table2DataApiService.getTableColumnList(tableInfo,true);
        IPage<Map<String, Object>> page= this._query(params,tableColumnMap);
        PageData<Map<String, Object>> data=new PageConverter<Map<String, Object>, Map<String, Object>>() {
            @Override
            public Map<String, Object> converter(Map<String, Object> entity) {
                return entity;
            }
        }.getPageData(page);
        return data;
    }


    private IPage<Map<String, Object>> _query(TableDataQueryDTO params, Map<String, TableColumnVO> tableColumnMap){
        EntityOperateQueryDTO queryDTO=new EntityOperateQueryDTO();
        queryDTO.setTableCode(params.getTableId());
        queryDTO.setPage(params.getPage());
        queryDTO.setRows(params.getRows());

        //select
        List<SelectBean> select=new ArrayList<>();
        tableColumnMap.forEach((key,item)->{
            select.add(new SelectBean(params.getTableId(),item.getCode(),item.getType()));
        });
        queryDTO.setSelect(select);


        //where
        List<WhereAndOrBean> where=new ArrayList<>();
        if(CollUtil.isNotEmpty(params.getCondtions())){
            params.getCondtions().forEach(item->{
                TableColumnVO tableColumn= tableColumnMap.get(item.getPropCode());
                if(tableColumn!=null){
                    where.add(new WhereAndOrBean(new WhereItemBean(params.getTableId(),item.getPropCode(),tableColumn.getType(),
                            item.getOp(),item.getVal(),item.getVal2(),item.getVals())));
                }
            });
        }

        if(StrUtil.isNotEmpty(params.getObjectType())){
            where.add(new WhereAndOrBean(new WhereItemBean(params.getTableId(),
                    TableBaseEnum.ObjectType.getCode(),
                    TableBaseEnum.ObjectType.getType(),
                    ConditionOp.EQ,
                    params.getObjectType()
            )));
        }

        if(StrUtil.isNotEmpty(params.getObjectId())){
            where.add(new WhereAndOrBean(new WhereItemBean(params.getTableId(),
                    TableBaseEnum.ObjectId.getCode(),
                    TableBaseEnum.ObjectId.getType(),
                    ConditionOp.EQ,
                    params.getObjectId()
            )));
        }

        queryDTO.setWhere(where);

        //order by
        if(CollUtil.isNotEmpty(params.getOrderBys())){
            List<OrderByBean> orderBy=new ArrayList<>();
            params.getOrderBys().forEach(item->{
                orderBy.add(new OrderByBean(params.getTableId(),item.getPropCode(),item.getOrderByType()));
            });
            queryDTO.setOrderBy(orderBy);
        }


        IPage<Map<String, Object>> page= entityOperateApiService.query(queryDTO);
        return page;
    }


}
