package com.xxh.cloud.metadata.sys.manager.controller;


import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.biz.MetadataCategoryInfoBizService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategoryByIdDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategorySaveDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategoryTreeDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataCategoryUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.service.MetadataCategoryInfoService;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.MetadataStandardResultTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

//@SaCheckPermission("sys:metadata:categoryMetadata")
@Log4j2
@RestController
@RequestMapping("/sys/metadata/categoryMetadata")
@Api(tags = "运营端,元数据分类管理")
public class MetadataCategoryManagerController {

    @Autowired
    private MetadataCategoryInfoBizService metadataCategoryInfoService;


    @SaCheckPermission("sys:metadata:categoryMetadata:tree")
    @PostMapping("/tree")
    @ApiOperation(value = "元数据分类树", response = MetadataCategoryVO.class)
    public Result<List<MetadataCategoryVO>> tree(@RequestBody MetadataCategoryTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<MetadataCategoryVO> data= metadataCategoryInfoService.tree(params);
        return new Result<List<MetadataCategoryVO>>().ok(data);
    }

    @SaCheckPermission("sys:metadata:categoryMetadata:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = MetadataCategoryVO.class)
    public Result<MetadataCategoryVO> save(@RequestBody MetadataCategorySaveDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataCategoryVO data= metadataCategoryInfoService.save(params);
        return new Result<MetadataCategoryVO>().ok(data);
    }

    @SaCheckPermission("sys:metadata:categoryMetadata:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = MetadataCategoryVO.class)
    public Result<MetadataCategoryVO> update(@RequestBody MetadataCategoryUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataCategoryVO data=metadataCategoryInfoService.update(params);
        return new Result<MetadataCategoryVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:categoryMetadata:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody MetadataCategoryByIdDTO params) {
        ValidatorUtils.validateEntity(params);
        metadataCategoryInfoService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:metadata:categoryMetadata:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = MetadataCategoryVO.class)
    public  Result<MetadataCategoryVO> info(@RequestBody MetadataCategoryByIdDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataCategoryVO data= metadataCategoryInfoService.infoById(params.getId());
        return new Result<MetadataCategoryVO>().ok(data);
    }



}
