package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.util.StrUtil;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.biz.MetadataInfoBizService;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.MetadataInfoVO;
import com.xxh.cloud.metadata.framework.modules.base.service.MetadataInfoService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoByIdDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoQueryDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoSaveDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.MetadataInfoUpdateDTO;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.MetadataStandardTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

//@SaCheckPermission("sys:metadata:infoMetadata")
@Log4j2
@RestController
@RequestMapping("/sys/metadata/infoMetadata")
@Api(tags = "运营端,元数据管理")
public class MetadataManagerController {

    @Autowired
    private MetadataInfoBizService metadataInfoService;


//    @SaCheckPermission("sys:metadata:infoMetadata:getMetadataValueConfig")
//    @PostMapping("/getMetadataValueConfig")
//    @ApiOperation(value = "获取标准数据值配置", response = MetadataInfoVO.class)
//    public Result<PageData<MetadataInfoVO>> getMetadataValueConfig(@RequestBody MetadataInfoQueryDTO params) {
//        ValidatorUtils.validateEntity(params);
//
////        StrUtil.isNotEmpty()
//        return new Result<PageData<MetadataInfoVO>>().ok(null);
//    }


    @SaCheckPermission("sys:metadata:infoMetadata:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = MetadataInfoVO.class)
    public Result<PageData<MetadataInfoVO>> query(@RequestBody MetadataInfoQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<MetadataInfoVO> data= metadataInfoService.query(params);
        return new Result<PageData<MetadataInfoVO>>().ok(data);
    }


    @SaCheckPermission("sys:metadata:infoMetadata:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = MetadataInfoVO.class)
    public Result<MetadataInfoVO> save(@RequestBody MetadataInfoSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataInfoVO data= metadataInfoService.save(params);
        return new Result<MetadataInfoVO>().ok(data);
    }

    @SaCheckPermission("sys:metadata:infoMetadata:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = MetadataInfoVO.class)
    public Result<MetadataInfoVO> update(@RequestBody MetadataInfoUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataInfoVO data=metadataInfoService.update(params);
        return new Result<MetadataInfoVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:infoMetadata:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody MetadataInfoByIdDTO params) {
        ValidatorUtils.validateEntity(params);
        metadataInfoService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:metadata:infoMetadata:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = MetadataInfoVO.class)
    public  Result<MetadataInfoVO> info(@RequestBody MetadataInfoByIdDTO params) {
        ValidatorUtils.validateEntity(params);
        MetadataInfoVO data= metadataInfoService.infoById(params.getId());
        return new Result<MetadataInfoVO>().ok(data);
    }




}
