package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDeptVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDeptBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/dept")
@Api(tags = "运营端,标准部门(科室)管理")
public class StandardDeptManagerController {


    @Autowired
    private StandardDeptBizService standardDeptBizService;


    @SaCheckPermission("sys:standard:dept:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardDeptVO.class)
    public Result<PageData<StandardDeptVO>> query(@RequestBody StandardDeptQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardDeptVO> data=standardDeptBizService.query(params);
        return new Result<PageData<StandardDeptVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:dept:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardDeptVO.class)
    public Result<List<StandardDeptVO>> list(@RequestBody StandardDeptListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDeptVO> data=standardDeptBizService.list(params);
        return new Result<List<StandardDeptVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:dept:tree")
    @PostMapping("/stree")
    @ApiOperation(value = "标准树", response = StandardDeptVO.class)
    public Result<List<StandardDeptVO>> trees(@RequestBody StandardDeptListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDeptVO> data=standardDeptBizService.tree(params);
        return new Result<List<StandardDeptVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:dept:tree")
    @PostMapping("/tree")
    @ApiOperation(value = "树", response = StandardDeptVO.class)
    public Result<List<StandardDeptVO>> tree(@RequestBody StandardDeptListDTO params) {
        ValidatorUtils.validateEntity(params);
        //todo:从标准部门，更改到用户部门
        //List<StandardDeptVO> data=standardDeptBizService.tree(params);
        List<StandardDeptVO> data=standardDeptBizService.tree2SysDept(params);
        return new Result<List<StandardDeptVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:dept:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardDeptVO.class)
    public Result<StandardDeptVO> save(@RequestBody StandardDeptSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDeptVO data=standardDeptBizService.save(params);
        return new Result<StandardDeptVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:dept:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardDeptVO.class)
    public Result<StandardDeptVO> update(@RequestBody StandardDeptUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDeptVO data=standardDeptBizService.update(params);
        return new Result<StandardDeptVO>().ok(null);
    }


    @SaCheckPermission("sys:standard:dept:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardDeptGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDeptBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:dept:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardDeptVO.class)
    public  Result<StandardDeptVO> info(@RequestBody StandardDeptGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDeptVO data=standardDeptBizService.getById(params.getId());
        return new Result<StandardDeptVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:dept:info")
    @PostMapping("/detail")
    @ApiOperation(value = "详情", response = StandardDeptVO.class)
    public  Result<StandardDeptVO> detail(@RequestBody StandardDeptGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDeptVO data=standardDeptBizService.detail(params);
        return new Result<StandardDeptVO>().ok(data);
    }


}
