package com.xxh.cloud.metadata.sys.manager.controller;


import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.util.StrUtil;

import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseFullVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/disease")
@Api(tags = "运营端,标准疾病(诊断)管理")
public class StandardDiseaseManagerController {

    @Autowired
    private StandardDiseaseBizService standardDiseaseBizService;

    @SaCheckPermission("sys:standard:disease:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardDiseaseVO.class)
    public Result<PageData<StandardDiseaseVO>> query(@RequestBody StandardDiseaseQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardDiseaseVO> data=standardDiseaseBizService.query(params);
        return new Result<PageData<StandardDiseaseVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:disease:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardDiseaseVO.class)
    public Result<List<StandardDiseaseVO>> list(@RequestBody StandardDiseaseListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseVO> data=standardDiseaseBizService.list(params);
        return new Result<List<StandardDiseaseVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:disease:tree")
    @PostMapping("/tree")
    @ApiOperation(value = "树", response = StandardDiseaseVO.class)
    public Result<List<StandardDiseaseVO>> tree(@RequestBody StandardDiseaseTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseVO> data=standardDiseaseBizService.tree(params);
        return new Result<List<StandardDiseaseVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:disease:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardDiseaseVO.class)
    public Result<StandardDiseaseVO> save(@RequestBody StandardDiseaseSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseVO data=standardDiseaseBizService.save(params);
        return new Result<StandardDiseaseVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:disease:saveFull")
    @PostMapping("/saveFull")
    @ApiOperation(value = "新增[含关联]", response = StandardDiseaseVO.class)
    public Result<StandardDiseaseVO> saveFull(@RequestBody StandardDiseaseSaveFullDTO params) {
        ValidatorUtils.validateEntity(params);
        if (StrUtil.isBlank(params.getDiseaseInfo().getProjectCode())) {
            params.getDiseaseInfo().setProjectCode("WBMD");
        }
        StandardDiseaseVO data=standardDiseaseBizService.saveFull(params);
        return new Result<StandardDiseaseVO>().ok(data);
    }



    @SaCheckPermission("sys:standard:disease:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardDiseaseVO.class)
    public Result<StandardDiseaseVO> update(@RequestBody StandardDiseaseUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseVO data=standardDiseaseBizService.update(params);
        return new Result<StandardDiseaseVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:disease:updateFull")
    @PostMapping("/updateFull")
    @ApiOperation(value = "修改[含关联]", response = StandardDiseaseVO.class)
    public Result<StandardDiseaseVO> updateFull(@RequestBody StandardDiseaseUpdateFullDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseVO data=standardDiseaseBizService.updateFull(params);
        return new Result<StandardDiseaseVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:disease:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardDiseaseGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDiseaseBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:disease:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardDiseaseVO.class)
    public  Result<StandardDiseaseVO> info(@RequestBody StandardDiseaseGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseVO data=standardDiseaseBizService.getById(params.getId());
        return new Result<StandardDiseaseVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:disease:infoFull")
    @PostMapping("/infoFull")
    @ApiOperation(value = "获取[含关联]", response = StandardDiseaseFullVO.class)
    public  Result<StandardDiseaseFullVO> infoFull(@RequestBody StandardDiseaseGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseFullVO data=standardDiseaseBizService.getFullById(params.getId());
        return new Result<StandardDiseaseFullVO>().ok(data);
    }





}
