package com.xxh.cloud.metadata.sys.manager.controller;


import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.util.StrUtil;

import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.common.constant.enums.RuleCondtionDataTypeEnum;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseDiagnosisVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseIcdVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseRelationBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/relation/disease")
@Api(tags = "运营端,标准疾病(诊断)关联管理")
public class StandardDiseaseRelationManagerController {


    @Autowired
    private StandardDiseaseRelationBizService standardDiseaseRelationBizService;



    @SaCheckPermission("sys:standard:relation:disease:queryDiagnosis")
    @PostMapping("/queryDiagnosis")
    @ApiOperation(value = "诊断依据查询", response = StandardDiseaseDiagnosisVO.class)
    public Result<PageData<StandardDiseaseDiagnosisVO>> queryDiagnosis(@RequestBody StandardDiseaseDiagnosisPageDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardDiseaseDiagnosisVO>  data = standardDiseaseRelationBizService.queryRelDiagnosis(params);
        return new Result<PageData<StandardDiseaseDiagnosisVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:relation:disease:listDiagnosis")
    @PostMapping("/listDiagnosis")
    @ApiOperation(value = "诊断依据列表", response = StandardDiseaseDiagnosisVO.class)
    public Result<List<StandardDiseaseDiagnosisVO>> listDiagnosis(@RequestBody StandardDiseaseDiagnosisListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseDiagnosisVO> data = standardDiseaseRelationBizService.listRelDiagnosis(params);
        return new Result<List<StandardDiseaseDiagnosisVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:relation:disease:addDiagnosis")
    @PostMapping("/addDiagnosis")
    @ApiOperation(value = "诊断依据新增", response = String.class)
    public Result<String> addDiagnosis(@RequestBody StandardDiseaseDiagnosisAddDTO params) {
        ValidatorUtils.validateEntity(params);
        if (StrUtil.isBlank(params.getProjectCode())) {
            params.setProjectCode("WBMD");
        }
        standardDiseaseRelationBizService.addRelDiagnosis(params);
        return new Result<String>().ok("ok");
    }


    @SaCheckPermission("sys:standard:relation:disease:addBatchDiagnosis")
    @PostMapping("/addBatchDiagnosis")
    @ApiOperation(value = "诊断依据批量新增", response = String.class)
    public Result<String> addBatchDiagnosis(@RequestBody StandardDiseaseDiagnosisAddBatchDTO params) {
        ValidatorUtils.validateEntity(params);
        params.getItems().forEach(item -> {
            if (StrUtil.isBlank(item.getProjectCode())) {
                item.setProjectCode("WBMD");
            }
        });


        standardDiseaseRelationBizService.addBatchRelDiagnosis(params);
        return new Result<String>().ok("ok");
    }


    @SaCheckPermission("sys:standard:relation:disease:delRelDiagnosisById")
    @PostMapping("/delRelDiagnosisById")
    @ApiOperation(value = "诊断依据删除", response = String.class)
    public Result<String> delRelDiagnosisById(@RequestBody StandardDiseaseDiagnosisGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDiseaseRelationBizService.delRelDiagnosisById(params.getId());
        return new Result<String>().ok("ok");
    }



    @SaCheckPermission("sys:standard:relation:disease:delBatchRelDiagnosisById")
    @PostMapping("/delBatchRelDiagnosisById")
    @ApiOperation(value = "诊断依据批量删除", response = String.class)
    public Result<String> delBatchRelDiagnosisById(@RequestBody StandardDiseaseDiagnosisGetBatchDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDiseaseRelationBizService.delRelDiagnosisByIds(params.getIds());
        return new Result<String>().ok("ok");
    }



    @SaCheckPermission("sys:standard:relation:disease:getRelDiagnosisById")
    @PostMapping("/getRelDiagnosisById")
    @ApiOperation(value = "诊断依据获取", response = StandardDiseaseDiagnosisVO.class)
    public Result<StandardDiseaseDiagnosisVO> getRelDiagnosisById(@RequestBody StandardDiseaseDiagnosisGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseDiagnosisVO data= standardDiseaseRelationBizService.getRelDiagnosisById(params.getId());
        return new Result<StandardDiseaseDiagnosisVO>().ok(data);
    }

    //===============================================================================

    @SaCheckPermission("sys:standard:relation:disease:queryRelICD")
    @PostMapping("/queryRelICD")
    @ApiOperation(value = "关联ICD查询", response = StandardDiseaseIcdVO.class)
    public Result<PageData<StandardDiseaseIcdVO>> queryRelICD(@RequestBody StandardDiseaseIcdPageDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardDiseaseIcdVO>  data = standardDiseaseRelationBizService.queryRelIdc(params);
        return new Result<PageData<StandardDiseaseIcdVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:relation:disease:listRelICD")
    @PostMapping("/listRelICD")
    @ApiOperation(value = "关联ICD列表", response = StandardDiseaseIcdVO.class)
    public Result<List<StandardDiseaseIcdVO>> listRelICD(@RequestBody StandardDiseaseIcdListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseIcdVO> data = standardDiseaseRelationBizService.listRelIdc(params);
        return new Result<List<StandardDiseaseIcdVO>>().ok(data);
    }



    @SaCheckPermission("sys:standard:relation:disease:addRelICD")
    @PostMapping("/addRelICD")
    @ApiOperation(value = "关联ICD新增", response = String.class)
    public Result<String> addRelICD(@RequestBody StandardDiseaseIcdAddDTO params) {
        ValidatorUtils.validateEntity(params);
        if (StrUtil.isBlank(params.getProjectCode())) {
            params.setProjectCode("WBMD");
        }
        standardDiseaseRelationBizService.addRelIdc(params);
        return new Result<String>().ok("ok");
    }


    @SaCheckPermission("sys:standard:relation:disease:addBatchRelICD")
    @PostMapping("/addBatchRelICD")
    @ApiOperation(value = "关联ICD批量新增", response = String.class)
    public Result<String> addBatchRelICD(@RequestBody StandardDiseaseIcdAddBatchDTO params) {
        ValidatorUtils.validateEntity(params);
        params.getItems().forEach(item -> {
            if (StrUtil.isBlank(item.getProjectCode())) {
                item.setProjectCode("WBMD");
            }
        });
        standardDiseaseRelationBizService.addBatchRelIdc(params);
        return new Result<String>().ok("ok");
    }


    @SaCheckPermission("sys:standard:relation:disease:delRelICDById")
    @PostMapping("/delRelICDById")
    @ApiOperation(value = "关联ICD删除", response = String.class)
    public Result<String> delRelICDById(@RequestBody StandardDiseaseIcdGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDiseaseRelationBizService.delRelIdcById(params.getId());
        return new Result<String>().ok("ok");
    }



    @SaCheckPermission("sys:standard:relation:disease:delBatchRelICDById")
    @PostMapping("/delBatchRelICDById")
    @ApiOperation(value = "关联ICD批量删除", response = String.class)
    public Result<String> delBatchRelICDById(@RequestBody StandardDiseaseIcdGetBatchDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDiseaseRelationBizService.delRelIdcByIds(params.getIds());
        return new Result<String>().ok("ok");
    }



    @SaCheckPermission("sys:standard:relation:disease:getRelICDById")
    @PostMapping("/getRelICDById")
    @ApiOperation(value = "关联ICD获取", response = StandardDiseaseIcdVO.class)
    public Result<StandardDiseaseIcdVO> getRelICDById(@RequestBody StandardDiseaseIcdGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseIcdVO data= standardDiseaseRelationBizService.getRelIdcById(params.getId());
        return new Result<StandardDiseaseIcdVO>().ok(data);
    }













}
