package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseSystemVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardDiseaseSystemBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/systemDisease")
@Api(tags = "运营端,标准疾病系统管理")
public class StandardDiseaseSystemManagerController {

    @Autowired
    private StandardDiseaseSystemBizService standardDiseaseSystemBizService;



    @SaCheckPermission("sys:standard:systemDisease:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardMedicantVO.class)
    public Result<PageData<StandardDiseaseSystemVO>> query(@RequestBody StandardSystemDiseaseQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardDiseaseSystemVO> data = standardDiseaseSystemBizService.query(params);
        return new Result<PageData<StandardDiseaseSystemVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:systemDisease:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardMedicantVO.class)
    public Result<List<StandardDiseaseSystemVO>> list(@RequestBody StandardSystemDiseaseListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardDiseaseSystemVO> data=standardDiseaseSystemBizService.list(params);
        return new Result<List<StandardDiseaseSystemVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:systemDisease:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardDiseaseSystemVO.class)
    public Result<StandardDiseaseSystemVO> save(@RequestBody StandardSystemDiseaseSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseSystemVO data= standardDiseaseSystemBizService.save(params);
        return new Result<StandardDiseaseSystemVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:systemDisease:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardDiseaseSystemVO.class)
    public Result<StandardDiseaseSystemVO> update(@RequestBody StandardSystemDiseaseUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseSystemVO data=  standardDiseaseSystemBizService.update(params);
        return new Result<StandardDiseaseSystemVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:systemDisease:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardSystemDiseaseGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardDiseaseSystemBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:systemDisease:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardDiseaseSystemVO.class)
    public  Result<StandardDiseaseSystemVO> info(@RequestBody StandardSystemDiseaseGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardDiseaseSystemVO data=  standardDiseaseSystemBizService.getById(params.getId());
        return new Result<StandardDiseaseSystemVO>().ok(data);
    }

}
