package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardEventVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardEventBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/event")
@Api(tags = "运营端,标准事件管理")
public class StandardEventManagerController {

    @Autowired
    private StandardEventBizService standardEventBizService;


    @SaCheckPermission("sys:standard:event:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardEventVO.class)
    public Result<PageData<StandardEventVO>> query(@RequestBody StandardEventQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardEventVO> data = standardEventBizService.query(params);
        return new Result<PageData<StandardEventVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:event:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardMedicantVO.class)
    public Result<List<StandardEventVO>> list(@RequestBody StandardEventListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardEventVO> data=standardEventBizService.list(params);
        return new Result<List<StandardEventVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:event:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardEventVO.class)
    public Result<StandardEventVO> save(@RequestBody StandardEventSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardEventVO data= standardEventBizService.save(params);
        return new Result<StandardEventVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:event:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardEventVO.class)
    public Result<StandardEventVO> update(@RequestBody StandardEventUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardEventVO data=  standardEventBizService.update(params);
        return new Result<StandardEventVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:event:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardEventGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardEventBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:event:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardEventVO.class)
    public  Result<StandardEventVO> info(@RequestBody StandardEventGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardEventVO data=  standardEventBizService.getById(params.getId());
        return new Result<StandardEventVO>().ok(data);
    }


}
