package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardExamineNameVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardExamineProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardExamineNameBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/examineName")
@Api(tags = "运营端,标准检查项目名称管理")
public class StandardExamineNameManagerController {

    @Autowired
    private StandardExamineNameBizService standardExamineNameBizService;



    @SaCheckPermission("sys:standard:examineName:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardExamineNameVO.class)
    public Result<PageData<StandardExamineNameVO>> query(@RequestBody StandardExamineNameQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardExamineNameVO> data = standardExamineNameBizService.query(params);
        return new Result<PageData<StandardExamineNameVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:examineName:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardExamineNameVO.class)
    public Result<List<StandardExamineNameVO>> list(@RequestBody StandardExamineNameListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardExamineNameVO> data=standardExamineNameBizService.list(params);
        return new Result<List<StandardExamineNameVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:examineName:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardExamineNameVO.class)
    public Result<StandardExamineNameVO> save(@RequestBody StandardExamineNameSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineNameVO data= standardExamineNameBizService.save(params);
        return new Result<StandardExamineNameVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:examineName:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardExamineNameVO.class)
    public Result<StandardExamineNameVO> update(@RequestBody StandardExamineNameUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineNameVO data=  standardExamineNameBizService.update(params);
        return new Result<StandardExamineNameVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:examineName:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardExamineNameGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardExamineNameBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:examineName:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardExamineNameVO.class)
    public  Result<StandardExamineNameVO> info(@RequestBody StandardExamineNameGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineNameVO data=  standardExamineNameBizService.getById(params.getId());
        return new Result<StandardExamineNameVO>().ok(data);
    }


}
