package com.xxh.cloud.metadata.sys.manager.controller;


import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardExamineProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardExamineProjectBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/examineProject")
@Api(tags = "运营端,标准检查项目管理")
public class StandardExamineProjectManagerController {

    @Autowired
    private StandardExamineProjectBizService standardExamineProjectBizService;



    @SaCheckPermission("sys:standard:examineProject:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardExamineProjectVO.class)
    public Result<PageData<StandardExamineProjectVO>> query(@RequestBody StandardExamineProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardExamineProjectVO> data = standardExamineProjectBizService.query(params);
        return new Result<PageData<StandardExamineProjectVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:examineProject:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardExamineProjectVO.class)
    public Result<List<StandardExamineProjectVO>> list(@RequestBody StandardExamineProjectListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardExamineProjectVO> data=standardExamineProjectBizService.list(params);
        return new Result<List<StandardExamineProjectVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:examineProject:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardExamineProjectVO.class)
    public Result<StandardExamineProjectVO> save(@RequestBody StandardExamineProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectVO data= standardExamineProjectBizService.save(params);
        return new Result<StandardExamineProjectVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:examineProject:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardExamineProjectVO.class)
    public Result<StandardExamineProjectVO> update(@RequestBody StandardExamineProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectVO data=  standardExamineProjectBizService.update(params);
        return new Result<StandardExamineProjectVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:examineProject:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardExamineProjectGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardExamineProjectBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:examineProject:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardExamineProjectVO.class)
    public  Result<StandardExamineProjectVO> info(@RequestBody StandardExamineProjectGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardExamineProjectVO data=  standardExamineProjectBizService.getById(params.getId());
        return new Result<StandardExamineProjectVO>().ok(data);
    }

}
