package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardFeeGroupVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardFeeGroupBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/feeGroup")
@Api(tags = "运营端,标准收费项目组套管理")
public class StandardFeeGroupManagerController {


    @Autowired
    private StandardFeeGroupBizService standardFeeGroupBizService;


    @SaCheckPermission("sys:standard:feeGroup:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardFeeGroupVO.class)
    public Result<PageData<StandardFeeGroupVO>> query(@RequestBody StandardFeeGroupQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardFeeGroupVO> data = standardFeeGroupBizService.query(params);
        return new Result<PageData<StandardFeeGroupVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:feeGroup:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardFeeGroupVO.class)
    public Result<List<StandardFeeGroupVO>> list(@RequestBody StandardFeeGroupListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardFeeGroupVO> data=standardFeeGroupBizService.list(params);
        return new Result<List<StandardFeeGroupVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:feeGroup:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardFeeGroupVO.class)
    public Result<StandardFeeGroupVO> save(@RequestBody StandardFeeGroupSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeGroupVO data= standardFeeGroupBizService.save(params);
        return new Result<StandardFeeGroupVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:feeGroup:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardFeeGroupVO.class)
    public Result<StandardFeeGroupVO> update(@RequestBody StandardFeeGroupUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeGroupVO data=  standardFeeGroupBizService.update(params);
        return new Result<StandardFeeGroupVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:feeGroup:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardFeeGroupGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardFeeGroupBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:feeGroup:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardFeeGroupVO.class)
    public  Result<StandardFeeGroupVO> info(@RequestBody StandardFeeGroupGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeGroupVO data=  standardFeeGroupBizService.getById(params.getId());
        return new Result<StandardFeeGroupVO>().ok(data);
    }



}
