package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardFeeProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardFeeProjectBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/feeProject")
@Api(tags = "运营端,标准收费项目管理")
public class StandardFeeProjectManagerController {

    @Autowired
    private StandardFeeProjectBizService standardFeeProjectBizService;


    @SaCheckPermission("sys:standard:feeProject:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardFeeProjectVO.class)
    public Result<PageData<StandardFeeProjectVO>> query(@RequestBody StandardFeeProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardFeeProjectVO> data = standardFeeProjectBizService.query(params);
        return new Result<PageData<StandardFeeProjectVO>>().ok(data);
    }




    @SaCheckPermission("sys:standard:feeProject:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardFeeProjectVO.class)
    public Result<List<StandardFeeProjectVO>> list(@RequestBody StandardFeeProjectListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardFeeProjectVO> data=standardFeeProjectBizService.list(params);
        return new Result<List<StandardFeeProjectVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:feeProject:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardFeeProjectVO.class)
    public Result<StandardFeeProjectVO> save(@RequestBody StandardFeeProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeProjectVO data= standardFeeProjectBizService.save(params);
        return new Result<StandardFeeProjectVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:feeProject:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardFeeProjectVO.class)
    public Result<StandardFeeProjectVO> update(@RequestBody StandardFeeProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeProjectVO data=  standardFeeProjectBizService.update(params);
        return new Result<StandardFeeProjectVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:feeProject:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardFeeProjectGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardFeeProjectBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:feeProject:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardFeeProjectVO.class)
    public  Result<StandardFeeProjectVO> info(@RequestBody StandardFeeProjectGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardFeeProjectVO data=  standardFeeProjectBizService.getById(params.getId());
        return new Result<StandardFeeProjectVO>().ok(data);
    }



}
