package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.exception.BusinessBaseErrorEnum;
import com.xxh.cloud.framework.common.exception.BusinessException;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.ql.QLExpressHelper;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardKeywordsTypeVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardKeywordsVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardKeywordsBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/keywords")
@Api(tags = "运营端,标准关键字管理")
public class StandardKeywordsManagerController {

    @Autowired
    private StandardKeywordsBizService standardKeywordsBizService;



    @SaCheckPermission("sys:standard:keywords:typeTree")
    @PostMapping("/typeTree")
    @ApiOperation(value = "关键字分类树", response = StandardKeywordsVO.class)
    public Result<List<StandardKeywordsTypeVO>> typeTree() {

        List<StandardKeywordsTypeVO> data=new ArrayList<>();

        StandardKeywordsTypeVO one=new StandardKeywordsTypeVO("检查报告","检查报告");

        StandardKeywordsTypeVO one1=new StandardKeywordsTypeVO("心电图","心电图");
        one1.addChild(new StandardKeywordsTypeVO("报告提示","报告提示"));
        one1.addChild(new StandardKeywordsTypeVO("报告所见","报告所见"));

        StandardKeywordsTypeVO one2=new StandardKeywordsTypeVO("X线","X线");
        one2.addChild(new StandardKeywordsTypeVO("报告提示","报告提示"));
        one2.addChild(new StandardKeywordsTypeVO("报告所见","报告所见"));

        StandardKeywordsTypeVO one3=new StandardKeywordsTypeVO("CT","CT");
        one3.addChild(new StandardKeywordsTypeVO("报告提示","报告提示"));
        one3.addChild(new StandardKeywordsTypeVO("报告所见","报告所见"));

        one.addChild(one1);
        one.addChild(one2);
        one.addChild(one3);

        StandardKeywordsTypeVO two=new StandardKeywordsTypeVO("病理报告","病理报告");


        StandardKeywordsTypeVO three=new StandardKeywordsTypeVO("出院","出院");
        three.addChild(new StandardKeywordsTypeVO("主诊断","主诊断"));
        three.addChild(new StandardKeywordsTypeVO("预诊断","预诊断"));

        StandardKeywordsTypeVO four=new StandardKeywordsTypeVO("出院小结","出院小结");


        data.add(one);
        data.add(two);
        data.add(three);
        data.add(four);

        return new Result<List<StandardKeywordsTypeVO>>().ok(data);
    }



    @SaCheckPermission("sys:standard:keywords:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardKeywordsVO.class)
    public Result<PageData<StandardKeywordsVO>> query(@RequestBody StandardKeywordsQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardKeywordsVO> data = standardKeywordsBizService.query(params);
        return new Result<PageData<StandardKeywordsVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:keywords:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardKeywordsVO.class)
    public Result<List<StandardKeywordsVO>> list(@RequestBody StandardKeywordsListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardKeywordsVO> data=standardKeywordsBizService.list(params);
        return new Result<List<StandardKeywordsVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:keywords:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardKeywordsVO.class)
    public Result<StandardKeywordsVO> save(@RequestBody StandardKeywordsSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        boolean flag= QLExpressHelper.parseScript(params.getRegExp());
        if(flag==false){
            throw new BusinessException(BusinessBaseErrorEnum.Config_QL_ERROR);
        }
        StandardKeywordsVO data= standardKeywordsBizService.save(params);
        return new Result<StandardKeywordsVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:keywords:run")
    @PostMapping("/run")
    @ApiOperation(value = "执行QL规则", response = Boolean.class)
    public Result<Boolean> run(@RequestBody StandardKeywordsRunDTO params) {
        ValidatorUtils.validateEntity(params);
        boolean flag= QLExpressHelper.parseScript(params.getRegExp());
        if(flag==false){
            throw new BusinessException(BusinessBaseErrorEnum.Config_QL_ERROR);
        }
        boolean data= QLExpressHelper.execute(params.getRegExp(),params.getContent());
        return new Result<Boolean>().ok(data);
    }


    @SaCheckPermission("sys:standard:keywords:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardKeywordsVO.class)
    public Result<StandardKeywordsVO> update(@RequestBody StandardKeywordsUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardKeywordsVO data=  standardKeywordsBizService.update(params);
        return new Result<StandardKeywordsVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:keywords:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardKeywordsGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardKeywordsBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:keywords:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardKeywordsVO.class)
    public  Result<StandardKeywordsVO> info(@RequestBody StandardKeywordsGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardKeywordsVO data=  standardKeywordsBizService.getById(params.getId());
        return new Result<StandardKeywordsVO>().ok(data);
    }





}
