package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardLaboratoryGroupVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardLaboratoryGroupBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/laboratoryGroup")
@Api(tags = "运营端,标准检验组套管理")
public class StandardLaboratoryGroupManagerController {

    @Autowired
    private StandardLaboratoryGroupBizService standardLaboratoryGroupBizService;




    @SaCheckPermission("sys:standard:laboratoryGroup:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardLaboratoryGroupVO.class)
    public Result<PageData<StandardLaboratoryGroupVO>> query(@RequestBody StandardLaboratoryGroupQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardLaboratoryGroupVO> data = standardLaboratoryGroupBizService.query(params);
        return new Result<PageData<StandardLaboratoryGroupVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryGroup:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardLaboratoryGroupVO.class)
    public Result<List<StandardLaboratoryGroupVO>> list(@RequestBody StandardLaboratoryGroupListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardLaboratoryGroupVO> data=standardLaboratoryGroupBizService.list(params);
        return new Result<List<StandardLaboratoryGroupVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryGroup:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardLaboratoryGroupVO.class)
    public Result<StandardLaboratoryGroupVO> save(@RequestBody StandardLaboratoryGroupSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryGroupVO data= standardLaboratoryGroupBizService.save(params);
        return new Result<StandardLaboratoryGroupVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:laboratoryGroup:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardLaboratoryGroupVO.class)
    public Result<StandardLaboratoryGroupVO> update(@RequestBody StandardLaboratoryGroupUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryGroupVO data=  standardLaboratoryGroupBizService.update(params);
        return new Result<StandardLaboratoryGroupVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryGroup:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardLaboratoryGroupGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardLaboratoryGroupBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:laboratoryGroup:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardLaboratoryGroupVO.class)
    public  Result<StandardLaboratoryGroupVO> info(@RequestBody StandardLaboratoryGroupGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryGroupVO data=  standardLaboratoryGroupBizService.getById(params.getId());
        return new Result<StandardLaboratoryGroupVO>().ok(data);
    }

}
