package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardLaboratoryProjectVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardLaboratoryProjectBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/laboratoryProject")
@Api(tags = "运营端,标准检验项目管理")
public class StandardLaboratoryProjectManagerController {

    @Autowired
    private StandardLaboratoryProjectBizService standardLaboratoryProjectBizService;



    @SaCheckPermission("sys:standard:laboratoryProject:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardLaboratoryProjectVO.class)
    public Result<PageData<StandardLaboratoryProjectVO>> query(@RequestBody StandardLaboratoryProjectQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardLaboratoryProjectVO> data = standardLaboratoryProjectBizService.query(params);
        return new Result<PageData<StandardLaboratoryProjectVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryProject:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardLaboratoryProjectVO.class)
    public Result<List<StandardLaboratoryProjectVO>> list(@RequestBody StandardLaboratoryProjectListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardLaboratoryProjectVO> data=standardLaboratoryProjectBizService.list(params);
        return new Result<List<StandardLaboratoryProjectVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryProject:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardLaboratoryProjectVO.class)
    public Result<StandardLaboratoryProjectVO> save(@RequestBody StandardLaboratoryProjectSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryProjectVO data= standardLaboratoryProjectBizService.save(params);
        return new Result<StandardLaboratoryProjectVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:laboratoryProject:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardLaboratoryProjectVO.class)
    public Result<StandardLaboratoryProjectVO> update(@RequestBody StandardLaboratoryProjectUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryProjectVO data=  standardLaboratoryProjectBizService.update(params);
        return new Result<StandardLaboratoryProjectVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryProject:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardLaboratoryProjectGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardLaboratoryProjectBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:laboratoryProject:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardLaboratoryProjectVO.class)
    public  Result<StandardLaboratoryProjectVO> info(@RequestBody StandardLaboratoryProjectGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryProjectVO data=  standardLaboratoryProjectBizService.getById(params.getId());
        return new Result<StandardLaboratoryProjectVO>().ok(data);
    }



}
