package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardLaboratoryTypeVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardLaboratoryTypeBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/laboratoryType")
@Api(tags = "运营端,标准检验分类管理")
public class StandardLaboratoryTypeManagerController {

    @Autowired
    private StandardLaboratoryTypeBizService standardLaboratoryTypeBizService;




    @SaCheckPermission("sys:standard:laboratoryType:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardLaboratoryTypeVO.class)
    public Result<PageData<StandardLaboratoryTypeVO>> query(@RequestBody StandardLaboratoryTypeQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardLaboratoryTypeVO> data = standardLaboratoryTypeBizService.query(params);
        return new Result<PageData<StandardLaboratoryTypeVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryType:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardLaboratoryTypeVO.class)
    public Result<List<StandardLaboratoryTypeVO>> list(@RequestBody StandardLaboratoryTypeListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardLaboratoryTypeVO> data=standardLaboratoryTypeBizService.list(params);
        return new Result<List<StandardLaboratoryTypeVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryType:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardLaboratoryTypeVO.class)
    public Result<StandardLaboratoryTypeVO> save(@RequestBody StandardLaboratoryTypeSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryTypeVO data= standardLaboratoryTypeBizService.save(params);
        return new Result<StandardLaboratoryTypeVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:laboratoryType:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardLaboratoryTypeVO.class)
    public Result<StandardLaboratoryTypeVO> update(@RequestBody StandardLaboratoryTypeUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryTypeVO data= standardLaboratoryTypeBizService.update(params);
        return new Result<StandardLaboratoryTypeVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:laboratoryType:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardLaboratoryTypeGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardLaboratoryTypeBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:laboratoryType:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardLaboratoryTypeVO.class)
    public  Result<StandardLaboratoryTypeVO> info(@RequestBody StandardLaboratoryTypeGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardLaboratoryTypeVO data=  standardLaboratoryTypeBizService.getById(params.getId());
        return new Result<StandardLaboratoryTypeVO>().ok(data);
    }

}
