package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.util.StrUtil;

import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantDrugRelVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardMedicantDrugRelBizService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/relation/medicant")
@Api(tags = "运营端,标准药物关联医院药品管理")
public class StandardMedicantDrugRelManagerController {

    @Autowired
    private StandardMedicantDrugRelBizService standardMedicantDrugRelBizService;


    @SaCheckPermission("sys:standard:relation:medicant:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardMedicantDrugRelVO.class)
    public Result<PageData<StandardMedicantDrugRelVO>> query(@RequestBody StandardMedicantDrugRelQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardMedicantDrugRelVO> data = standardMedicantDrugRelBizService.query(params);
        return new Result<PageData<StandardMedicantDrugRelVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:relation:medicant:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardMedicantDrugRelVO.class)
    public Result<List<StandardMedicantDrugRelVO>> list(@RequestBody StandardMedicantDrugRelListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardMedicantDrugRelVO> data=standardMedicantDrugRelBizService.list(params);
        return new Result<List<StandardMedicantDrugRelVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:relation:medicant:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardMedicantDrugRelVO.class)
    public Result<StandardMedicantDrugRelVO> save(@RequestBody StandardMedicantDrugRelSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        if (StrUtil.isBlank(params.getProjectCode())) {
            params.setProjectCode("WBMD");
        }
        StandardMedicantDrugRelVO data= standardMedicantDrugRelBizService.save(params);
        return new Result<StandardMedicantDrugRelVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:relation:medicant:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardMedicantDrugRelVO.class)
    public Result<StandardMedicantDrugRelVO> update(@RequestBody StandardMedicantDrugRelUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        if (StrUtil.isBlank(params.getProjectCode())) {
            params.setProjectCode("WBMD");
        }
        StandardMedicantDrugRelVO data=  standardMedicantDrugRelBizService.update(params);
        return new Result<StandardMedicantDrugRelVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:relation:medicant:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardMedicantDrugRelGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardMedicantDrugRelBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:relation:medicant:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardMedicantDrugRelVO.class)
    public  Result<StandardMedicantDrugRelVO> info(@RequestBody StandardMedicantDrugRelGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantDrugRelVO data=  standardMedicantDrugRelBizService.getById(params.getId());
        return new Result<StandardMedicantDrugRelVO>().ok(data);
    }

}
