package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardMedicantVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardMedicantBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/medicant")
@Api(tags = "运营端,标准药物管理")
public class StandardMedicantManagerController {

    @Autowired
    private StandardMedicantBizService standardMedicantBizService;



    @SaCheckPermission("sys:standard:medicant:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardMedicantVO.class)
    public Result<PageData<StandardMedicantVO>> query(@RequestBody StandardMedicantQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardMedicantVO> data = standardMedicantBizService.query(params);
        return new Result<PageData<StandardMedicantVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:medicant:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardMedicantVO.class)
    public Result<List<StandardMedicantVO>> list(@RequestBody StandardMedicantListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardMedicantVO> data=standardMedicantBizService.list(params);
        return new Result<List<StandardMedicantVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:medicant:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardMedicantVO.class)
    public Result<StandardMedicantVO> save(@RequestBody StandardMedicantSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantVO data= standardMedicantBizService.save(params);
        return new Result<StandardMedicantVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:medicant:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardMedicantVO.class)
    public Result<StandardMedicantVO> update(@RequestBody StandardMedicantUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantVO data=  standardMedicantBizService.update(params);
        return new Result<StandardMedicantVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:medicant:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardMedicantGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardMedicantBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:medicant:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardMedicantVO.class)
    public  Result<StandardMedicantVO> info(@RequestBody StandardMedicantGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardMedicantVO data=  standardMedicantBizService.getById(params.getId());
        return new Result<StandardMedicantVO>().ok(data);
    }

}
