package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardOperationVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardOperationBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Log4j2
@RestController
@RequestMapping("/sys/standard/operation")
@Api(tags = "运营端,标准手术管理")
public class StandardOperationManagerController {

    @Autowired
    private StandardOperationBizService standardOperationBizService;


    @SaCheckPermission("sys:standard:operation:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardOperationVO.class)
    public Result<PageData<StandardOperationVO>> query(@RequestBody StandardOperationQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardOperationVO> data = standardOperationBizService.query(params);
        return new Result<PageData<StandardOperationVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:operation:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardOperationVO.class)
    public Result<List<StandardOperationVO>> list(@RequestBody StandardOperationListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardOperationVO> data=standardOperationBizService.list(params);
        return new Result<List<StandardOperationVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:operation:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardOperationVO.class)
    public Result<StandardOperationVO> save(@RequestBody StandardOperationSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardOperationVO data= standardOperationBizService.save(params);
        return new Result<StandardOperationVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:operation:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardOperationVO.class)
    public Result<StandardOperationVO> update(@RequestBody StandardOperationUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardOperationVO data=  standardOperationBizService.update(params);
        return new Result<StandardOperationVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:operation:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardOperationGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardOperationBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:operation:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardOperationVO.class)
    public  Result<StandardOperationVO> info(@RequestBody StandardOperationGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardOperationVO data=  standardOperationBizService.getById(params.getId());
        return new Result<StandardOperationVO>().ok(data);
    }



}
