package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardSampleVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardSampleBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/sample")
@Api(tags = "运营端,标准样本类型管理")
public class StandardSampleManagerController {

    @Autowired
    private StandardSampleBizService standardSampleBizService;



    @SaCheckPermission("sys:standard:sample:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardSampleVO.class)
    public Result<PageData<StandardSampleVO>> query(@RequestBody StandardSampleQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardSampleVO> data = standardSampleBizService.query(params);
        return new Result<PageData<StandardSampleVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:sample:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardSampleVO.class)
    public Result<List<StandardSampleVO>> list(@RequestBody StandardSampleListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSampleVO> data=standardSampleBizService.list(params);
        return new Result<List<StandardSampleVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:sample:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardSampleVO.class)
    public Result<StandardSampleVO> save(@RequestBody StandardSampleSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSampleVO data= standardSampleBizService.save(params);
        return new Result<StandardSampleVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:sample:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardSampleVO.class)
    public Result<StandardSampleVO> update(@RequestBody StandardSampleUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSampleVO data=  standardSampleBizService.update(params);
        return new Result<StandardSampleVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:sample:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardSampleGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardSampleBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:sample:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardSampleVO.class)
    public  Result<StandardSampleVO> info(@RequestBody StandardSampleGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSampleVO data=  standardSampleBizService.getById(params.getId());
        return new Result<StandardSampleVO>().ok(data);
    }


}
