package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardSourceVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardSourceBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/source")
@Api(tags = "运营端,数据来源管理")
public class StandardSourceManagerController {


    @Autowired
    private StandardSourceBizService standardSourceBizService;



    @SaCheckPermission("sys:standard:source:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardSourceVO.class)
    public Result<PageData<StandardSourceVO>> query(@RequestBody StandardSourceQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardSourceVO> data = standardSourceBizService.query(params);
        return new Result<PageData<StandardSourceVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:source:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardSourceVO.class)
    public Result<List<StandardSourceVO>> list(@RequestBody StandardSourceListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSourceVO> data=standardSourceBizService.list(params);
        return new Result<List<StandardSourceVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:source:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardSourceVO.class)
    public Result<StandardSourceVO> save(@RequestBody StandardSourceSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSourceVO data= standardSourceBizService.save(params);
        return new Result<StandardSourceVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:source:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardSourceVO.class)
    public Result<StandardSourceVO> update(@RequestBody StandardSourceUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSourceVO data=  standardSourceBizService.update(params);
        return new Result<StandardSourceVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:source:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardSourceGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardSourceBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:source:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardSourceVO.class)
    public  Result<StandardSourceVO> info(@RequestBody StandardSourceGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSourceVO data=  standardSourceBizService.getById(params.getId());
        return new Result<StandardSourceVO>().ok(data);
    }





}
