package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardDiseaseVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardSymptomVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardSymptomBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/symptom")
@Api(tags = "运营端,标准症状管理")
public class StandardSymptomManagerController {

    @Autowired
    private StandardSymptomBizService standardSymptomBizService;


    @SaCheckPermission("sys:standard:symptom:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardSymptomVO.class)
    public Result<PageData<StandardSymptomVO>> query(@RequestBody StandardSymptomQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardSymptomVO> data = standardSymptomBizService.query(params);
        return new Result<PageData<StandardSymptomVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:symptom:tree")
    @PostMapping("/tree")
    @ApiOperation(value = "树", response = StandardDiseaseVO.class)
    public Result<List<StandardSymptomVO>> tree(@RequestBody StandardSymptomTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSymptomVO> data=standardSymptomBizService.tree(params);
        return new Result<List<StandardSymptomVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:symptom:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardDiseaseVO.class)
    public Result<List<StandardSymptomVO>> list(@RequestBody StandardSymptomListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardSymptomVO> data=standardSymptomBizService.list(params);
        return new Result<List<StandardSymptomVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:symptom:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardSymptomVO.class)
    public Result<StandardSymptomVO> save(@RequestBody StandardSymptomSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSymptomVO data= standardSymptomBizService.save(params);
        return new Result<StandardSymptomVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:symptom:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardSymptomVO.class)
    public Result<StandardSymptomVO> update(@RequestBody StandardSymptomUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSymptomVO data=  standardSymptomBizService.update(params);
        return new Result<StandardSymptomVO>().ok(data);
    }


    @SaCheckPermission("sys:standard:symptom:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardSymptomGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardSymptomBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:symptom:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardSymptomVO.class)
    public  Result<StandardSymptomVO> info(@RequestBody StandardSymptomGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardSymptomVO data=  standardSymptomBizService.getById(params.getId());
        return new Result<StandardSymptomVO>().ok(data);
    }




}
