package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardUnitVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.biz.StandardUnitBizService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Log4j2
@RestController
@RequestMapping("/sys/standard/unit")
@Api(tags = "运营端,标准化验单位管理")
public class StandardUnitManagerController {

    @Autowired
    private StandardUnitBizService standardUnitBizService;




    @SaCheckPermission("sys:standard:unit:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = StandardUnitVO.class)
    public Result<PageData<StandardUnitVO>> query(@RequestBody StandardUnitQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<StandardUnitVO> data= standardUnitBizService.query(params);
        return new Result<PageData<StandardUnitVO>>().ok(data);
    }

    @SaCheckPermission("sys:standard:unit:list")
    @PostMapping("/tree")
    @ApiOperation(value = "列表", response = StandardUnitVO.class)
    public Result<List<StandardUnitVO>> list(@RequestBody StandardUnitListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<StandardUnitVO> data=standardUnitBizService.list(params);
        return new Result<List<StandardUnitVO>>().ok(data);
    }


    @SaCheckPermission("sys:standard:unit:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = StandardUnitVO.class)
    public Result<StandardUnitVO> save(@RequestBody StandardUnitSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardUnitVO data= standardUnitBizService.save(params);
        return new Result<StandardUnitVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:unit:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = StandardUnitVO.class)
    public Result<StandardUnitVO> update(@RequestBody StandardUnitUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardUnitVO data=standardUnitBizService.update(params);
        return new Result<StandardUnitVO>().ok(data);
    }

    @SaCheckPermission("sys:standard:unit:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody StandardUnitGetDTO params) {
        ValidatorUtils.validateEntity(params);
        standardUnitBizService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:standard:unit:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = StandardUnitVO.class)
    public  Result<StandardUnitVO> info(@RequestBody StandardUnitGetDTO params) {
        ValidatorUtils.validateEntity(params);
        StandardUnitVO data= standardUnitBizService.getById(params.getId());
        return new Result<StandardUnitVO>().ok(data);
    }


}
