package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.biz.TableCategoryInfoBizService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategoryTreeDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableCategoryVO;
import com.xxh.cloud.metadata.framework.modules.base.service.TableCategoryInfoService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategoryInfoDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategorySaveDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableCategoryUpdateDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

//@SaCheckPermission("sys:metadata:tableCategory")
@Log4j2
@RestController
@RequestMapping("/sys/metadata/tableCategory")
@Api(tags = "运营端, 表分类管理")
public class TableCategoryManagerController {

    @Autowired
    private TableCategoryInfoBizService tableCategoryInfoService;



    @SaCheckPermission("sys:metadata:tableCategory:tree")
    @PostMapping("/tree")
    @ApiOperation(value = "元数据分类树", response = TableCategoryVO.class)
    public Result<List<TableCategoryVO>> tree(@RequestBody TableCategoryTreeDTO params) {
        ValidatorUtils.validateEntity(params);
        List<TableCategoryVO> data= tableCategoryInfoService.tree(params);
        return new Result<List<TableCategoryVO>>().ok(data);
    }



    @SaCheckPermission("sys:metadata:tableCategory:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = TableCategoryVO.class)
    public Result<TableCategoryVO> save(@RequestBody TableCategorySaveDTO params) {
        ValidatorUtils.validateEntity(params);
        TableCategoryVO data= tableCategoryInfoService.save(params);
        return new Result<TableCategoryVO>().ok(data);
    }

    @SaCheckPermission("sys:metadata:tableCategory:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = TableCategoryVO.class)
    public Result<TableCategoryVO> update(@RequestBody TableCategoryUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        TableCategoryVO data=tableCategoryInfoService.update(params);
        return new Result<TableCategoryVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:tableCategory:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody TableCategoryInfoDTO params) {
        ValidatorUtils.validateEntity(params);
        tableCategoryInfoService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:metadata:tableCategory:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = TableCategoryVO.class)
    public  Result<TableCategoryVO> info(@RequestBody TableCategoryInfoDTO params) {
        ValidatorUtils.validateEntity(params);
        TableCategoryVO data= tableCategoryInfoService.infoById(params.getId());
        return new Result<TableCategoryVO>().ok(data);
    }


}
