package com.xxh.cloud.metadata.sys.manager.controller;


import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.collection.CollUtil;
import com.xxh.cloud.framework.common.constant.YN;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.biz.TableInfoBizService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.TableInfoListDTO;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import com.xxh.cloud.metadata.framework.modules.standardBiz.bean.vos.StandardOperationVO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.dto.*;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataList2TableVO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataOne2TableVO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataPage2TableVO;
import com.xxh.cloud.metadata.framework.modules.tableData.bean.vos.TableDataVO;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataBizService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataGetService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataListService;
import com.xxh.cloud.metadata.framework.modules.tableData.biz.TableDataQueryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

//@SaCheckPermission("sys:metadata:tableInfo")
@Log4j2
@RestController
@RequestMapping("/sys/data/table")
@Api(tags = "运营端, 表数据管理")
public class TableDataManagerController {

    @Autowired
    private TableDataBizService tableDataBizService;
    @Autowired
    private TableDataQueryService tableDataQueryService;
    @Autowired
    private TableDataListService tableDataListService;
    @Autowired
    private TableDataGetService tableDataGetService;


    @Autowired
    private TableInfoBizService tableInfoService;


    /**
     * query
     * */
    @SaCheckPermission("sys:data:table:query")
    @PostMapping("/query")
    @ApiOperation(value = "查询", response = TableDataVO.class)
    public Result<PageData<TableDataVO>> query(@RequestBody TableDataQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<TableDataVO> data= tableDataQueryService.query(params);
        return new Result<PageData<TableDataVO>>().ok(data);
    }

    @SaCheckPermission("sys:data:table:queryMap")
    @PostMapping("/queryMap")
    @ApiOperation(value = "查询", response = Map.class)
    public Result<PageData<Map<String,Object>>> queryMap(@RequestBody TableDataQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<Map<String,Object>> data= tableDataQueryService.queryMap(params);
        return new Result<PageData<Map<String,Object>>>().ok(data);
    }

    @SaCheckPermission("sys:data:table:query2Table")
    @PostMapping("/query2Table")
    @ApiOperation(value = "查询(含表字段)", response = TableDataPage2TableVO.class)
    public Result<TableDataPage2TableVO> query2Table(@RequestBody TableDataQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        TableDataPage2TableVO data= tableDataQueryService.query2Table(params);
        return new Result<TableDataPage2TableVO>().ok(data);
    }


    /**
     * list
     * */
    @SaCheckPermission("sys:data:table:list")
    @PostMapping("/list")
    @ApiOperation(value = "列表", response = StandardOperationVO.class)
    public Result<List<TableDataVO>> list(@RequestBody TableDataListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<TableDataVO> data=tableDataListService.list(params);
        return new Result<List<TableDataVO>>().ok(data);
    }

    @SaCheckPermission("sys:data:table:listMap")
    @PostMapping("/listMap")
    @ApiOperation(value = "列表", response = Map.class)
    public Result<List<Map<String,Object>>> listMap(@RequestBody TableDataListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<Map<String,Object>> data=tableDataListService.listMap(params);
        return new Result<List<Map<String,Object>>>().ok(data);
    }

    @SaCheckPermission("sys:data:table:list2Table")
    @PostMapping("/list2Table")
    @ApiOperation(value = "列表(含表字段)", response = TableDataList2TableVO.class)
    public Result<TableDataList2TableVO> list2Table(@RequestBody TableDataListDTO params) {
        ValidatorUtils.validateEntity(params);
        TableDataList2TableVO data=tableDataListService.list2Table(params);
        return new Result<TableDataList2TableVO>().ok(data);
    }


    @SaCheckPermission("sys:data:table:list2TableByTableCategory")
    @PostMapping("/list2TableByTableCategory")
    @ApiOperation(value = "列表(含表字段)", response = TableDataList2TableVO.class)
    public Result<List<TableDataList2TableVO>> list2TableByTableCategory(@RequestBody TableDataListByTableCategoryDTO params) {
        ValidatorUtils.validateEntity(params);

        TableInfoListDTO listDTO=new TableInfoListDTO();
        listDTO.setCategoryId(params.getCategoryId());
        listDTO.setProjectCode(params.getProjectCode());
        listDTO.setCols(false);
        listDTO.setStatus(YN.YES.getCode());
        List<TableInfoVO> tableList= tableInfoService.list(listDTO);

        List<TableDataList2TableVO> data=new ArrayList<>();

        if(CollUtil.isNotEmpty(tableList)){
            tableList.forEach(item->{
                TableDataListDTO tableDataListDTO=new TableDataListDTO();
                tableDataListDTO.setTableId(item.getId());
                tableDataListDTO.setObjectType(params.getObjectType());
                tableDataListDTO.setObjectId(params.getObjectId());
                TableDataList2TableVO dataItem=tableDataListService.list2Table(tableDataListDTO);
                data.add(dataItem);
            });
        }

        return new Result<List<TableDataList2TableVO>>().ok(data);
    }


    /**
     * get
     * */
    @SaCheckPermission("sys:data:table:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = TableDataVO.class)
    public  Result<TableDataVO> info(@RequestBody TableDataGetDTO params) {
        ValidatorUtils.validateEntity(params);
        TableDataVO data= tableDataGetService.getById(params);
        return new Result<TableDataVO>().ok(data);
    }


    @SaCheckPermission("sys:data:table:info2Map")
    @PostMapping("/info2Map")
    @ApiOperation(value = "获取", response = Map.class)
    public  Result<Map<String,Object>> info2Map(@RequestBody TableDataGetDTO params) {
        ValidatorUtils.validateEntity(params);
        Map<String,Object> data= tableDataGetService.getMapById(params);
        return new Result<Map<String,Object>>().ok(data);
    }

    @SaCheckPermission("sys:data:table:info2Table")
    @PostMapping("/info2Table")
    @ApiOperation(value = "获取数据(含表字段)", response = TableDataOne2TableVO.class)
    public  Result<TableDataOne2TableVO> info2Col(@RequestBody TableDataGetDTO params) {
        ValidatorUtils.validateEntity(params);
        TableDataOne2TableVO data=  tableDataGetService.get2TableById(params);
        return new Result<TableDataOne2TableVO>().ok(data);
    }

    /**
     *
     * */
    @SaCheckPermission("sys:data:table:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增", response = String.class)
    public Result<String> save(@RequestBody TableDataSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        tableDataBizService.save(params);
        return new Result<String>().ok("ok");
    }

    /**
     *
     * */
    @SaCheckPermission("sys:data:table:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改", response = String.class)
    public Result<String> update(@RequestBody TableDataUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        tableDataBizService.update(params);
        return new Result<String>().ok("ok");
    }


    /**
     *
     * */
    @SaCheckPermission("sys:data:table:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody TableDataGetDTO params) {
        ValidatorUtils.validateEntity(params);
        tableDataBizService.delById(params);
        return new Result<String>().ok("ok");
    }

}
