package com.xxh.cloud.metadata.sys.manager.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.xxh.cloud.framework.common.entity.Result;
import com.xxh.cloud.framework.common.page.PageData;
import com.xxh.cloud.framework.common.validator.ValidatorUtils;
import com.xxh.cloud.metadata.framework.modules.base.biz.TableInfoBizService;
import com.xxh.cloud.metadata.framework.modules.base.entity.dto.*;
import com.xxh.cloud.metadata.framework.modules.base.entity.vos.TableInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

//@SaCheckPermission("sys:metadata:tableInfo")
@Log4j2
@RestController
@RequestMapping("/sys/metadata/tableInfo")
@Api(tags = "运营端, 表管理")
public class TableManagerController {

    @Autowired
    private TableInfoBizService tableInfoService;


    @SaCheckPermission("sys:metadata:tableInfo:query")
    @PostMapping("/query")
    @ApiOperation(value = "表查询", response = TableInfoVO.class)
    public Result<PageData<TableInfoVO>> query(@RequestBody TableInfoQueryDTO params) {
        ValidatorUtils.validateEntity(params);
        PageData<TableInfoVO> data= tableInfoService.query(params);
        return new Result<PageData<TableInfoVO>>().ok(data);
    }



    @SaCheckPermission("sys:metadata:tableInfo:list")
    @PostMapping("/list")
    @ApiOperation(value = "表列表", response = TableInfoVO.class)
    public Result<List<TableInfoVO>> list(@RequestBody TableInfoListDTO params) {
        ValidatorUtils.validateEntity(params);
        List<TableInfoVO> data= tableInfoService.list(params);
        return new Result<List<TableInfoVO>>().ok(data);
    }



    @SaCheckPermission("sys:metadata:tableInfo:save")
    @PostMapping("/save")
    @ApiOperation(value = "新增(不含字段)", response = TableInfoVO.class)
    public Result<TableInfoVO> save(@RequestBody TableInfoSaveDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO data= tableInfoService.save(params);
        return new Result<TableInfoVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:tableInfo:update")
    @PostMapping("/update")
    @ApiOperation(value = "修改(不含字段)", response = TableInfoVO.class)
    public Result<TableInfoVO> update(@RequestBody TableInfoUpdateDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO data=tableInfoService.update(params);
        return new Result<TableInfoVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:tableInfo:updateStatus")
    @PostMapping("/updateStatus")
    @ApiOperation(value = "更新状态", response = String.class)
    public Result<String> updateStatus(@RequestBody TableInfoUpdateStatusDTO params) {
        ValidatorUtils.validateEntity(params);
        tableInfoService.updateStatus(params);
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:metadata:tableInfo:save2col")
    @PostMapping("/save2col")
    @ApiOperation(value = "新增(含字段)", response = TableInfoVO.class)
    public Result<TableInfoVO> save2col(@RequestBody TableInfoSave2ColDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO data= tableInfoService.save2Column(params);
        return new Result<TableInfoVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:tableInfo:update2col")
    @PostMapping("/update2col")
    @ApiOperation(value = "修改(含字段)", response = TableInfoVO.class)
    public Result<TableInfoVO> update2col(@RequestBody TableInfoUpdate2ColDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO data=tableInfoService.update2Column(params);
        return new Result<TableInfoVO>().ok(data);
    }

    @SaCheckPermission("sys:metadata:tableInfo:saveUpdateTable2Col")
    @PostMapping("/saveUpdateTable2Col")
    @ApiOperation(value = "批量新增修改表字段", response = TableInfoVO.class)
    public Result<TableInfoVO> saveUpdateTable2Col(@RequestBody TableInfoUpdate2ColDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO data=tableInfoService.save2updateColumnBatch(params);
        return new Result<TableInfoVO>().ok(data);
    }


    @SaCheckPermission("sys:metadata:tableInfo:del")
    @PostMapping("/del")
    @ApiOperation(value = "删除", response = String.class)
    public Result<String> del(@RequestBody TableInfoGetDTO params) {
        ValidatorUtils.validateEntity(params);
        tableInfoService.delById(params.getId());
        return new Result<String>().ok("ok");
    }

    @SaCheckPermission("sys:metadata:tableInfo:info")
    @PostMapping("/info")
    @ApiOperation(value = "获取", response = TableInfoVO.class)
    public  Result<TableInfoVO> info(@RequestBody TableInfoGetDTO params) {
        ValidatorUtils.validateEntity(params);
        TableInfoVO data= tableInfoService.infoById(params.getId());
        return new Result<TableInfoVO>().ok(data);
    }




}
